// ===  BITA.CPP ===
// manipulacia so suborom na urovni bitov

#include "bita.h"
#include <alloc.h>
#include <mem.h>

bita *bitar_create(char fn[])
{
  bita *ba;

  if ( !(ba = new bita) ) return NULL;
  if ( (ba->file = fopen(fn, "rb")) == NULL) {
    delete ba;
    return NULL;
  }
  if ( !(ba->buf = (char*)malloc(BUF_SZ)) ) {
    fclose(ba->file);
    delete ba;
    return NULL;
  }
  if ( (ba->full = fread((void*)ba->buf,1,BUF_SZ,ba->file)) <= 0 ) {
    free(ba->buf);
    fclose(ba->file);
    delete ba;
    return NULL;
  };
  ba->pos = 0;
  ba->full *= 8;
  return ba;
}

BOOLEAN bita_read(bita *ba,uchar count,uint *val)
{
  uint size,swap,div;
  ulong res;
  uchar mod,remaind;

  div = ba->pos/8;
  mod = ba->pos%8;

  if ( ba->pos + count > ba->full ) {
    remaind = ba->full/8 - div;
    memcpy((void*)&swap,(void*)(ba->buf+div),remaind);
    if ( (size = fread((void*)(ba->buf+remaind),1,BUF_SZ-remaind,ba->file)) <= 0 ) return FALSE;
    memcpy((void*)ba->buf,(void*)&swap,remaind);
    ba->pos = mod;
    div = 0;
    ba->full = (ulong)(size+remaind)*8;
  }
//  res = *(ulong*)(ba->buf + div);
  *((char*)&res  ) = *(ba->buf + div + 3);
  *((char*)&res+1) = *(ba->buf + div + 2);
  *((char*)&res+2) = *(ba->buf + div + 1);
  *((char*)&res+3) = *(ba->buf + div    );

  res <<= mod;
  res >>= 32-count;
  *val = res;
  ba->pos += count;
  return TRUE;
}

void bitar_drop(bita *ba)
{
  fclose(ba->file);
  free(ba->buf);
  delete ba;
}

bita *bitaw_create(char fn[])
{
  bita *ba;

  if ( !(ba = new bita) ) return NULL;
  if ( (ba->file = fopen(fn, "wb")) == NULL) {
    delete ba;
    return NULL;
  }
  if ( !(ba->buf = (char*)malloc(BUF_SZ)) ) {
    fclose(ba->file);
    delete ba;
    return NULL;
  }
  memset((void*)ba->buf,0,BUF_SZ);
  ba->pos = 0;
  ba->full = (ulong)BUF_SZ*8;
  return ba;
}

BOOLEAN bita_write(bita *ba,uchar count,uint val)
{
  uint div,res;
  uchar mod,remaind;
  char rorc;

  div = ba->pos/8;
  mod = ba->pos%8;

  if (ba->pos + count > ba->full) {
    if ( fwrite((void*)ba->buf,1,div,ba->file) <=0 ) return FALSE;
    remaind = ba->full/8 - div;
    memcpy((void*)ba->buf,(void*)(ba->buf+div),remaind);
    memset(ba->buf+remaind,0,BUF_SZ-remaind);
    ba->pos = mod;
    div = 0;
  }

  if (count>8) {
    res = *((uchar*)&val+1);
    rorc = count+mod-16;
    asm {
      mov cl,rorc
      ror res,cl
    }
    *(uint*)(ba->buf + div) |= res;
    ba->pos += count-8;
    div = ba->pos/8;
    mod = ba->pos%8;
    count = 8;
  }

  res = (uchar)val;
  rorc = count+mod-8;
  asm {
    mov cl,rorc
    ror res,cl
  }
  *(uint*)(ba->buf + div) |= res;
  ba->pos += count;

  return TRUE;
}

void bitaw_drop(bita *ba)
{
  fwrite((void*)ba->buf,1,ba->pos/8+(ba->pos%8==0 ? 0:1),ba->file);
  fclose(ba->file);
  free(ba->buf);
  delete ba;
}
