// === code.cpp ===
// zakodovanie vstupneho suboru Huffmanovym kodom

#include "bita.h"
#include "tree.h"
#include <string.h>
#include <values.h>

ulong filesize(FILE *stream)
{
   long curpos, length;

   curpos = ftell(stream);
   fseek(stream, 0L, SEEK_END);
   length = ftell(stream);
   fseek(stream, curpos, SEEK_SET);
   return length;
}

BOOLEAN make_histogram(char fn[],alpha *abc)
{
  FILE *f;
  ulong fsize,i;
  uchar ch;

  if ( (f = fopen(fn, "rb")) == NULL) return FALSE;
  fsize = filesize(f);
  for (i=0;i<NALPHA;i++) {
    abc[i].weight = 0;
    abc[i].code = 0;
    abc[i].ch = i;
    abc[i].sz = 0;
  }
  for (i=0;i<fsize;i++) {
    fread((void*)&ch,1,1,f);
    abc[ch].weight++;
  }
  for (i=0;i<NALPHA-1;i++)
    abc[i].weight /= fsize;
  abc[i].weight = MINFLOAT;

  fclose(f);
  return TRUE;
}

BOOLEAN create_wood(vertex *wood[],alpha abc[])
{
  int treei,i;

  for (i=0;i<NALPHA;i++)
    wood[i] = NULL;
  treei = 0;
  for (i=0;i<NALPHA;i++)
    if (abc[i].weight > 0)
      if ( (wood[treei++] = empty00(&abc[i])) == NULL) return FALSE;
  return TRUE;
}

BOOLEAN find(vertex *wood[],uint *i1,uint *i2)
{
  float minwei,weight;
  uint ch,i;
  int mini1,mini2,count;

  minwei = 2.00;
  count = 0;
  for (i=0;i<NALPHA;i++) {
    if (wood[i] == NULL) continue;
    count++;
    hod(wood[i],&ch,&weight);
    if (weight < minwei) {
      minwei = weight;
      mini1 = i;
    }
  }
  if (count == 1) return FALSE;
  minwei = 2.00;
  for (i=0;i<NALPHA;i++) {
    if ((wood[i] == NULL) || (i == mini1)) continue;
    hod(wood[i],&ch,&weight);
    if (weight < minwei) {
      minwei = weight;
      mini2 = i;
    }
  }

  if (mini1 < mini2) {
    *i1 = mini1;
    *i2 = mini2;
  } else {
    *i1 = mini2;
    *i2 = mini1;
  }
  return TRUE;
}

void huffman(vertex *wood[])
{
  uint i1,i2;

  while (find(wood,&i1,&i2)) {
    wood[i1] = empty02(wood[i1],wood[i2]);
    wood[i2] = NULL;
  }
}

void get_codes(vertex *tree,alpha abc[],uchar sz,uint code)
{
  uint ch;
  float weight;

  if ( (nextl(tree) == NULL) && (nextr(tree) == NULL) ) {
    hod(tree,&ch,&weight);
    abc[ch].sz = sz;
    abc[ch].code = code;
    return ;
  }
  if ( nextl(tree) != NULL)
    get_codes(nextl(tree),abc,sz+1,(code << 1)|1);
  if ( nextr(tree) != NULL)
    get_codes(nextr(tree),abc,sz+1,code << 1);
  return;
}

void getoutfn(char fn[],char outfn[])
{
  strcpy(outfn,fn);
  *strchr(outfn,'.') = 0;
  strcat(outfn,".huf");
}

BOOLEAN code(char fn[],alpha abc[])
{
  FILE *in;
  bita *baw;
  uint i;
  uchar ch;
  char outfn[100];

  getoutfn(fn,outfn);
  if ( (in = fopen(fn, "rb")) == NULL ) return FALSE;
  if ( (baw = bitaw_create(outfn)) == NULL ) return FALSE;

  for (i=0;i<NALPHA;i++) {
    bita_write(baw,MAX_CODE_SIZE,abc[i].sz);
    bita_write(baw,abc[i].sz,abc[i].code);
  }

  while (fread((void*)&ch,1,1,in))
    bita_write(baw,abc[ch].sz,abc[ch].code);
  bita_write(baw,abc[NALPHA-1].sz,abc[NALPHA-1].code);
  bitaw_drop(baw);
  fclose(in);
  return TRUE;
}

int main(int argc,char *argv[])
{
  char *fn;
  alpha abc[NALPHA];
  vertex *wood[NALPHA];

  if (argc != 2) {
    fprintf(stderr,"Usage: %s filename\n",argv[0]);
    return 1;
  }
  fn = argv[1];
  if (!make_histogram(fn,abc)) {
    fprintf(stderr,"File %s not found.\n",fn);
    return 1;
  }
  if (!create_wood(wood,abc)) {
    fprintf(stderr,"Not enough memory.\n",fn);
    return 1;
  }
  huffman(wood);
  get_codes(wood[0],abc,0,0);

  if (!code(fn,abc)) {
    drop(wood[0]);
    fprintf(stderr,"Error while try compress.\n",fn);
    return 1;
  }
  drop(wood[0]);
  return 0;
}