// === decode.cpp ===
// dekodovanie Huffmanovho kodu do povodneho suboru 

#include "bita.h"
#include "tree.h"

vertex *recreate_tree(alpha abc[])
{
  vertex *root,*v1,*v2;
  uint code,mask,i,j;
  BOOLEAN left;

  root = empty00();

  mask = 1 << (sizeof(code)*8-1);
  for (i=0;i<NALPHA;i++) {
    if (abc[i].sz == 0) continue;
    v1 = root;
    code = abc[i].code;
    code <<= sizeof(code)*8-abc[i].sz;
    for (j=0;j<abc[i].sz;j++) {
      if (code&mask) left=TRUE;
      else left=FALSE;
      code <<= 1;

      if (left) v2 = nextl(v1);
      else v2 = nextr(v1);

      if (v2 == NULL) {
	v2 = empty00();
	if (left) setnextl(v1,v2);
	else setnextr(v1,v2);
      }
      v1 = v2;
    }
    v1->ch = i;
  }

  return root;
}

void get_codes(bita *bar,alpha abc[])
{
  uint i,size;

  for (i=0;i<NALPHA;i++) {
    bita_read(bar,MAX_CODE_SIZE,&size);
    abc[i].weight = 0;
    abc[i].ch = i;
    abc[i].sz = (char)size;
    bita_read(bar,abc[i].sz,&abc[i].code);
  }
}

BOOLEAN decode(char fn1[],char fn2[])
{
  FILE *out;
  bita *bar;
  uint bit,ch;
  alpha abc[NALPHA];
  vertex *tree,*v;
  float weight;

  if ( (out = fopen(fn2,"wb")) == NULL ) return FALSE;
  if ( (bar = bitar_create(fn1)) == NULL ) return FALSE;

  get_codes(bar,abc);
  tree = recreate_tree(abc);
  v = tree;

  while (bita_read(bar,1,&bit)) {
    if (bit==1) v = nextl(v);
    else v = nextr(v);
    if ((nextl(v) == NULL) && (nextr(v) == NULL)) {
      hod(v,&ch,&weight);
      if (ch == NALPHA-1)
	break;
      if (fwrite((void*)&ch,1,1,out) <= 0) {
	drop(tree);
	return FALSE;
      }
      v = tree;
    }
  }

  bitar_drop(bar);
  fclose(out);
  drop(tree);

  return TRUE;
}

int main(int argc,char *argv[])
{
  if (argc != 3) {
    fprintf(stderr,"Usage: %s filename1.huf filename2\n",argv[0]);
    return 1;
  }
  if (!decode(argv[1],argv[2])) {
    fprintf(stderr,"Error while try decompress.\n",argv[1]);
    return 1;
  }

  return 0;
}

