#include "toolset.h"
#define TDELTA 8.0

//Marek Ratkovsky 3INF8 1997
//Simulacia obvodu navypocet neparnej parity
//Obvod ma na vystupe 1-tku, ked je na vstupe nepatny pocet jednotiek
/*
Navrh obvodu:



	Tabulka prechodov:

						X0|X1|X2|Y
						----------
						 0| 0| 0|0
						 0| 0| 1|1
						 0| 1| 0|1
						 0| 1| 1|0
						 1| 0| 0|1
						 1| 0| 1|0
						 1| 1| 0|0
						 1| 1| 1|1

	Karn.mapa:
									X2
							 X1 ___
								---
						 +-+-+-+-+
						 |0|1|0|1|
						|+-+-+-+-+
					X0||1|0|1|0|
						|+-+-+-+-+


	Vysledna funkcia:

								 -- -- --    --          -- --
							X0.X1.X2+X0.X1.X2+X0.X1.X2+X0.X1.X2



	Schema obvodu:

										--
			 "INTERNAL0"="X0"
								+---+
								|	 1|
	"X0" O-----x--|   |o---------+
						 |	|   |          |
						 |	+---+          |
						 |                 |  +---+
						 +-------------x------|  &|                  -- --
													 |   |	|   |  "INTERNAL3"= X0.X1.X2
											 +----------|   |-------+
											 |	 |   |	|   |       |
											 | +--------|   |       |
											 | | |   |	+---+       |
											 | | |   | 							|
											 | | |   |  						|
											 | | |   |	  					|
											 | | |   |	+---+       |
										-- | | |   x--|  &|       |
			 "INTERNAL1"="X1"| | |	 |	|   |       |             -- --
								+---+  | | | +----|   |-----+ |"INTERNAL5"= X0.X1.X2
								|  1|  | | | | |  |   |     | | +---+
	"X1" O-----x--|	  |o-x----------|   |     | +-|  1|
						 |	|   |    | | | |  +---+     |   |   |
						 |	+---+    | | | |            +---|   |              -- -- --    --          -- --
						 |	         | | | |                |   |----O "O"= X0.X1.X2+X0.X1.X2+X0.X1.X2+X0.X1.X2
						 |           | | | |            +---|   |
						 |				   | | | |	+---+     |   |   |
						 +---------x-|--------|  &|     | +-|   |
											 | | | | |	|   |     | | +---+
											 | | +------|   |-----+ |"INTERNAL6"= X0.X1.X2
											 | |	 | |	|   |       |
											 | |   x----|   |       |
											 | |   | |  +---+       |
											 | |   | |    					|
											 | |   | |		  				|
										-- | |   | |			  			|
			 "INTERNAL2"="X2"| |   | |	+---+       |
								+---+  | |   | +--|  &|       |
								|	 1|  | |   |    |   |       |
	"X2" O-----x--|   |o---x--------|   |-------+       --    --
						 |	|   |  |     |    |   |  "INTERNAL4"= X0.X1.X2
						 |	+---+  +----------|   |
						 |               |    +---+
						 +---------------+



Priebehy na vstupoch su naplanovane nasledovne (vid initSimulation):




	HIGH                       +-----------------------+
X1                           |                       |
	LOW -----------------------+                       +-
														100                     200  [ns]

	HIGH           +-----------+           +-----------+
X1               |           |           |           |
	LOW -----------+           +-----------+           +-
								 50         100         150         200  [ns]

	HIGH     +-----+     +-----+     +-----+     +-----+
X2         |     |     |     |     |     |     |     |
	LOW -----+     +-----+     +-----+     +-----+     +-
					 25	   50    75   100   125   150   175   200  [ns]


Vysledna funkcia:

										-- -- --    --          -- --
							 O=X0.X1.X2+X0.X1.X2+X0.X1.X2+X0.X1.X2


Sprava o simulacii:

 Time   X0 X1 X2  I0 I1 I2 I3 I4 I5 I6    O
 ------------------------------------------
		0   L  L  L 	 X  X  X  X  X  X  X    X
		8   L  L  L 	 H  H  H  L  L  L  L    X
	 16   L  L  L 	 H  H  H  L  L  L  L    L
	 25   L  L  H 	 H  H  H  L  L  L  L    L
	 33   L  L  H 	 H  H  L  L  L  H  L    L
	 41   L  L  H 	 H  H  L  L  L  H  L    H
	 50   L  H  L 	 H  H  L  L  L  H  L    H
	 58   L  H  L 	 H  L  H  L  L  L  L    H
	 66   L  H  L 	 H  L  H  L  H  L  L    L
	 74   L  H  L 	 H  L  H  L  H  L  L    H
	 75   L  H  H 	 H  L  H  L  H  L  L    H
	 83   L  H  H 	 H  L  L  L  H  L  L    H
	 91   L  H  H 	 H  L  L  L  L  L  L    H
	 99   L  H  H 	 H  L  L  L  L  L  L    L
	100   H  L  L 	 H  L  L  L  L  L  L    L
	108   H  L  L 	 L  H  H  L  L  L  L    L
	116   H  L  L 	 L  H  H  H  L  L  L    L
	124   H  L  L 	 L  H  H  H  L  L  L    H
	125   H  L  H 	 L  H  H  H  L  L  L    H
	133   H  L  H 	 L  H  L  H  L  L  L    H
	141   H  L  H 	 L  H  L  L  L  L  L    H
	149   H  L  H 	 L  H  L  L  L  L  L    L
	150   H  H  L 	 L  H  L  L  L  L  L    L
	158   H  H  L 	 L  L  H  L  L  L  L    L
	175   H  H  H 	 L  L  H  L  L  L  L    L
	183   H  H  H 	 L  L  L  L  L  L  H    L
	191   H  H  H 	 L  L  L  L  L  L  H    H
	200   L  L  L 	 L  L  L  L  L  L  H    H

*/


class CparitaSimulation : public CLogicSimulation {
protected:
	virtual void output();
	virtual void report();   // iba pre ladenie, ked stlacime 'R'
	virtual void design();
	virtual void initSimulation();

	void and(int val[MAX_VAL], CPin& out); //zadefinovanie obvodov and a or
	void and3(CPin& in1, CPin& in2,CPin& in3, CPin& out);

	void or(int val[MAX_VAL], CPin& out);
	void or4(CPin& in1, CPin& in2,CPin& in3,CPin& in4, CPin& out);

public:
	CparitaSimulation() : CLogicSimulation("Logic Simulation", 200.0){}
};

//////////////////////////////////// AND /////////////////////////////////
void CparitaSimulation::and3(CPin& in1,CPin& in2,CPin& in3,CPin& out) {
	int val[MAX_VAL];

	if(analyseInputs(val, 3, &in1, &in2, &in3))
		and(val, out);
}
/////////////////////////////////// OR ///////////////////////////////////
void CparitaSimulation::or4(CPin& in1,CPin& in2,CPin& in3,CPin& in4, CPin& out) {
	int val[MAX_VAL];

	if(analyseInputs(val, 4, &in1, &in2, &in3, &in4))
		or(val, out);
}

void CparitaSimulation::and(int val[MAX_VAL], CPin& out) {
	logic_val v;

	if(val[LOW]) v = LOW;
	else if(!val[UNDEF]) v = HIGH;
			 else v = UNDEF;

	setPin(out, TDELTA, v);
}

void CparitaSimulation::or(int val[MAX_VAL], CPin& out) {
	logic_val v;

	if(val[HIGH]) v = HIGH;
	else if(!val[UNDEF]) v = LOW;
			 else v = UNDEF;

	setPin(out, TDELTA, v);
}

DEFINE_BUS(X,3);      	// 3 vstupy
DEFINE_BUS(INTERNAL,7); // 7 internych uzlov schemy
DEFINE_NODE(O);         // vystup

// V metode output urcime format a obsah vypisu hodnot jednotlivych uzlov
void CparitaSimulation::output() {
	print("%4.0lf   %c  %c  %c 	 %c  %c  %c  %c  %c  %c  %c    %c\n", getSimTime(), X[0].printVal(),
				X[1].printVal(),X[2].printVal(), INTERNAL[0].printVal(), INTERNAL[1].printVal(),
				INTERNAL[2].printVal(), INTERNAL[3].printVal(), INTERNAL[4].printVal(),
				INTERNAL[5].printVal(), INTERNAL[6].printVal(),O.printVal());
}

// Na zaver vypoctu sa nechystame tlacit spravu o simulacii,
// ale pocas ladenia sa mozeme zaujimat o aktualne hodnoty na uzloch.
// Metoda report() vypise to iste ako output(), ale s hlavickou.
void CparitaSimulation::report()
{
	print("                     \n"
				"----------------------SIMULATION REPORT---------------------------\n"
	"Simulation name : %s", getName());
	print("\nTime X0 X1 X2   I0 I1 I2 I3 I4 I5 I6  O"
				"\n---------------------------------------\n");
	output();
	print("----------------------- END OF REPORT ----------------------------\n");
}

// metoda design obsahuje volania metod, reprezentujucich jednotlive logicke
// cleny. Parametrami su cisla uzlov (vid schema vyssie)
void CparitaSimulation::design() {

	clock(X[0], 100, 100, LOW);
	clock(X[1],  50,  50, LOW);
	clock(X[2],  25,  25, LOW);

	not(X[0], INTERNAL[0]);
	not(X[1], INTERNAL[1]);
	not(X[2], INTERNAL[2]);

	and3(X[0],INTERNAL[1],INTERNAL[2],INTERNAL[3]);
	and3(X[1],INTERNAL[0],INTERNAL[2],INTERNAL[4]);
	and3(X[2],INTERNAL[0],INTERNAL[1],INTERNAL[5]);
	and3(X[0],X[1]       ,X[2]       ,INTERNAL[6]);

	or4(INTERNAL[3],INTERNAL[4],INTERNAL[5],INTERNAL[6],O);
}

// v metode initSimulation naplanujeme priebehy logickych hodnot na vstupnych
// uzloch schemy a vytlacime hlavicku, popisujucu vysledky
void CparitaSimulation::initSimulation() {

	design();
	print("\nTime X0 X1 X2   I0 I1 I2 I3 I4 I5 I6  O"
				"\n---------------------------------------\n");
}

int main() {
	CparitaSimulation sim;
	sim.interaction(TRUE);               // zastane po stlaceni klavesy
	sim.tracing(FALSE);                   // vypisuje informacie
	sim.stepping(FALSE);                 // zastane pred kazdou udalostou
	sim.simulate();
	return 0;
}
