
#include "toolset.h"    // hlavickovy subor toolset.h zabezpeci deklaraciu
			// potrebnych udajovych struktur pre "tiny toolset"

#define MAX_PROCES 3			// 3 procesy
#define MAX_TIME 300000			// msec 300sec

#define CACHE_CHANCE 0.8		// normal 0.8

#define STR_DOBA_PROC (100/(2+CACHE_CHANCE))	// msec , 10 msec normal
#define STR_DOBA_ZAL1 25
#define STR_DOBA_ZAL2 100


CAbstractProcess* scheduler, *zal1, *zal2, *proc;

CMultiGen	genProc(3), genZal1(3),	genZal2(3), genWhich(), genWhich2();  // generatory nahodnych cisel

TIMETYPE procTime = 0;
TIMETYPE zal1Time = 0;
TIMETYPE zal2Time = 0;
TIMETYPE startTime = 0;

// proces zdroj v intervaloch vytvara nove poziadavky a vklada ich do radu
// ak spolupracujuci proces kanal spal, tak ho zobudi
DEFINE_PROCESS(zal1) {
  for(;;) {
    CTrans* trNew = new CTrans(owner->getSimTime());
    Q->insert(trNew);
    if(kanalid->isIdle())
      kanalid->activateAfterProcess(this);
    hold(gen1.negexp(meanArr));

	double casula = genZal1->negexp(STR_DOBA_ZAL1);
	::zal1Time += casula;

    scheduler->activateAfterProcess(this);
    hold(casula);

  }
}

// ak proces kanal zisti prazdny rad, ide spat. V opacnom pripade vyberie
// poziadavku a obsadi nou na dany cas zariadenie. A toto stale dokola
DEFINE_PROCESS(zal2) {
  for(;;) {
    if(Q->getLength()==0) passivate();
    CTrans* tr = Q->remove();
    F->enter(tr);
    hold(gen2.negexp(meanServ));
    F->leave(tr);
    delete tr;
  }
}

DEFINE_PROCESS(proc) {
  for(;;) {
    if(Q->getLength()==0) passivate();
    CTrans* tr = Q->remove();
    F->enter(tr);
    hold(gen2.negexp(meanServ));
    F->leave(tr);
    delete tr;
  }
}

DEFINE_PROCESS(scheduler) {
  for(;;) {
    if(Q->getLength()==0) passivate();
    CTrans* tr = Q->remove();
    F->enter(tr);
    hold(gen2.negexp(meanServ));
    F->leave(tr);
    delete tr;
  }
}


// odvodime si novy simulator
class CProcSim : public CProcessSimulation {
public:
  CProcSim(TIMETYPE, const char*);
  ~CProcSim();
  void initSimulation();
};

// v konstruktore vytvorime vsetky potrebne objekty (2 procesy rad a zaria-
// denie)
CProcSim::CProcSim(TIMETYPE end, const char* name) : CProcessSimulation(end, name) {
  tracing(TRUE);                   // vypisuje informacie
  kanalid = new kanal(this);
  zdrojid = new zdroj(this);
  Q = new CFifoQueue((CSimulation*)this, "rad");
  F = new CFacility((CSimulation*)this, "Obsluha F");
}

// a v destruktore ich zrusime
CProcSim::~CProcSim() {
  delete kanalid; delete zdrojid;
  delete F; delete Q;
}

// aktivujeme proces zdroj
void CProcSim::initSimulation() {
  zdrojid->activateAfterProcess(current());
}


int main() {
  CProcSim sim(endTime, "Procesova simulacia modelu M/M/1 c.1");
  sim.interaction(TRUE);               // zastane po stlaceni klavesy
  sim.tracing(TRUE);                   // vypisuje informacie
  sim.stepping(TRUE);                  // zastane pred kazdou udalostou
  sim.simulate();
  
  return 0;
}
