#include "toolset.h"

CAbstractProcess * pracovisko1id,* pracovisko2id, * zdrojid;
CMultiGen gen1(3), gen2(3), gen3(3);         // generatory nahodnych cisel
const TIMETYPE endTime  = 28800.0; // cas ukoncenia simulacie
CFifoQueue* Q1,* Q2;                      // smernik na rad poziadaviek bez priority
CFacility* F1,* F2;                       // smernik na zariadenie

// proces zdroj v intervaloch vytvara nove poziadavky a vklada ich do radu
// ak spolupracujuci proces kanal spal, tak ho zobudi
DEFINE_PROCESS(zdroj) {
	for(;;) {
		if(Q1->getLength()<100)
		{
			CTrans* trNew = new CTrans(owner->getSimTime());
			Q1->insert(trNew);
		}

		if(pracovisko1id->isIdle())
			pracovisko1id->activateAfterProcess(this);
		hold(gen1.uniform(400,500));
	}
}

// ak proces kanal zisti prazdny rad, ide spat. V opacnom pripade vyberie
// poziadavku a obsadi nou na dany cas zariadenie. A toto stale dokola
DEFINE_PROCESS(pracovisko1) {
	for(;;) {
		if(Q1->getLength()==0) passivate();
		CTrans* tr = Q1->remove();
		F1->enter(tr);
		hold(gen2.uniform(360,440));
		F1->leave(tr);

		if(Q2->getLength()<100) Q2->insert(tr);

		if(pracovisko2id->isIdle())
			pracovisko2id->activateAfterProcess(this);
	}
}

DEFINE_PROCESS(pracovisko2) {
	for(;;) {
		if(Q2->getLength()==0) passivate();
		CTrans* tr = Q2->remove();
		F2->enter(tr);
		hold(gen2.uniform(280,320));
		F2->leave(tr);
		delete tr;
	}
}


// odvodime si novy simulator
class CProcSim : public CProcessSimulation {
public:
	CProcSim(TIMETYPE, const char*);
	~CProcSim();
	void initSimulation();
};

// v konstruktore vytvorime vsetky potrebne objekty (2 procesy rad a zaria-
// denie)
CProcSim::CProcSim(TIMETYPE end, const char* name) : CProcessSimulation(end, name) {
	tracing(TRUE);                   // vypisuje informacie
	pracovisko1id = new pracovisko1(this);
	pracovisko2id = new pracovisko2(this);
	zdrojid = new zdroj(this);
	Q1 = new CFifoQueue((CSimulation*)this, "rad1");
	Q2 = new CFifoQueue((CSimulation*)this, "rad2");
	F1 = new CFacility((CSimulation*)this, "Obsluha F1");
	F2 = new CFacility((CSimulation*)this, "Obsluha F2");
}

// a v destruktore ich zrusime
CProcSim::~CProcSim() {
	delete pracovisko1id;delete pracovisko2id;delete zdrojid;
	delete F1; delete F2;
	delete Q1;delete Q2;
}

// aktivujeme proces zdroj
void CProcSim::initSimulation() {
	zdrojid->activateAfterProcess(current());
}

int main() {
	CProcSim sim(endTime, "Procesova simulacia modelu M/M/1");
	sim.interaction(TRUE);               // zastane po stlaceni klavesy
	sim.tracing(FALSE);                   // vypisuje informacie
	sim.stepping(FALSE);                  // zastane pred kazdou udalostou
	sim.simulate();
	return 0;
}
