/*
/*
/*	Simulacia 3 vstupoveho multiplexora
/*	pomocou logickych clenov NAND ( 3-vstupove 4ks. )
/*	a dvoch clenov NOT.
/*
/*	(c) 1998 Mojmir Murin
/*
/*	Modelovanie a simulacia 3. rocnik FEI-STU Blava.
/*
/*
*/

#include <toolset.h>

class CMltPlexSim : public CLogicSimulation {
protected:
  virtual void output();
  virtual void report();   // iba pre ladenie, ked stlacime 'R'
  virtual void design();
  virtual void initSimulation();

public:
  CMltPlexSim() : CLogicSimulation("MultiPlex Simulation", 1000.0){}
};


DEFINE_NODE(A1);			// vstup adresa 0
DEFINE_NODE(A2);			// vstup adresa 1
DEFINE_NODE(A);				// vstup 1
DEFINE_NODE(B);				// vstup 2
DEFINE_NODE(C);				// vstup 3
DEFINE_BUS(INTERN,5);		// 5 internych uzlov schemy
DEFINE_NODE(Y);				// vystup multiplexora ( jeden zo vstupov A,B,C podla A1, A2)


// V metode output urcime format a obsah vypisu hodnot jednotlivych uzlov
void CMltPlexSim::output() {
  print("%4.0lf   %c  %c  %c   %c  %c   %c   %c   %c   %c   %c   %c\n", getSimTime(), A.printVal(),
        B.printVal(), C.printVal(), A1.printVal(), A2.printVal(), Y.printVal(),
		INTERN[0].printVal(), INTERN[1].printVal(), INTERN[2].printVal(), INTERN[3].printVal(),
		INTERN[4].printVal());
}

// Na zaver vypoctu sa nechystame tlacit spravu o simulacii,
// ale pocas ladenia sa mozeme zaujimat o aktualne hodnoty na uzloch.
// Metoda report() vypise to iste ako output(), ale s hlavickou.
void CMltPlexSim::report()
{
  print("                     \n"    // vymazeme "   running..."
        "----------------------SIMULATION REPORT---------------------------\n"
	"Simulation name : %s", getName());
//  print("Simulation time : %8.2lf\n", getSimTime());
    // report presne ako output, iba pridaj hlavicku
  print("\nTime   A  B  C   A1 A2  Y   In0 In1 In2 In3 In4"
        "\n-------------------------------\n");
  output();
  print("----------------------- END OF REPORT ----------------------------\n");
}

// metoda design obsahuje volania metod, reprezentujucich jednotlive logicke
// cleny. Parametrami su cisla uzlov (vid schema vyssie)
void CMltPlexSim::design() {

  clock(A1, 150, 150, LOW);
  clock(A2, 300, 300, LOW);
  clock(A,  20,  20,  LOW);
  clock(B,  40,  40,  LOW);
  clock(C,  60,  60,  LOW);

  nand3(A			,INTERN[0]	,INTERN[1]	,INTERN[2]	);
  nand3(B			,INTERN[1]	,A1			,INTERN[3]	);
  nand3(C			,INTERN[0]	,A2			,INTERN[4]	);
  nand3(INTERN[2]	,INTERN[3]	,INTERN[4]	,Y			);
  not(A1,	INTERN[0]);
  not(A2,	INTERN[1]);
}

// v metode initSimulation naplanujeme priebehy logickych hodnot na vstupnych
// uzloch schemy a vytlacime hlavicku, popisujucu vysledky
void CMltPlexSim::initSimulation() {


	
  design();

  print("\nTime   A  B  C   A1 A2  Y   In0 In1 In2 In3 In4"
        "\n-------------------------------\n");
}

// na zaver zostava len vytvorit instanciu nasej triedy a zavolat jej metodu
// simulate
int main() {
  CMltPlexSim sim;
  sim.interaction(TRUE);               // zastane po stlaceni klavesy
  sim.tracing(TRUE);                   // vypisuje informacie
  sim.stepping(TRUE);                  // zastane pred kazdou udalostou
  sim.simulate();
  return 0;
}
