// MasSimulation implementation

#include <iostream.h>
#include "MasSimulation.h"

MasSimulation::MasSimulation(const char * simName, TIMETYPE end)
{
	genProc = new CMultiGen(3);
	genZal1 = new CMultiGen(3);
	genZal2 = new CMultiGen(3);
	genWhich = new CMultiGen();
	genWhich2 = new CMultiGen();

	for (int i = MAX_PROCES; i; i--) {
		processes[i - 1] = new MasProces;
		processes[i - 1]->setStartTime(getSimTime());
	}

	cacheChance = CACHE_CHANCE;

	current = 0;
	procUsage = 0;
	zal1Usage = 0;
	zal2Usage = 0;
	numProcs = 0;
	avTimeProc = 0;
}

MasSimulation::~MasSimulation()
{
	delete genProc;
	delete genZal1;
	delete genZal2;
	delete genWhich;
	delete genWhich2;

// Add current processes into statistics (whatta hell it was to find this should be done)
	for (int i = MAX_PROCES; i; i--) {
		procUsage += processes[i - 1]->procTime;
		zal1Usage += processes[i - 1]->zal1Time;
		zal2Usage += processes[i - 1]->zal2Time;
	}

// Print statistics

//	cout << "Cas straveny v procesore: " << procUsage << " " << (procUsage / getSimTime())*100 << "%" << endl;
//	cout << "Cas straveny v zal1: " << zal1Usage << " " << (zal1Usage / getSimTime())*100 << "%" << endl;
//	cout << "Cas straveny v zal2: " << zal2Usage << " " << (zal2Usage / getSimTime())*100 << "%" << endl;

//	cout << "Priemerna doba trvania procesu v systeme: " << (avTimeProc / numProcs) << endl;

	cout << (procUsage*100/getSimTime()) << "\t" << (zal1Usage*100/getSimTime()) << "\t" << 
		(zal2Usage*100/getSimTime()) << "\t" << (avTimeProc / numProcs) << endl;
}

void MasSimulation::initSimulation()
{
  schedule(0, EV_PROC, processes[current]);
}

BOOL MasSimulation::terminateCondition()
{
	if (getSimTime() >= MAX_TIME) return TRUE;
	else return FALSE;
}

void MasSimulation::executeEvent(EVENTTYPE ev, CTrans * tr, CEntity * en)
{
	switch (ev)
	{
		case EV_SCHED:
			scheduler(tr); break;
		case EV_PROC:
			proc(tr); break;
		case EV_CACHE:
			cache(tr); break;
		case EV_DISK:
			disk(tr); break;
		default: ErrorExit("Je to nejak v passe");
	}
}

void MasSimulation::scheduler(CTrans * trans)
{
	if (++current == MAX_PROCES) current = 0;		// nastav sa na dalsi proces

	if (processes[current]->hadProc) {
		processes[current]->hadProc = FALSE;
		if (genWhich->chance(cacheChance)) {
			schedule(0, EV_CACHE, processes[current]);
			return;
		}
		if (genWhich2->chance((1 - cacheChance - 0.1)/(1 - cacheChance))) {
			numProcs++;								// proces odchadza zo systemu
			avTimeProc += (getSimTime() - processes[current]->startTime);
			procUsage += processes[current]->procTime;
			zal1Usage += processes[current]->zal1Time;
			zal2Usage += processes[current]->zal2Time;
			processes[current]->cleanValues();
			processes[current]->setStartTime(getSimTime());
			if (--current < 0) current = MAX_PROCES - 1;
			schedule(0, EV_PROC, processes[current]);
		} else schedule(0, EV_DISK, processes[current]);	// proces si pyta disk
	} else {										// inac proces vyzaduje procesor
		schedule(0, EV_PROC, processes[current]);
		processes[current]->hadProc = TRUE;
	}
}

void MasSimulation::proc(CTrans * trans)
{
//	printf("proc called\n");
	double casula = genProc->negexp(STR_DOBA_PROC);
	((MasProces*)trans)->procTime += casula;
	schedule(casula, EV_SCHED, trans);
}

void MasSimulation::cache(CTrans * trans)
{
//	printf("cache called\n");
	double casula = genZal1->negexp(STR_DOBA_ZAL1);
	((MasProces*)trans)->zal1Time += casula;
	schedule(casula, EV_SCHED, trans);
}

void MasSimulation::disk(CTrans * trans)
{
//	printf("disk called\n");
	double casula = genZal2->negexp(STR_DOBA_ZAL2);
	((MasProces*)trans)->zal2Time += casula;
	schedule(casula, EV_SCHED, trans);
}

