// MasSimulation header

#ifndef __MAS_SIMULATION_H
#define __MAS_SIMULATION_H

#include <toolset.h>

#define MAX_PROCES 3			// 3 procesy
#define MAX_TIME 300000			// msec 300sec

#define CACHE_CHANCE 0.8		// normal 0.8

#define STR_DOBA_PROC (100/(2+CACHE_CHANCE))	// msec , 10 msec normal
#define STR_DOBA_ZAL1 25
#define STR_DOBA_ZAL2 100

enum { EV_SCHED = 1, EV_PROC, EV_CACHE, EV_DISK };


class MasProces : public CTrans
{
public:
	MasProces()
	{
		name = "MasProces";
		cleanValues();
	};
	virtual ~MasProces() {};
	void cleanValues()
	{
		hadProc = FALSE;
		procTime = zal1Time = zal2Time = 0;
	};
	void setStartTime(TIMETYPE t)
	{
		startTime = t;
	}
	BOOL hadProc;
	TIMETYPE procTime;
	TIMETYPE zal1Time;
	TIMETYPE zal2Time;
	TIMETYPE startTime;
};


class MasSimulation : public CEventSimulation
{
public:
	MasSimulation(const char * simName, TIMETYPE end);
	~MasSimulation();
	virtual void initSimulation();
	virtual void executeEvent(EVENTTYPE ev, CTrans * tr, CEntity * en);
	BOOL terminateCondition();
	void scheduler(CTrans * tr);
	void proc(CTrans * tr);
	void cache(CTrans * tr);
	void disk(CTrans *tr);


	MasProces * processes[MAX_PROCES];
	int current;
	
	double cacheChance;

 	double procUsage;
	double zal1Usage;
	double zal2Usage;
	double avTimeProc;		// time of all the processes which we served
	int numProcs;			// number of processes which system served into the end

	CMultiGen * genProc;	// stredna doba prace procesora bez prerusenia
	CMultiGen * genZal1;	// stredna doba obsluhy zaloznej pamati 1 (cache)
	CMultiGen * genZal2;	// stredna doba obsluhy diskovej pamati
	//CAbstracGen * genWhich;	// rozhoduje co sa stane (cache, disk, end)
	CMultiGen * genWhich;	// rozhoduje co sa stane (cache, disk, end)
	CMultiGen * genWhich2;
};

#endif // __MAS_SIMULATION_H