/*
/*
/*	Simulacia 3 vstupoveho multiplexora
/*	pomocou logickych clenov NAND ( 3-vstupove 4ks. )
/*	a dvoch clenov NOT.
/*
/*	(c) 1998 Mojmir Murin
/*
/*	Modelovanie a simulacia 3. rocnik FEI-STU Blava.
/*
/*
*/


#include <toolset.h>

class MyLogicSimulation : public WLogicSimulation {
protected:
  virtual void update();
  virtual void initSimulation();

  CPin A1, A2, A, B, C, Y, Int1, Int2, Int3, Int4, Int5;

  FILE *log;

public:
  MyLogicSimulation();
  ~MyLogicSimulation() {fclose(log);};

  virtual void vprint(const char *fmt, va_list arglist);

};


// konstruktor MylogicSimulation - volanie konstruktora zakladnej triedy,
// vytvorenie uzlov schemy, vytvorenie logickych clenov,
// otvorenie logu SIM.LOG.
MyLogicSimulation::MyLogicSimulation() :
     log(NULL),
     WLogicSimulation("Logic Simulation", 1200.0),
     A1("A1"),
     A2("A2"),
     A("A"),
     B("B"),
     C("C"),
	 Y("Y"),
	 Int1("I1"),
	 Int2("I2"),
	 Int3("I3"),
	 Int4("I4"),
	 Int5("I5")

{
	new Nand3Gate(this, A,		Int1,	Int2,	Int3, 5, 10);  // 5 L->H ; 10 H->L 
															   // Aj tak si myslim ze je to naopak !
															   // Look at simulation output !
	new Nand3Gate(this, B,		Int2,	A1,		Int4, 5, 5);
	new Nand3Gate(this, C,		Int1,	A2,		Int5, 5, 5);
	new Nand3Gate(this, Int3,	Int4,	Int5,	Y,	  5, 5);
	new NotGate(this, A1,	Int1, 5, 5);
	new NotGate(this, A2,	Int2, 5, 5);

	ErrorCheck((log = fopen("SIM.LOG", "wt")) == NULL,
		 "Unable to create simulation logfile SIM.LOG.");
}

// metoda vprint() - vystup na obrazovku a do logu SIM.LOG
void MyLogicSimulation::vprint(const char *fmt, va_list arglist)
{
  vprintf(fmt, arglist);
  if (log) vfprintf(log, fmt, arglist);
}

// metoda update() obsahuje volania metod, ktore obnovuju stavy na vystupnych
// a vnutornych uzloch jednotlivych logickych clenov
void MyLogicSimulation::update()
{
  clock(A1, 300, 300, LOW);
  clock(A2, 600, 600, LOW);
  clock(A,	20,	 15,  LOW);
  clock(B,	45,  30,  LOW);
  clock(C,  100,  85,  LOW);

  WLogicContainer::update();
}

// inicializacia simulacie - naplanujeme priebehy logickych hodnot
// na vstupnych uzloch, nastavime sondy na uzly, ktore chceme sledovat.
void MyLogicSimulation::initSimulation() {
  setPin(A1, 0, LOW, TRUE);
  setPin(A1, 300, HIGH, TRUE);

  addProbe(&A1);
  addProbe(&A2);
  addProbe(NULL);
  addProbe(&A);
  addProbe(&B);
  addProbe(&C);
  addProbe(NULL);
  addProbe(&Y);
}


int main() {
  MyLogicSimulation sim;
//  sim.stepping( TRUE );
  sim.simulate();
  return 0;
}
