/* Zretazena volna pamat prvkov rovnakej dzlky
 * Marek DZURKO, 3.rocnik,3.kruzok,INFO/SI
 *
 * Data v pamati maju takuto strukturu :
 * ---------------------------------------------     ------------------
 * | nasledujuci | data | nsaledujuci | data| ...   ... | NULL | data |
 * ---------------------------------------------     ------------------
 *
 * Ako data som zvolil 5 cisel typu ELEMENT=int, ale do ziskanej pamate naci-
 * tavam retazec o primeranej dlzke. Ukazovatel na nasledujuci volny blok je
 * tiez typu ELEMENT.
 *
 * Funkcie : new()      - Vrati ukazovatel na volne miesto v pamati. Ak
 *                         v pamati uz nie je volny blok, vrati NULL.
 *           dispose(p) - Uvolni blok v pamati na ktory ukazuje p.
 *           empty()    - Vyprazdni(vymaze) celu pamat
 *           isempty()  - Ak este je v pamati nejaky volny blok, tak vrati
 *                         hodnotu 0, inac vrati 1.
 */

#include <stdio.h>
#include <sys/ioctl.h>

#ifdef NULL
#undef NULL
#endif

#define NULL (-1)			/* Definicia ukazovatela NULL */
#define ELEM_SIZE 5			/* Velkost dat (v elementoch) */
#define MAXSIZE (ELEM_SIZE+1)*10	/* Velkost pamate (v elementoch) */
#define POC_RETAZCOV 20			/* Pocet retazcov pre demo */

typedef int ELEMENT;			/* Definicia typu element */
typedef int MEMPTR;			/* Definicia typu ukazovatel na element */

ELEMENT mem[MAXSIZE]={0};		/* Deklaracia pamate */
MEMPTR first;				/* definicia ukazovatela na zaciatok ZVP */

/* Funkcia EMPTY vytvori zretazenu volnu pamat a vrati ukazovatel na prvu
 * volnu polozku
 */
MEMPTR empty()
{
	MEMPTR p;
	first=p=0;
	while (p+ELEM_SIZE+1<MAXSIZE-ELEM_SIZE) {
		mem[p]=p+ELEM_SIZE+1;
		p+=ELEM_SIZE+1;
	}
	mem[p]=NULL;
	return(first);
}

/* Funkcia ISEMPTY vrati 0 ak je uz zvp plna t.j. ak neexistuje dalsi volny
 * usek. Inak vrati 1.
 */
int isempty()
{
	return(first==NULL ? 1 : 0);
}

/* Funkcia NEW vrati ukazovatel na prvy volny usek v pamati. Ak taky neexistuje,
 * funkcia vrati NULL.
 */
MEMPTR new()
{
	MEMPTR p=first;
	if (first==NULL) return(NULL);
	first=mem[first];
	return(p);
}

/* Funkcia DISPOSE uvolni obsadeny usek zvp a zaradi ho do zoznamu zvp.
 */
void dispose(pos)
MEMPTR pos;
{
	mem[pos]=first;
	first=pos;
}

/* Funkcia GETCH nacita jeden znak z klavesnice (bez stlacenia Enter/Return)
 * a vrati ho.
 */
int getch()
{
	struct sgttyb sigold,signew;
	int c;
	ioctl(0,TIOCGETP,&sigold);	/* Uchovanie povodneho stavu */
	signew=sigold;
	signew.sg_flags &= ~ECHO;	/* Zakazanie vypisu znakov */
	signew.sg_flags |= CBREAK;	/* Zakazanie prerusenia CTRL-C */
	ioctl(0,TIOCSETP,&signew);
	c=getchar();			/* Nacitanie jedneho znaku */
	ioctl(0,TIOCSETP,&sigold);	/* Obnovenie povodneho stavu */
	return(c);
}

void main()
{
	MEMPTR a,p[POC_RETAZCOV];
	int n=0,i;
	empty();
	for(i=0;i<POC_RETAZCOV;i++) p[i]=NULL;
	do {
	/* Vypis volnych usekov ZVP */
		printf("Zaciatky volnych usekov pamate : ");
		for(a=first;a!=NULL;a=mem[a]) printf("%d, ",a);
	/* Zistenie ci je este nejaka voln pamat */
		printf("\b\b \b\n\nJe este volna pamat ?  %s\n\n",isempty()==1?"Nie":"Ano");
	/* Vypis obsahu pamate */
		printf("Retazce v pamati :\n");
		for(i=0;i<POC_RETAZCOV;i++) if (p[i]!=NULL) printf("%2d. usek c.%3d : %s\n",i,p[i],&mem[p[i]]);
	/* Vypis menu */
		printf("\n\n");
		printf("Tvoja volba : 1-vlozenie noveho retazca do pamate\n");
		printf("              2-uvolnenie pamate\n");
		printf("              3-vyprazdnenie pamate\n");
		printf("              q-koniec\n");
		switch(getch()) {
	/* Ziskanie polozky zo ZVP */
			case '1':	for(i=0;i<POC_RETAZCOV && p[i]!=NULL;i++) ;
					if (i==POC_RETAZCOV) {
						printf("V pamati je uz 20 retazcov !\n");
						break; }
					if ((n=new())==NULL) {
						printf("V pamati uz nie je miesto !\n");
						getch();
						break; }
					printf("Vloz retazec (max. 9 znakov) : ");
					scanf("%9s",&mem[p[i]=n]);
					getch(); /* ONLY FOR UNIX !!! */
					break;
	/* Uvolnenie polozky */
			case '2':	do {printf("Vloz cislo retazca : ");
						scanf("%d",&i);
					} while (i>=POC_RETAZCOV);
					if (p[i]==NULL) {
						printf("Retazec s tumto cislom neexistuje !\n");
						break; }
					dispose(p[i]);
					p[i]=NULL;
					getch(); /* ONLY FOR UNIX !!! */
					break;
	/* Uvolnenie celej ZVP */
			case '3':	empty();
					for(i=0;i<POC_RETAZCOV;i++) p[i]=NULL;
					break;
	/* Koniec prace */
			case 'q':	return;
		}
	} while(1);
}

