#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include "zvp.h"

/* funkcia zvpconstructor je konstruktorom ZVP s velkostou dlzka
   vrati zaporne vzatu aktualnu dlzku, ktoru sa pokusal alokovat,
   ak bol neuspesny, inak vrati kladnu aktualnu dlzku */

int zvpconstructor(struct zvp *z,int dlzka)
{
	unsigned int test=(unsigned int) -1;
	int i;
	double d;
	int di;

	/* nasl. 5 riadkov vypocita max dlzku ZVP s akou dokazeme pracovat */
	d=log((double)sizeof(struct elm))/log(2.0);
	di=(int)d;
	if (d-di) di++;
	di+=2;
	test>>=di;
	/* test je max dlzka ZVP */

	if (dlzka < 1) dlzka=1;
	if ((unsigned int) dlzka > test) dlzka=test;
	/* tu uz je dlzka vtesnana do max. hranic */

	if ((z->x = (struct elm*) malloc(sizeof(struct elm) * dlzka)) == NULL) return -dlzka;
	/* tu uz vieme, ze miesto na ZVP sa nam podarilo uspesne alokovat */

	z->lng = dlzka;
	z->ffree = 0;
	z->isfree = 1;
	
	/* inicializujeme smerniky */
	for ( i=0 ; i<(dlzka-1) ; ++i ) z->x[i].smernik = i+1;
	z->x[dlzka-1].smernik = -1;
	return dlzka;
}

/* zpvdestructor je destruktorom ZVP */

void zvpdestructor(struct zvp *z)
{
	free((void*)z->x);
}

/* funkcia zvpisempty vracia 1 ak su este volne alokacne jednotky v ZVP
   inak vrati 0 */

int zvpisempty(struct zvp *z)
{
	return z->isfree;
}

/* funkcia zvpnovy vyradi prvu jednotku ZVP a oznaci ju ako obsadenu a vrati
   smernik na tuto jednotku, alebo vrati -1 ak uz v ZVP nie je volna ziadna
   jednotka */

int zvpnovy(struct zvp *z)
{
	int kde,alloc=z->ffree;

	if (zvpisempty(z))
	{
		if ((kde=z->x[alloc].smernik) != -1) z->ffree=kde;
		else z->isfree=0; /* v tejto vetve sme uvolnili posl. jedn. */			
		z->x[alloc].smernik=z->lng; /* index za ZVP ozn. alok. jedn. */
		return alloc;
	}
	else return -1;
}

/* funkcia zvpzrus uvolni alokovanu jednotku a vrati ju na zaciatok ZVP,
   navratovou hodnotou je cislo jednotky, ktoru sme chceli uvolnit ak
   bol uspesny, inak vrati -2 ak bol pouzity neplatny index, alebo -1
   ak zadana jednotka uz bola v ZVP */

int zvpzrus(struct zvp *z,int i)
{
	if ((i<0)||(i>=z->lng)) return -2; /* neplatny index */
	if (z->x[i].smernik != z->lng) return -1; /* jednotka je v ZVP */
	else
	{
		if (zvpisempty(z)) /* ak ex. zoznam alok. j. pridaj na zac. */
		{
			z->x[i].smernik=z->ffree;
			z->ffree=i;
			return i;
		}
		else /* vytvor novy zoznam alokacnych jednotiek */
		{
			z->x[i].smernik=-1;
			z->ffree=i;
			z->isfree=1;
			return i;
		}
	}
}

/* funkcia zvpdputh vlozi prvok i do index-tej alokovanej jednotky */

void zvpdputh(struct zvp *z,int index,int i)
{
	z->x[index].hodnota = i;
	return;
}

/* funkcia zvpdgeth vrati hodnotu prvku index-tej jednotky ZVP */

int zvpdgeth(struct zvp *z,int index)
{
	return z->x[index].hodnota;
}

/* funkcia zvpputh vlozi prvok i do index-tej alokovanej jednotky,
   ak index ukazuje do ZVP vrati -1 a hodnotu nezapise */ 

int zvpputh(struct zvp *z,int index,int i)
{
	if (z->x[index].smernik != z->lng) return -1;
	zvpdputh(z,index,i);
	return 0;
}

/* funkcia zvpgeth vrati smernik na hodnotu v alokovanej jednotke s indexom i,
   ak je tato jednotka v ZVP, vrati NULL */

int *zvpgeth(struct zvp *z,int index)
{
	static int h;
	if (z->x[index].smernik != z->lng) return NULL;
	h = zvpdgeth(z,index);
	return &h;
}

/* funkcia zvpprintall vypise na stdout obsahy smernikov, kde alokovanu
   jednotku oznaci ako * a prvu jednotku v ZVP znakom !
   offs posuva cisla smernikov na vystupe */

void zvpprintall(struct zvp *z,int offs)
{
	int i,h;
	printf("Indexuje sa od %d, prvy prvok je oznaceny !\n",offs);
	for (i=0; i<z->lng; ++i)
	{
		if ((h=z->x[i].smernik)==z->lng) printf("* ");
		else {if (i == z->ffree) putchar('!');printf("%d ",h+offs);}
	}
	putchar('\n');
}
