/*
MENO  :	Marian Velicky
KRUZOK:	11

ZADANiE: Program implementuje STROM (morseova abeceda)

REPREZENTACiA:

T_NODE        -Polozka v strome(struktura, ktora obshuje odkaz na prvok
               v pravo a vlavo a ulozeny znak)
INT           -Navratove kody a pocet nacitanych prvkov
CHR           -Reprezentacia retazca


SIGNATURA:
   empty:                           -> T_NODE
   create_tree_from_file: T_NODE    -> INT
   write_to_tree: T_NODE, CHR, CHR  -> INT
   read_from_tree: T_NODE, CHR      -> CHR

POPIS CINNOSTI:
 Program nacita zo suboru strom z popisom kodov Morseovej abecedy
 a caka na vstupny retazec v Morseovej abecede, ktory nasledovne
 rozkoduje.


PRIKLAD:
Zadaj postupnost morseovych kodov :
... --- ...
sos

*/

#include <stdio.h>

#define	VST_SUBOR	"morse.txt"

typedef struct T_NODE { char znak[3] ; struct T_NODE *left , *right ; } T_NODE;

T_NODE *empty()
{
	T_NODE *tmp;
	tmp = (T_NODE *)malloc( sizeof(T_NODE) );
	tmp -> znak[0]=0x0;
	tmp -> left=tmp -> right=NULL;
	return tmp;
}

int create_tree_from_file( T_NODE *tree , char *file )
{
	FILE *fd;
	char znak[3] , morse[20];
	int n=0;
	if (( fd=fopen(file,"rt")) == NULL )
    {
		fprintf( stderr,"Can't open file %s for reading!\n",file );
		exit(-1);
	}
	while ( fscanf( fd,"%s%s",morse,znak ) == 2 )
    {
		write_to_tree( tree,morse,znak );
		n++;
	}
	fclose(fd);
	return n;
}

int write_to_tree( T_NODE *tree,char *code,char *znak )
{
	switch (*code) {
		case 0x0:	strcpy(tree->znak,znak);
					 return 1;
		case '.':	if (tree->left == NULL) tree->left=empty();
					write_to_tree(tree->left,++code,znak);
					break;
		case '-':	if (tree->right == NULL) tree->right=empty();
					write_to_tree(tree->right,++code,znak);
					break;
		default:	fprintf(stderr,"Zly znak v postupnosti !\n");
					return 0;
	}
	return 1;
}

char *read_from_tree(T_NODE *tree,char *code)
{
	switch (*code) {
		case 0x0:	return tree->znak;
		case '.':	if (tree->left==NULL) return NULL;
					else return read_from_tree(tree->left,++code);
		case '-':   if (tree->right==NULL) return NULL;
					else return read_from_tree(tree->right,++code);
		default:	fprintf(stderr,"Zly znak v postupnosti !\n");
					return NULL;
	}
}

void main()
{
	T_NODE *strom;
	char kod[80],slovo[20];
	char *c;

	strom=empty();

	printf("Nacitavam strom ...\n");
	printf("Bolo nacitanych %d znakov.\n",create_tree_from_file(strom,VST_SUBOR));
	printf("Zadaj postupnost morseovych kodov :\n");
	while (!feof(stdin))
    {
		fscanf(stdin,"%s",slovo);
		c=read_from_tree(strom,slovo);
		if (c==NULL) fprintf(stderr,"Znak s kodom %s sa v strome nenachadza !\n",slovo);
		else printf("%s",c);
    }
	printf("\n");
}

