/*Roman Dzamko
program simuluje HASH tabulku s vnutornym rozptylenim

Reprezentacia:
Tabulka je reprezentovana ako jednorozmerne pole riadkov
tabulky. Riadky su reprezentovane ako struktura:
kluc  - retazec znakov na zaklade ktoreho je zatriedovana
		do triedy ekvivalencie
elm   - integer predstavujuci hodnotu prvku, v praxi bud
		struktura alebo iny potrebny udaj


SIGNATURA: druhy  ELM, TABULKA, BOOL, KEY
		   operacie: empty                  --> TABULKA
					 insert TABULKA,ELM,KEY --> TABULKA
					 delete TABULKA,KEY     --> TABULKA
					 isin   TABULKA,KEY     --> BOOL
					 read   TABULKA,KEY     --> ELM

Navrh Implementacie
Nad tabulkou su naprogramovane operacie empty, delete, isin
insert.
empty - funkcia vytvori prazdnu tabulku
insert- umiestni prvok do tabulky na zaklade kluca
delete- vymaze prvok s danym klucom
isin  - vracia hodnotu True/Flase podla toho ci sa prvok
		s danym klucom v tabulke nachadza alebo nie
readelm - vracia hodnotu prvku s danym klucom

HASH funkcia na zaklade zadaneho kluca zatrieduje prvky do
	 jednotlivych tried ekvivalencie. Pocet tried ekvivalencie
	 je zhodny s poctom riadkov tabulky.
	 V nasom pripade je hash funkcia riesena tak, trieda
	 ekvivalencie (index v poli riadkov) je urcena suctom
	 kodov prvkov kluca (retazca), podeleneho poctom riadkov
	 tabulky. Index je zvysok po tomto deleni.

Kedze je to tabulka s vnutornym rozptylenim musi sa v pripade
toho ze riadok je uz obsadeny vykonat prerozdelenie REHASH.
Tato funkcia hlada najblizsi volny riadok ktory obsadi.
Vykonava sa postupne prehladavanie.


*/
#include<stdio.h>
#include<conio.h>
#include<stdlib.h>
#include<string.h>
#include<dos.h>

#define poc_riadkov 10
#define prazdny "<...>"
#define zmazany ".."
#define onesk 4000
#define true 1
#define false 0

typedef struct{
	char kluc[8];
	int  elm;
	} tab_elm;

int hash(char *a){
//funkcia prevadza rozptylenie podla kluca a
//v tabulke, vracia index riadku v tabulke
  int sum,i,pom,poc_zn;
  div_t vysl;

  poc_zn=strlen(a);
  if((poc_zn==0)||(poc_zn>8)) //testuje dlzku kluca
	return(-1);
  sum=0;
  for(i=0;i<(poc_zn); i++){   //funkcia scituje
	pom=(int)*(a+i);          //ascii hodnoty
    sum = sum+pom;            //znakov kluca
  }//for
  vysl=div(sum,poc_riadkov);  //vysledna adresa
  return(vysl.rem);           //suma delena poctom
}//hash                       //riadkov

int rehash(char *a, tab_elm *tab,int ins){
//funkcia vykonava prerozdelenie pri uzavretom rozptyleni
//teda ak je riadok v danej triede ekvivalencie obsadeny
//hlada najblizsi volny riadok a vrati jeho adresu
  int index,i=0;

  index = hash(a); //zisti triedu ekvivalencie
  if(index==-1)
    return(-1);
  while(((strcmp(tab[index].kluc,a)!=0) && //ak nasiel dany kluc
	(strcmp(tab[index].kluc,prazdny)!=0)) //prazdny riadok
	||((strcmp(tab[index].kluc,zmazany)==0)&&(ins==true))){
	if((index)==(poc_riadkov-1))//ak je posledny riadok
	  index=0;                  //nasledujuci nulty riadok
    else {
      index++;                  //inak riadok plus 1
	  if(i++==poc_riadkov)      //presiel uz vsetky riadky??
	return(-1);
	}//else
  }//while
  return(index);
}//rehash

int insert(tab_elm prvok, tab_elm *tab){
//funkcia vykona pridanie prvku do tabulky
//podla daneho kluca, v pripade uspechu vracia 0
//inak -1
  int index;
  if((index=rehash(prvok.kluc, tab, true))==-1){  //vyber adresu
    printf("\nTabulka je alebo plna alebo");//ak nenajde
    printf(" kluc bol chybne zadany");      //volnu adresu
    delay(onesk);
	return(-1);
  }//if..                            //inak
  tab[index].elm=prvok.elm;          //zapis hodnotu prvoku
  strcpy(tab[index].kluc,prvok.kluc);//zapis kluc do tabulky
  return(0);
}//insert

int isin(char *a, tab_elm *tab){
//funkcia vracia hodnotu true ak sa prvok v tabulke
//nachadza, false ak sa v tabulke nenachadza
  int index=rehash(a, tab, false);          //zisti adresu
  if((index==-1)||(strcmp(tab[index].kluc,prazdny)==0)){
    printf("\n v tabulke sa nenachadza");
    delay(onesk);
    return(false);
  }//if
  else {                  //ak sa tam nachadza vypis
	return(true);
  }//else
}//isin

void delete(char *a, tab_elm *tab){
//funkcia vymaze prvok z tabulky

  int index=rehash(a, tab, false);   //najdi adresu
  if(index==-1){
	printf("\nkluc bol chybne zadany alebo sa v");
	printf(" tabulke nenachadza");
	delay(onesk);
	return;
  }//if
  else{
	  if(strcmp(tab[index].kluc,a)==0){
	strcpy(tab[index].kluc,zmazany);

	  }//if
	  else{
	printf("\nkluc sa v tabulke nenachadza");
	delay(onesk);
	  }

  return;
  }//else
}//delete

void empty(tab_elm *tab){
//funkcia vykonava vytvorenie prazdnej tabulky
//klucove slova naplni vyrazom prazdny
  int i;
  for(i=0; i<poc_riadkov; i++){
	strcpy(tab[i].kluc,prazdny);//klucove slova napln prazdny
	tab[i].elm=0;               //hodnoty prvkov napln 0
  }//for
}//empty

int readelm(char *a, tab_elm *tab){
//funkcia vrati hodnotu prvku s danym klucom
  int index;
  if(isin(a,tab)!=true)
	return (-1);
  index=rehash(a, tab, false);
  return(tab[index].elm);
}



void main(void){
 char kluc[8];
 int i,j=true,key,vytv=false;
 tab_elm tabulka[poc_riadkov], prvok;

 while(j==true){
   clrscr();
   if(vytv==true){  //vypis tabulky
	 printf("\n KLUC       Ascii hodnota klavesi");
	 printf("\n-----------------------------------");
	 for(i=0; i<poc_riadkov; i++){
	   printf("\n %s",tabulka[i].kluc);
	   gotoxy(15,wherey());
	   printf("%d",tabulka[i].elm);
	 }//for
   }//if
   printf("\n\n e-empty i-insert d-delete s-isin r-read k-koniec\n");
   key=getche(); //operacie menu
   fflush (stdin);
   switch(key){
	 case 'e' : { empty(tabulka);  //vytvori prazdnu tabulku
				  vytv=true;
				  break;
				}

	 case 'i' : { if(vytv==false) break;
				  printf("\n zadaj kluc (max. 7 znakov) :");
				  gets(prvok.kluc);    //nacita kluc
				  fflush(stdin);
				  printf("\n zadaj hodnotu prvku (cislo) :");
				  prvok.elm=getche();
				  fflush(stdin);
				  if(insert(prvok, tabulka)==-1)
				  printf("\PRVOK NEBOL VSUNUTY");
				  break;
				}

	 case 'd' : { if(vytv==false) break;//nacita kluc
				  printf("\n zadaj kluc (max 7 znakov) :");
				  gets(kluc);
				  fflush(stdin);
				  delete(kluc, tabulka); //zmaz dany kluc
				  break;
				  }

	 case 's' : { if(vytv==false) break;
				  printf("\n zadaj kluc (max 7 znakov) :");
				  gets(kluc);  //nacitaj kluc
				  fflush(stdin);
				  if(isin(kluc,tabulka)==true){  //testuj ci sa tam nachadza
						printf("prvok  sa v tabulke nachadza");
						delay(onesk);
				  }
				  break;
				}

	 case 'r' : { if(vytv==false)
					break;
				  printf("\n zadaj kluc (max 7 znakov) :");
				  gets(kluc);
				  fflush(stdin);
				  if((i=readelm(kluc,tabulka))==-1){
					printf("\nprvok sa v tabulke nenachadza");
					delay(onesk);
				  }
				  else {
					printf("\n hodnnota je %d",i);
					delay(onesk);
				  }
				  break;
				}
	 case 'k' : { j=false;
		  break;
		}

	 default  : break;
   }//switch

 }//while

}//main
