// Jednosmerny, Obojsmerny a kruhovy zoznam implementovany v C++
// (c) 1995 Radovan Semancik

#include <iostream.h>

// virtualna trieda TElement, univerzalny prvok zoznamu bez hodnoty
// obsahuje nedefinovanu funkciu print(), ktoru predufinuju nasledovnici

class TElement
{
protected:
	TElement *next;    // ukazatel na dalsi prvok
        TElement *prev;    // ukazatel na predchadzajuci prvok
public:
	TElement() {next=(TElement*)NULL; prev=(TElement*)NULL;}; // konstruktor
	TElement* getNext() {return next;};
	TElement* getPrev() {return prev;};
	void setNext(TElement* elm) {next=elm;};
	void setPrev(TElement* elm) {prev=elm;};
	virtual void print() = 0;
};

// Jednosmerny zoznam, zakladna trieda pre vsetky osotatne zoznamy

class TList
{
protected:
	TElement *head;  // ukazatel na zaciatok
	TElement *active;  // ukazatel na koniec
public:
	TList() {head=(TElement*)NULL; active=(TElement*)NULL;}; // konstruktor bez parametra
	TList(TElement* elm) {head=elm; active=elm; elm->setNext((TElement*)NULL);}; // konstruktor s naplnenim prveho prvku zoznamu
	virtual void first() {active=head;};
	virtual void succ() {if (active!=NULL) active=active->getNext();};
	void postDelete();
	void deleteFirst() {if (head!=NULL) head=head->getNext();};
	TElement* copy() {return active;};
	TElement* copyFirst() {return head;};
	void postInsert(TElement* elm) {elm->setNext(active->getNext()); active->setNext(elm);};
	void insertFirst(TElement* elm) {elm->setNext(head); head=elm;};
	void actualize(TElement* elm) {active=elm;};
	int isActive() {return (active!=NULL);};
	virtual void print();
};

// Kruhovy zoznam ... naslednik triedy TList
class TCList : public TList
{
public:
	virtual void succ();
};

// Obojsmerny zoznam, naslednik triedy TList
class TBiList : public TList
{
protected:
	TElement *tail;  // koniec zoznamu, pridany prvok k triede TList
public:
	TBiList() : TList() {tail=NULL;}; // konstruktory .. volaju predchodcu z triedy TList
	TBiList(TElement *elm) : TList(elm) {tail=elm; elm->setPrev(NULL);};
	virtual void pred() {if (active!=NULL) active=active->getPrev();};
	void last() {active=tail;};
	void postDelete();
	void preDelete();
	void deleteFirst();
	void deleteLast();
	TElement* copyLast() {return tail;};
	void postInsert(TElement* elm);
	void preInsert(TElement* elm);
	void insertFirst(TElement* elm);
	void insertLast(TElement* elm);
};

// Template class ... trieda s vseobecnym typom, implementacia prvku zoznamu
// ktora moze pouzivat vsetky zakladne typy a aj vsetky uzivatelske ktore
// maju definovany vystup na stream

template <class T>
class TElmVal : public TElement
{
protected:
	T value; // hodnota prvku, vseobecny typ
public:
	TElmVal(T val) : TElement() {value=val;}; // konstruktor
	T getValue() {return value;};
	void setValue(T val) {value=val;};
	virtual void print() {cout << value;}; // vystup prvku na stream
};

// Function implementataion .. implementacia vonkajsich funkcii triedy TList
// class TList
void TList::postDelete()
{
	if (active!=NULL && active->getNext()!=NULL) {
		active->setNext((active->getNext())->getNext());
	}
}

void TList::print()
{
	TElement* elm;
	int i;

	cout << "* START of list\n";
	for(elm=head,i=0; elm!=NULL; elm=elm->getNext(), i++) {
		cout <<"> ELEMENT " << i << ": ";
		elm->print();
		if (elm==active) cout << " <<ACTIVE>>";
		cout << '\n';
	}
	cout << "* END of list\n\n";
}

// class TCList .... implementacia funkcii triedy TCList - kruhovy zoznam
void TCList::succ()
{
	TList::succ();
	if (active==NULL) active=head;
}

// class TBiList ... implementacia vonkajsich funkcii triedy TBiList - obojsmerny zoznam
void TBiList::postDelete()
{
	if (active!=NULL) {
		((active->getNext())->getNext())->setPrev(active);
		active->setNext((active->getNext())->getNext());
	}
}

void TBiList::preDelete()
{
	if ((active->getPrev())->getPrev()==NULL) head=active;
	else ((active->getPrev())->getPrev())->setNext(active);
	active->setPrev((active->getPrev())->getPrev());
}

void TBiList::deleteFirst()
{
	if (head->getNext() == NULL) {
		tail=NULL;
		head=NULL;
	} else {
		(head->getNext())->setPrev(NULL);
		head=head->getNext();
	}
}

void TBiList::deleteLast()
{
	if (tail->getPrev() == NULL) {
		tail=NULL;
		head=NULL;
	} else {
		(tail->getPrev())->setNext(NULL);
		tail=tail->getPrev();
	}
}

void TBiList::postInsert(TElement* elm) 
{
	if (active->getNext()==NULL) tail=elm;
	else (active->getNext())->setPrev(elm);
	elm->setPrev(active);
	elm->setNext(active->getNext()); 
	active->setNext(elm);
}

void TBiList::preInsert(TElement* elm)
{
	if (active->getPrev()==NULL) head=elm;
	else (active->getPrev())->setNext(elm);
	elm->setNext(active);
	elm->setPrev(active->getPrev());
	active->setPrev(elm);
}

void TBiList::insertFirst(TElement* elm)
{
	if (head!=NULL) head->setPrev(elm);
	else tail=elm;
	elm->setNext(head);
	elm->setPrev(NULL);
	head=elm;
}

void TBiList::insertLast(TElement* elm)
{
	if (tail!=NULL) tail->setNext(elm);
	else head=elm;
	elm->setPrev(tail);
	elm->setNext(NULL);
	tail=elm;
}

// testovacia funkcia

int main()
{
	TBiList list;
	TElmVal<int> ei1(1);
	TElmVal<int> ei2(2);
	TElmVal<double> ed(3.1415);
	TElmVal<char> eca('a');
	TElmVal<char*> es1("bla bla bla");

	cout << "insertFirst:\n";
	list.insertFirst(&ei1);
	list.print();
	cout << "inserFirst, actualize:\n";
	list.insertFirst(&ei2);
	list.actualize(&ei1);
	list.print();
	cout << "insertFirst:\n";
	list.insertFirst(&eca);
	list.print();
	cout << "postInsert:\n";
	list.postInsert(&es1);
	list.print();
	cout << "Gou actual element: ";
	list.copy()->print();
	cout << '\n';
	cout << "Got first element: ";
	list.copyFirst()->print();
	cout << '\n';
	cout << "Got last element: ";
	list.copyLast()->print();
	cout << "\nsucc:\n";
	list.succ();
	list.print();
	cout << "first:\n";
	list.first();
	list.print();
	cout << "postDelete:\n";
	list.postDelete();
	list.print();
	cout << "succ:\n";
	list.succ();
	list.print();
	cout << "preDelete:\n";
	list.preDelete();
	list.print();
	cout << "preInsert:\n";
	list.preInsert(&eca);
	list.print();
	cout << "insertLast:\n";
	list.insertLast(&ed);
	list.print();
	cout << "deleteFirst:\n";
	list.deleteFirst();
	list.print();
	cout << "deleteLast:\n";
	list.deleteLast();
	list.print();
}

