/*
 *  tab.c - Implementacia tabulky
 *  Erik Dulak  kr.15
 *
 *	Telefonny zoznam
 *	meno = kluc
 *	triedy tabulky = kazde zaciatocne pismeno - vlastna trieda
 *			=> pocet tried = POC_ABC
*/

#include <stdio.h>
#include <malloc.h>
#include <string.h>

#define MEN_LEN 16
#define TEL_LEN 12
#define POC_ABC 26

/*	def.typov pre tabulku	*/
typedef struct pol *pol_uk;

typedef struct pol {
  char meno[MEN_LEN];
  char telefon[TEL_LEN];
  pol_uk nxt_puk;
} pol_tp;

typedef struct {
  pol_uk abc_tr[POC_ABC];
} tab_tp;  

/*	def. typu pre spatne hlasenie z funkcie read	*/
typedef struct pol_zoz *nxt_z;
typedef struct pol_zoz {
 pol_uk pl;
 nxt_z zoz_nxt;
} pol_zoz;


/* hlavicky funkcii */
void print_tab(tab_tp *tab);
void print_rvysl(pol_zoz *zoz);
void zrus_vysl(nxt_z zoz_vysl);

/* empty: zmazanie tabulky */
int empty(tab_tp *tab)
{
 int i,poc_z;
 pol_uk ptmp,ptmp_nxt;

 poc_z = 0;
 for (i=0;i<POC_ABC;i++) {
	if (tab->abc_tr[i]!=NULL) {
	   ptmp=tab->abc_tr[i];
	   while(ptmp!=NULL) {
	      ptmp_nxt=ptmp->nxt_puk;
	      poc_z++;free(ptmp);
	      ptmp=ptmp_nxt;
	   }
	   tab->abc_tr[i]=NULL;
	}
 }
 return poc_z;
}

/* insert: vlozenie prvku do tabulky */
int insert(tab_tp *tab)
{
   static char buf[MEN_LEN];
   static char t_ok[]="OK";
   pol_uk polin,pol_tmp,pol_tmprv;
   int res_cmp;

   /* vyhradime pamat, nacitame a upravime data */
   polin = (pol_uk) malloc(sizeof(pol_tp));
   printf("Meno:");gets(buf);strncpy(polin->meno,buf,MEN_LEN);
   printf("Telefon:");gets(buf);
   if (strlen(buf)>=TEL_LEN) {
      printf("Tel. cislo maximalne %d pismen!\n",TEL_LEN);
      free(polin);return -1;
   }
   strncpy(polin->telefon,buf,TEL_LEN);
   
   /* najdeme volne miesto v tabulke. */
   if ((pol_tmp = tab->abc_tr[(polin->meno[0])-'a'])==NULL) {
      polin->nxt_puk = NULL;
      tab->abc_tr[(polin->meno[0])-'a'] = polin;
      puts(t_ok);return 1;
   }
   pol_tmprv = NULL;
   while (pol_tmp!=NULL) {
      res_cmp = strcasecmp(pol_tmp->meno,polin->meno);
      if (res_cmp>0){
	 polin->nxt_puk = pol_tmp;
	 if (pol_tmprv == NULL) tab->abc_tr[(polin->meno[0])-'a']=polin;
	 else pol_tmprv->nxt_puk = polin;
	 puts(t_ok);return 1;
      }
      else if(res_cmp<0){
	 if (pol_tmp->nxt_puk==NULL){
	    polin->nxt_puk = NULL;pol_tmp->nxt_puk = polin;
	    puts(t_ok);return 1;
	 } else{ pol_tmprv = pol_tmp;pol_tmp = pol_tmp->nxt_puk; }
      }
      else {
	 printf("Polozka s tymto menom uz existuje!\n");
	 return -1;
      }
   }
   return 1;
}

/* read_t: Najde v tabulke prvky vyhovujuce klucu (retazec)
 *         vyhoviet klucu == obsahovat >podretazec< key.
 *         ukazovatele na ne preda v zretazenom zozname
*/
nxt_z read_t(char *kluc,tab_tp *tab){
   int i;
   pol_uk pol_tmp;
   nxt_z zozn,z_tmp;

   zozn=z_tmp=NULL;
   for (i=0;i<POC_ABC;i++){
      pol_tmp = tab->abc_tr[i];
      while (pol_tmp!=NULL){
	 if (strstr(pol_tmp->meno,kluc)!=NULL){
	    if ((z_tmp = (nxt_z) malloc (sizeof(pol_zoz)))==NULL){
	       printf("Chyba pri alok.pamate");return NULL;
	    }
	    z_tmp->pl = pol_tmp;
	    z_tmp->zoz_nxt = zozn;
	    zozn = z_tmp;
	 }
         pol_tmp = pol_tmp->nxt_puk;
      }
   }
   return zozn;
}


/* delete_t: Maze vsetky zaznamy s danym klucom(retazec)
 *           klucu vyhovuju vsetky mena obsahujuce ako podretazec kluc
 *           vracia pocet zmazanych poloziek
*/
int delete_t(tab_tp *tab){
   pol_uk pol_tmp,pol_prv;
   char kluc[MEN_LEN],tin[3];
   int i,poc;
   
   printf("Mazanie Tabulky\nKluc:");gets(kluc);poc=0;
   for (i=0;i<POC_ABC;i++){
      pol_tmp = tab->abc_tr[i];
      pol_prv = NULL;
      while (pol_tmp != NULL){
	 if (strstr(pol_tmp->meno,kluc)==NULL){
	    pol_prv=pol_tmp;pol_tmp = pol_tmp->nxt_puk;
	 } else{
	    if (pol_prv!=NULL){
	       pol_prv->nxt_puk = pol_tmp->nxt_puk;free(pol_tmp);pol_tmp = pol_prv->nxt_puk;
	    } else{
	       tab->abc_tr[i] = pol_tmp->nxt_puk;free(pol_tmp);
	       pol_tmp = tab->abc_tr[i];
	    }
	    poc++;
	 }
      }
   }
   return poc;
}

/*  search - test ci sa v tabulke nachadza prvok s danym klucom
 *         vracia 0 ak nie, inak nenulu hodnotu
*/
int search(tab_tp *tab){
   char kluc[MEN_LEN];
   int i;
   pol_uk pol_tmp;

   printf("Test Kluca:");gets(kluc);
   for (i=0;i<POC_ABC;i++){
      pol_tmp = tab->abc_tr[i];
      while(pol_tmp!=NULL){
	 if (strstr(pol_tmp->meno,kluc)!=NULL) return 1;
	 pol_tmp = pol_tmp->nxt_puk;
      }
   }
   return 0;
}

/*  isequ - zisti ci kluce su ekvivalentne
 *          (ekvival = ak funkcia read_t spristupni rovnake prvky.
 *	     vracia: 1 ak ano, 0 ak nie.
*/
int isequ(tab_tp *tab){
   nxt_z zozk1,zozk2;
   nxt_z zt1,zt2;
   char kluc1[MEN_LEN],kluc2[MEN_LEN];
   int rez;

   printf("Kluc1:");gets(kluc1);
   printf("Kluc2:");gets(kluc2);

   zozk1 = read_t(kluc1,tab);zozk2 = read_t(kluc2,tab);
   zt1 = zozk1; zt2 =zozk2;
   while ((zt1!=NULL) && (zt2!=NULL)){
      if (zt1->pl!=zt2->pl) break;
      zt1 = zt1->zoz_nxt;zt2=zt2->zoz_nxt;
   }
   if (zt1!=zt2) rez=0; else rez=1;
   zrus_vysl(zozk1);zrus_vysl(zozk2);
   return(rez);
}


/*  MAIN */
void main() {
   tab_tp tab;
   nxt_z kuk;
   int i;
   char tin[3];
   char kluc[MEN_LEN];
   static char t_hlv[]="Telefony zoznam v 95.12.1\t<?>=help\njulo mlich";
   static char t_hlp[]="<e>=empty\t<i>=insert\t<r>=read\t<d>=delete\t<s>=search\n<I>=isequ\t<v>=vypis TZ\t<k>=koniec";

   for (i=0;i<POC_ABC;i++) tab.abc_tr[i]=NULL;
   puts(t_hlv);
   putchar('>');
   while(1){
    do gets(tin); while(tin[0]=='\0');
    if (strlen(tin)!=1) { printf("Len 1 pismeno!\n>");continue;}
    switch (tin[0]){
     case 'e':printf("Zmazane:%d\n",empty(&tab));break;
     case 'i':insert(&tab);break;
     case 'r':printf("Citanie tabulky\nkluc:");
       print_rvysl(kuk = read_t(gets(kluc),&tab));zrus_vysl(kuk);break;
     case 'd':printf("Zmazane:%d\n",delete_t(&tab));break;
     case 'I':if (isequ(&tab)) printf("kluce su ekvivalentne.\n");else printf("kluce nie su ekvivalentne.\n");break;
     case 's':if (!search(&tab)) printf("ne");puts("existuje prvok k danemu klucu.");break;
     case 'v':print_tab(&tab);break;
     case '?':puts(t_hlp);break;
     case 'k':return;
     default:puts("Nepoznam taku funkciu!");
    }
    putchar('>');
   }

}


/* vypis telefonneho zoznamu (~ kluc=vsetky zaznamy) */
void print_tab(tab_tp *tab)
{
  int i;
  pol_uk pol_ut;

  for(i=0;i<POC_ABC;i++) {
	if (tab->abc_tr[i]==NULL) continue;
	printf("--- Trieda '%c' ---\n",(char) i+'a');
	pol_ut = tab->abc_tr[i];
	while(pol_ut!=NULL){
	   printf("%s\t\ttel:%s\n",pol_ut->meno,pol_ut->telefon);
	   pol_ut = pol_ut->nxt_puk;
	}
  }
}


/* print_rvysl - vypise polozky spristupnene funkciou read_t */
void print_rvysl(pol_zoz *zoz){
   nxt_z zoz_tmp;

   if ((zoz_tmp = zoz)==NULL){ puts("Nic s rovnakym klucom.");return;}
   while (zoz_tmp!=NULL){
      printf("%s\t\ttel:%s\n",zoz_tmp->pl->meno,zoz_tmp->pl->telefon);
      zoz_tmp = zoz_tmp->zoz_nxt;
   }
}

/* funkcia na odalokovanie vysledku read_t */
void zrus_vysl(nxt_z zoz_vysl){
   nxt_z z_tmp,zt;

   z_tmp = zoz_vysl;
   while (z_tmp!=NULL) { zt = z_tmp->zoz_nxt;free(z_tmp);z_tmp=zt; }
}

