/***********************************************\
|*  sorts.c   Triediace algoritmy              *|
|*  Marian Varga, 3.INF8, zim.sem. 1997/8      *|
|*  Program.techniky, KIVT FEI STU Bratislava  *|
\***********************************************/

/*
V tomto programe som implementoval tri triediace algoritmy:

1. QuickSort - funkcia quicksort(), pouziva swapelm()
   Pouzil som rekurzivnu verziu algoritmu. Z triedenej postupnosti sa
   vyberie prostredny prvok za pivota x. Prehladavanim z obidvoch koncov
   postupnosti sa vyhladaju indexy i, j, i<=j, ze plati
   a[i].key >= x.key >= a[j].key. Take prvky a[i], a[j] sa vymenia
   (swapelm()), indexy i a j sa posunu o 1 smerom oproti sebe a proces
   pokracuje, kym i <= j.
   Tym sa postupnost rozdeli na dve casti:
   Lava cast: pre 0 <= k <= j plati a[k].key <= x.key.
   Prava cast: pre i <= k <= n-1 plati a[k].key >= x.key.
   Teraz na utriedenie postupnosti 0..n-1 staci izolovane utriedit
   lavu a pravu cast. Ak cast obsahuje iba 1 prvok, je utriedena,
   inak pre nu rekurzivne vyvolame rovnaky algoritmus triedenia.
   PRIKLAD:
   Pred rozdelenim:
    16 31 26 1 7 22 6 13 13 7
   pivot = 22
    16 *31* 26 1 7 22 6 13 13 *7*
    16 7 *26* 1 7 22 6 13 *13* 31
    16 7 13 1 7 *22* 6 *13* 26 31
    16 7 13 1 7 13 *6* 22 26 31
   Po rozdeleni (i=7, j=6):
    16 7 13 1 7 13 6 22 26 31
   Lava cast:  16 7 13 1 7 13 6
   Prava cast:  22 26 31

2. HeapSort - funkcia heapsort(), pouziva makeheap(), swapelm()
   Algoritmus je zalozeny na rychlom vyhladavani maximalneho prvku
   mnoziny reprezentovanej zvlastnou strukturou "haldou":
   Usek a[l..r] je HALDA (heap) prave vtedy, ked
   pre kazde i, l <= i <= (r-1)/2, plati a[i] >= max { a[i*2+1], a[i*2+2] }.
   Prvky pola tvoria vlastne vrcholy binarneho stromu s korenom na
   zaciatku pola. Rodic a[i] je vzdy vacsi alebo rovny svojim potomkom
   a[i*2+1], a[i*2+2], ak existuju.
   Vyuziva sa funkcia makeheap(), ktora rozsiri haldu v poli o 1 prvok
   smerom dolava, t.j. ak a[l+1]..a[r] tvoria haldu, po vykonani
   makeheap() bude halda a[l]..a[r]. Zacina sa z a[l], porovna sa
   s maximom jeho deti a v pripade, ze nie je od neho vacsi alebo rovny,
   vymenia sa. V pripade tejto vymeny je potrebne upravit aj haldu
   zacinajucu tym zmenenym dietatom. Tak sa pokracuje, az kym sa
   nesplnia podmienky v definicii haldy.
   Triedenie sa vykonava v dvoch zakladnych krokoch:
   1.  Postupne vytvorenie haldy v celom poli: V lubovolnom
   poli a[0..n-1] prvky a[n/2]..a[n-1] tvoria haldu a tu treba dalej
   po jednom prvku rozsirovat dolava pomocou makeheap().
   2.  Z vlastnosti haldy vyplyva, ze ak a[0]..a[r] tvoria haldu,
   potom a[0] je maximalny prvok postupnosti a[0]..a[r]. Tento sa vymeni
   s a[r] (swapelm()). Postupnost a[1]..a[r-1] tvori haldu. Zmensime r
   o 1, zavolame heapsort() a na zaciatku pola vznikne opat halda, ale
   o 1 prvok kratsia. Takto pre r == n-1,...1 tvorime od konca pola
   usporiadanu postupnost.

3. InsertSort - funkcia insertsort()
   Kvadraticky triediaci algoritmus vykonavany v dvoch vnorenych cykloch.
   Vonkajsi cyklus predlzuje i == 1,...n dlzku useku na zaciatku pola,
   ktory je uz usporiadany.
   Vnutorny cyklus vklada prvok a[i] do utriedeneho useku, cim sa ten
   predlzi o 1. Prvok x, povodne ulozeny v a[i], porovnava s prvkami
   a[j] pre j == i-1,i-2,... az po prvok a[j].k <= x.k alebo zaciatok
   pola. Kazdy "nevhodny" prvok (a[j].k > x.k) posunie o miesto doprava.
   Tym sa vytvori miesto pre vlozenie x do a[j+1], kde j je prve
   najdene a[j].k <= x.k alebo -1 (lavy okraj pola), ak take nebolo
   najdene.


*/


#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <time.h>

int verbose;  /* Ci sa pozaduju kontrolne vypisy */

typedef struct elm {
  int key;
} elm;

void swapelm(elm *a, elm *b)
{ elm t = *a;  *a = *b;  *b = t; }

void generarray(elm a[], int n)
{
  int i, nn;

  nn=n*n/3;
  for (i = 0; i < n; i++)
    a[i].key = nn<0 ? rand() : rand() % nn;
}

/* Skontroluj, ci pole a[] dlzky n je usporiadane */
int sorttest(elm a[], int n)
{
  int i;

  for (i = 1; i < n; i++)
    if (a[i].key < a[i-1].key)
      return 0;
  return 1;
}


void printarray(elm a[], int l, int r)
{
  int i;

  printf(" ");
  for (i = l; i <= r; i++)
    printf("%d ", a[i]);
}


/****************************** QUICK-SORT *******************************/
void quicksort(elm a[], int n)
{
  int i, j;
  elm x;

  i = 0;  j = n-1;
  x = a[n/2];

  /*
     spracuj pole a[0..n-1] tak, ze bude platit:
     a[k].key <= x.key  pre k == 1,...i-1
     a[k].key >= x.key  pre k == j+1,...n-1
  */

  if(verbose){  printf("Pred rozdelenim:\n");  printarray(a,0,j);}

  for (;;) {
    while (a[i].key < x.key)  i++;
    while (a[j].key > x.key)  j--;
    if (i <= j) {
      swapelm(a+i, a+j);  i++;  j--;
    }
    else
      break;
  }

  if(verbose){  printf("\nPo rozdeleni (pivot=%d,i=%d,j=%d):\n", x.key,i,j); printarray(a,0,n-1); printf("\n");}

  if (0 < j)  {
    if(verbose){  printf("Lava cast: ");  printarray(a,0,j);  getchar();}
    quicksort(a, j+1);
  }
  if (i < n-1) {
    if(verbose){  printf("Prava cast: ");  printarray(a,i,n-1);  getchar();}
    quicksort(a+i, n-i);
  }
}



/****************************** HEAP-SORT ********************************/
/*
*/

/* za predpokladu, ze a[l+1..r] je halda, urob haldou a[l..r] */
void makeheap(elm a[], int l, int r)
{
  int i, j;
  elm x;

  i = l;  j = i*2+1;  x = a[l];
  while (j <= r) {
    /* nastav j na vacsie dieta rodica i */
    if (j < r && a[j].key < a[j+1].key)
      j++;
    /* skontroluj, ci este halda nie je v poriadku */
    if (x.key >= a[j].key)
      break;
    a[i] = a[j];  i = j;  j = i*2+1;
  }
  a[i] = x;
}

void heapsort(elm a[], int n)
{
  int l, r;

  l = n/2;  r = n-1;
  /*
     l == n/2, r == n-1, (r-1)/2 == (n-2)/2 == n/2 - 1,
     teda a[l..r] tvori trivialnu haldu
  */

  if(verbose){  printf("Zaciatocny stav:\n"); printarray(a,0,l-1); printf("|"); printarray(a,l,r); printf("\nTvorba haldy:\n");}

  /* rozsir haldu smerom dolava na cele triedene pole */
  while (l--) {
    makeheap(a, l, r);
    if(verbose){  printarray(a,0,l-1); printf("|"); printarray(a,l,r);  getchar();}
  }

  if(verbose){  printf("Vyberanie z haldy:\n");}

  /* postupne vyberaj maximalne prvky a odzadu tvor usporiadane pole */
  while (r) {
    /* najvacsi prvok useku a[0..r], cize a[0], presun na a[r] */
    swapelm(a, a+r);
    /* skrat usek a[0..r] sprava a vznikne halda az na prvok a[0] */
    r--;
    makeheap(a, 0, r);
    if(verbose){  printarray(a,0,r); printf("|"); printarray(a,r+1,n-1);   getchar();}
  }
}


/*************************** INSERT-SORT ******************************/
void insertsort(elm a[], int n)
{
  int i, j;
  elm x;

  /* i je dlzka (od zaciatku pola) uz utriedenej casti pola */
  for (i = 1; i < n; i++) {
    x = a[i];
    /* vloz x */
    for (j = i-1; j >= 0 && x.key < a[j].key; j--)
      /* a[j] sa pomkne doprava, lebo je vacsie ako vkladane x */
      a[j+1] = a[j];
    a[j+1] = x;  /* x sa vlozi za prvok, ktory nie je vacsi ako x */
    if(verbose){  printf("Vlozene: %d na index %d\n", x.key, j+1);
	  printarray(a,0,i); printf("|"); printarray(a,i+1,n-1); getchar(); }
  }
}


#define MAXN 15000
elm my_a[MAXN];
int  my_n;


void main(void)
{
  char s[100], c;
  void (* sort)(elm [],int);
  clock_t t1, t2;

  do {
    printf("\n\n\n");
    printf("SORTS - program demonstrujuci usporaduvacie algoritmy\n");
    printf("~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n");
    printf("(Q)uickSort-rekurzivny\n");
    printf("(H)eapSort\n");
    printf("(I)nsertSort\n");
    printf("(K)oniec programu\n");
    printf("Vyberte si algorimus: ");  scanf("%s", s);
    sort = NULL;
    switch (c = toupper(*s)) {
      case 'H': sort = heapsort;  break;
      case 'Q': sort = quicksort;  break;
      case 'I': sort = insertsort;  break;
      case 'K':	break;
      default:	printf("'%c' --> nerozumiem!\n", c);
    }
    if (sort) {
	do {
	  printf("Dlzka pola (n): ");  scanf("%d", &my_n);
	  if (my_n < 1 || my_n > MAXN) {
	    printf("Povolene n je 1 <= n <= %d\n", MAXN);
	    my_n=0;
	  }
	} while (!my_n);
	printf("Mam zobrazovat priebeh triedenia? (A/N) ");  scanf("%s", s); getchar();
	verbose = (toupper(*s) == 'A');
	generarray(my_a, my_n);
	if(verbose){ printarray(my_a, 0, my_n-1); printf("\n"); }
	printf("Pole %sje usporiadane.\n", sorttest(my_a, my_n)?"":"nie ");
	t1=clock();
	sort(my_a, my_n);
	t2=clock();
	printf("Cas: %0.1f s\n", (float)(t2-t1)/CLK_TCK);
	if(verbose){ printarray(my_a, 0, my_n-1); printf("\n");}
	printf("Pole %sje usporiadane.\n", sorttest(my_a, my_n)?"":"nie ");
    }
  } while (c != 'K');
}