#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include "elm.h"
#include "sqelm.h"
#include "mq.h"

extern void memo ();

static void white (char* & p) // presunie sa za medzery
{
	while (*p == ' ' || *p == '\t') ++p;
}

static void endoct (char* & p) // presunie sa za osmickove cislo
{
	while (*p >= '0' && *p <= '7') ++p;
}

static void enddec (char* & p) // presunie sa za desiatkove cislo
{
	while (isdigit (*p)) ++p;
	if (*p == '.')
	{
		++p;
		while (isdigit (*p)) ++p;
	}
	if ((*p | 32) == 'e')
	{
		++p;
		if (*p == '+' || *p == '-') ++p;
		while (isdigit (*p)) ++p;
	}
}

static void endhex (char* & p) // presunie sa za sestnaskove cislo
{
	while (isdigit (*p) || ((*p & 0xdf) >= 'A' && (*p & 0xdf) <= 'F')) ++p;
}

mq* parse2q (char *p)
// prepise char* do frontu objektov elm a urobi prvotnu kontrolu
// naslednosti operatorov
{
	static mq x;
	elm tmp;
	double dtmp;
	int itmp;
	char c;

	tmp.vloz (4, '/'); // pociatocny stav automatu

	while (*p)
	{
		white (p);

		switch (*p)
		{
			case '/':
				tmp.vloz (4, '/'); // zmena stavu automatu
				++p;
				break;
			case '*':
				tmp.vloz (4, '*');
				++p;
				break;				
			case '+':
				c = tmp.op ();
				if (c && c != ' ' && c != ')')
				{
					if (c == 'p' || c == 'n')
					{
						x.afree ();
						return NULL;
					}
					tmp.vloz (5, 'p');
				}
				else
				{
					tmp.vloz (3, '+');
				}
				++p;
				break;
			case '-':
				c = tmp.op ();
				if (c && c != ' ' && c != ')')
				{
					if (c == 'p' || c == 'n')
					{
						x.afree ();
						return NULL;
					}
					tmp.vloz (5, 'n');
				}
				else
				{
					tmp.vloz (3, '-');
				}
				++p;
				break;
			case '(':
				if (tmp.op () == ' ')
				{
					x.afree ();
					return NULL;
				}
				tmp.vloz (2, '(');
				++p;
				break;
			case ')':
				if (tmp.op () != ' ' && tmp.op () != ')')
				{
					x.afree ();
					return NULL;
				}
				tmp.vloz (2, ')');
				++p;
				break;
			case '0':
				switch (*(p+1))
				{
		 			case 'x':
		 			case 'X':
					  if (tmp.op () == ' '
						|| tmp.op () == ')')
					  {
						x.afree ();
						return NULL;
					  }
  				          if (sscanf (p, "%x", &itmp) != 1)
					  {
						x.afree ();
						return NULL;
					  }
					  tmp.vloz ((double) itmp);
					  p += 2;
					  endhex (p);
  				          break;
  					case '.':
					  if (tmp.op () == ' '
						|| tmp.op () == ')')
					  {
						x.afree ();
						return NULL;
					  }
					  if (sscanf (p, "%lf", &dtmp) != 1)
					  {
						x.afree ();
						return NULL;
					  }
					  tmp.vloz (dtmp);
					  enddec (p);
  				          break;
  					case '0':
  					case '1':
  					case '2':
  					case '3':
  					case '4':
  					case '5':
  					case '6':
  					case '7':
					  if (tmp.op () == ' '
						|| tmp.op () == ')')
					  {
						x.afree ();
						return NULL;
					  }
  					  if (sscanf (p, "%o", &itmp) != 1)
					  {
						x.afree ();
						return NULL;
					  }
					  tmp.vloz ((double) itmp);
					  endoct (p);
					  break;
  					default:
					  if (tmp.op () == ' '
						|| tmp.op () == ')')
					  {
						x.afree ();
						return NULL;
					  }
					  tmp.vloz ((double) 0.0);
					  ++p;
				}
				break;
			default:
				if (*p == '.' || isdigit (*p))
				{
					if (tmp.op () == ' '
						|| tmp.op () == ')')
					{
						x.afree ();
						return NULL;
					}
					if (sscanf (p, "%lf", &dtmp) != 1)
					{
						x.afree ();
						return NULL;
					}
					tmp.vloz (dtmp);
					enddec (p);
				}
				else
				{
					x.afree ();
					return NULL;
				}
		}
		if (x.insert (tmp) < 0) // ulozi stav automatu na koniec frontu
		{
			x.afree ();
			memo ();
		}
	}
	return &x;
}

