/* Definitions & Procedures */
#include <io.h>
#include <dir.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <values.h>
#include <sys\stat.h>

#include "split.h"

ulong crc;
uchar *buffer;

/* Header definition */
struct ArchHeader
{
    ulong HeadCRC;
    uint  HeadType;
    uint  HeadFlags;
    uint  HeadSize;
    ulong FileSize;
    ulong FileCRC;
    ulong FileTime;
    uint  NameSize;
} AHead;

void pack(char *filename, ulong archsize)
{
    int flags, afile, pfile, archcount;
    uint rslt;
    ulong position, rest;
    char drive[MAXDRIVE], dir[MAXDIR], file[MAXFILE], ext[MAXEXT];
    char archname[MAXPATH], afname[MAXFILE + MAXEXT];

    position= archsize;                              /* Set archive size */
    archcount= 0;                                 /* Set archive counter */
    crc= INITCRC;                                          /* Set CRC-32 */

                                                 /* Compute archive name */
    flags= fnsplit(filename, drive, dir, file, ext);
    strcpy(afname, file);
    strcat(afname, ext);
    if (flags & EXTENSION) leadingzero(archcount, ext);
    strcpy(archname, drive);
    strcat(archname, dir);
    strcat(archname, file);
    strcat(archname, ext);
                                         /* Opens source & archive files */
    afile= open(archname, O_BINARY | O_CREAT | O_RDWR | O_TRUNC,
        S_IREAD | S_IWRITE);
    if (afile == -1) errexit(OPEN_ERROR, archname);
    pfile= open(filename, O_BINARY | O_RDONLY, S_IREAD);
    if (pfile == -1) {
        close(afile);
        remove(archname);
        errexit(OPEN_ERROR, filename);
    }

    printf("\nFile to split..... %s\n\n", filename);

    AHead.HeadType= 'FD';                      /* Fill archive structure */
    AHead.NameSize= strlen(afname);
    AHead.HeadSize= sizeof(AHead) + AHead.NameSize;
    getftime(pfile, (struct ftime *) &AHead.FileTime);
    AHead.HeadFlags= 0;

    position -= AHead.HeadSize;                          /* Degrees size */
    AHead.FileSize= filelength(pfile);       /* & store to the file size */

    do {
                                          /* if file size > archive size */
                                   /* store CONTNEXT flag & archive size */
                                /* the rest size will be in next archive */
        if (AHead.FileSize > position) {
            AHead.HeadFlags= AHead.HeadFlags | CONTNEXT;
            AHead.FileCRC= INITCRC;
            rest= AHead.FileSize - position;
            AHead.FileSize= position;
            AHead.HeadCRC= update_crc(INITCRC, (uchar *) &AHead.HeadType,
                sizeof(AHead) - sizeof(AHead.HeadCRC)) ^ INITCRC;
        }
        else {
            rest= 0;
            position= AHead.FileSize;        /* else modify archive size */
        }

        printf("Archive file...... %s\n", archname);

                          /* store archive structure & original filename */
        rslt= write(afile, &AHead, sizeof(AHead));
        if ((int)rslt == -1) {
            close(afile);
            close(pfile);
            remove(archname);
            errexit(WRITE_ERROR, archname);
        }
        rslt= write(afile, afname, AHead.NameSize);
        if ((int)rslt == -1) {
            close(afile);
            close(pfile);
            remove(archname);
            errexit(WRITE_ERROR, archname);
        }

        while (position > 0) {                        /* READ/WRITE loop */
            rslt= read(pfile, buffer, BUFSIZE);
            if ((int)rslt == -1) {
                close(afile);
                close(pfile);
                remove(archname);
                errexit(READ_ERROR, filename);
            }
                              /* if it's more readed modify file pointer */
            if ((rest != 0) && (rslt > position)) {
                lseek(pfile, tell(pfile) + position - rslt, SEEK_SET);
                rslt= position;                        /* & archive size */
            }
            crc= update_crc(crc, buffer, rslt);        /* Compute CRC-32 */
            write(afile, buffer, rslt);
            if ((int)rslt == -1) {
                close(afile);
                close(pfile);
                remove(archname);
                errexit(WRITE_ERROR, archname);
            }
            position -= rslt;                            /* Degrees size */
        }
        lseek(afile, 0, SEEK_SET);
        rslt= read(afile, &AHead, sizeof(AHead));
        if ((int)rslt == -1) {
            close(afile);
            close(pfile);
            remove(archname);
            errexit(READ_ERROR, filename);
        }
        AHead.FileCRC= crc ^ INITCRC;        /* store the CRC-32 of file */
        AHead.HeadCRC= update_crc(INITCRC, (uchar *) &AHead.HeadType,
            sizeof(AHead) - sizeof(AHead.HeadCRC)) ^ INITCRC;
        lseek(afile, 0, SEEK_SET);
        rslt= write(afile, &AHead, sizeof(AHead));
        if ((int)rslt == -1) {
            close(afile);
            close(pfile);
            remove(archname);
            errexit(WRITE_ERROR, archname);
        }
        
        if (rest != 0) {                    /* If it is not last archive */
            close(afile);
            archcount++;                      /* Increes archive counter */
            position= archsize;                      /* Set archive size */

                                                 /* Compute next archive */
            if (flags & EXTENSION) leadingzero(archcount, ext);
            strcpy(archname, drive);
            strcat(archname, dir);
            strcat(archname, file);
            strcat(archname, ext);

                                               /* Open next archive file */
            afile= open(archname, O_BINARY | O_CREAT | O_RDWR | O_TRUNC,
                S_IREAD | S_IWRITE);
            if (afile == -1) {
              close(pfile);
              errexit(OPEN_ERROR, archname);
            }
                                               /* Fill archive structure */
            AHead.HeadFlags= CONTPREV;    /* continue from previous arch */
            AHead.FileSize= rest;            /* Filesize in next archive */
            position -= AHead.HeadSize;
        }
    } while (rest != 0);

    close(afile);
    close(pfile);
}

void unpack(char *filename)
{
    int flags, afile, pfile, archcount;
    uint rslt;
    ulong tmpcrc;
    char drive[MAXDRIVE], dir[MAXDIR], file[MAXFILE], ext[MAXEXT];
    char packname[MAXFILE + MAXEXT], fext[MAXEXT];

    archcount= 0;                                 /* set archive counter */
    crc= INITCRC;                                             /* Set CRC */

                                                     /* Check a filename */
    flags= fnsplit(filename, drive, dir, file, ext);
    leadingzero(archcount, fext);
    if (strcmp(fext, ext))
        errexit(VOLUME_ERROR, "Please check arguments");

                                                    /* Open archive file */
    afile= open(filename, O_BINARY | O_RDONLY, S_IREAD);
    if (afile == -1) errexit(OPEN_ERROR, filename);

    printf("\n");
    
    do {                                    /* Read an Archive Structure */
        printf("Volume file....... %s\n", filename);

        rslt= read(afile, &AHead.HeadCRC, sizeof(AHead));
        if ((int)rslt == -1) {
            close(afile);
            errexit(READ_ERROR, filename);
        }
                                           /* Check a file & CRC of head */
        if (AHead.HeadType == 'FD') {
            tmpcrc= update_crc(INITCRC, (uchar *) &AHead.HeadType,
                sizeof(AHead) - sizeof(AHead.HeadCRC)) ^ INITCRC;
            if (AHead.HeadCRC == tmpcrc) {
                                                 /* Read a original name */
                rslt= read(afile, &packname, AHead.NameSize);
                if ((int)rslt == -1) {
                    close(afile);
                    errexit(READ_ERROR, filename);
                }
                packname[AHead.NameSize]= 0x00;

          /* if archive file is cont. from previous: open file to APPEND */
                if ((AHead.HeadFlags & CONTPREV) != 0) {
                    pfile= open(packname, O_BINARY | O_APPEND | O_RDWR,
                        S_IREAD | S_IWRITE);
                    if (pfile == -1) {
                        close(afile);
                        errexit(OPEN_ERROR, packname);
                    }
                } else {
                                                 /* else CREATE new file */
                    pfile= open(packname,
                        O_BINARY | O_CREAT | O_RDWR | O_TRUNC,
                        S_IREAD | S_IWRITE);
                    if (pfile == -1) {
                        close(pfile);
                        errexit(OPEN_ERROR, packname);
                    }
                }

                while (AHead.FileSize > 0) {          /* READ/WRITE loop */
                    rslt= read(afile, buffer, BUFSIZE);
                    if ((int)rslt == -1) {
                        close(afile);
                        close(pfile);
                        remove(packname);
                        errexit(READ_ERROR, filename);
                    }
                    crc= update_crc(crc, buffer, rslt);   /* Compute CRC */
                    rslt= write(pfile, buffer, rslt);
                    if ((int)rslt == -1) {
                        close(afile);
                        close(pfile);
                        remove(packname);
                        errexit(WRITE_ERROR, packname);
                    }
                    if (AHead.FileSize >= rslt) AHead.FileSize-= rslt;
                    else errexit(LEN_ERROR, filename);
                }
                setftime(pfile, (struct ftime *) &AHead.FileTime);
                close(pfile);
                close(afile);
                                                 /* check CRC-32 of file */
                tmpcrc= crc ^ INITCRC;
                if (tmpcrc != AHead.FileCRC) errexit(CRC_ERROR, filename);

/* If is not last archive: increes archive counter, set next archive name,
   open next archive name */
                if ((AHead.HeadFlags & CONTNEXT) != 0) {
                    archcount++;
                    if (flags & EXTENSION) leadingzero(archcount, ext);
                    strcpy(filename, drive);
                    strcat(filename, dir);
                    strcat(filename, file);
                    strcat(filename, ext);
                    afile= open(filename, O_BINARY | O_RDONLY, S_IREAD);
                    if (afile == -1) {
                        remove(packname);
                        errexit(OPEN_ERROR, filename);
                    }
                } else afile= -1;
            } else {
                close(afile);
                errexit(CRC_ERROR, filename);
            }
        } else {
           close(afile);
           errexit(ARCH_ERROR, filename);
        }
    } while (afile != -1);

    printf("\nRestored file..... %s\n", packname);
}

void leadingzero(int num, char *s)
{
    int i;

    strcpy(s, ".000");
    for(i= 3; i > 0; i--) {
        s[i]= (num % 10) + '0';
        num /= 10;
    }
}
