/* Definitions & Procedures */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "split.h"

extern ulong crc;
extern uchar *buffer;

void main(int argc, char **argv)
{
    char *s, *filename= NULL, *fsize= NULL, errstr[80];

    printf("Split - split/link file v. 1.0, (C) 1996 Henrich FUKNA & Marek DZURKO\n");

    if ((buffer = (uchar *) malloc(BUFSIZE)) == NULL) {
        errexit(MEMORY_ERROR, "Remove some program from memory");
    }
    make_crc_table();

    while (--argc > 0) {
        if (**++argv == '-')
            for(s= ++*argv; *s != 0; s++)
                switch (*s) {
                    case 'a':
                    case 'A': if (fsize == NULL) fsize= *argv;
                              else {
                                  help();
                                  errexit(USER_ERROR, "Too many arguments");
                              }
                              break;
                    case 'h':
                    case 'H': help();
                              errexit(SUCCESS, "");
                    default:  help();
                              strcpy(errstr, "Invalid switch ");
                              strcat(errstr, s);
                              errexit(USER_ERROR, errstr);
                }
        else if (filename == NULL) filename= *argv;
        else if (fsize == NULL) fsize= *argv;
        else {
            help();
            errexit(USER_ERROR, "Too many arguments");
        }
    }
    if (!filename || !fsize) {
        help();
        errexit(USER_ERROR, "Too few arguments");
    }
    if (!strcmp(fsize, "a") || !strcmp(fsize, "A")) unpack(filename);
    else if (!strcmp(fsize, "360")) pack(filename, 362496);
    else if (!strcmp(fsize, "720")) pack(filename, 730112);
    else if (!strcmp(fsize, "1200")) pack(filename, 1213952);
    else if (!strcmp(fsize, "1440")) pack(filename, 1457664);
    else if (!strcmp(fsize, "2880")) pack(filename, 2915328);
    else {
        help();
        strcpy(errstr, "Invalid size ");
        strcat(errstr, fsize);
        errexit(USER_ERROR, errstr);
    }

    errexit(SUCCESS, "");
}

void help(void)
{
    printf("Ussage : SPLIT [-h|H] <filename> <size>\n\n");
    printf("         OR\n\n");
    printf("         SPLIT [-h|H] <-a|A> <filename>\n\n");
    printf("           -h|H      - display this help\n");
    printf("           -a|A      - link volume files\n");
    printf("           filename  - file to split | first volume file\n");
    printf("           size      - split size: 360, 720, 1200, 1440, 2880\n\n");
}

void errexit(int errcode, char *errstr)
{
    char errmsg[80];

    switch (errcode) {
        case ARCH_ERROR:
            strcpy(errmsg, "Invalid archive file"); break;
        case CRC_ERROR:
            strcpy(errmsg, "CRC-32 error. File broken ?"); break;
        case LEN_ERROR:
            strcpy(errmsg, "File length is different. File broken ?"); break;
        case READ_ERROR:
            strcpy(errmsg, "Read error"); break;
        case WRITE_ERROR:
            strcpy(errmsg, "Write error"); break;
        case OPEN_ERROR:
            strcpy(errmsg, "File open error"); break;
        case MEMORY_ERROR:
            strcpy(errmsg, "Not enough memory"); break;
        case VOLUME_ERROR:
            strcpy(errmsg, "Required first volume file"); break;
        case USER_ERROR:
            strcpy(errmsg, "User error"); break;
    }
    if (errcode != SUCCESS)
        printf("\n Program aborted\n %s ( %s )\n", errmsg, errstr);
    if (buffer != NULL) free(buffer);
    exit(errcode);
}
