
%{
#include <stdio.h>
#define YYSTYPE double /* typ premennych yacc */
#include <math.h>
#include <ctype.h>
%}


%token NUM    /* terminalny symbol */
%left '-' '+'
%left '*' '/'
%left SIG     /* toto je tu kvoli unarnym operatorom */
%right '^'    /* umocnovanie        */

%%

input:
        | line input
;

line:     '\n'
        | exp '\n'  { printf ("\t%.10g\n", $1); }
	| error '\n' { yyerrprint;		}
;

exp:      NUM                { $$ = $1;         }
        | exp '+' exp        { $$ = $1 + $3;    }
        | exp '-' exp        { $$ = $1 - $3;    }
        | exp '*' exp        { $$ = $1 * $3;    }
        | exp '/' exp        { $$ = $1 / $3;    }
        | '-' exp  %prec SIG { $$ = -$2;        }
        | '+' exp  %prec SIG { $$ = +$2;        }
        | exp '^' exp        { $$ = pow ($1, $3); }
        | '(' exp ')'        { $$ = $2;         }
;

%%


yylex ()
{
  int c;
  int tmp;

  while ((c = getchar ()) == ' ' || c == '\t')  
    ;

  if (c == '0')
    {
      int cc;
      cc = getchar ();
      switch (cc)
        {
          case 'x':
          case 'X':
            scanf ("%x", &tmp);
            yylval = tmp;
            return NUM;
          case '.':
            c = cc;
            break;
          case '0':
          case '1':
          case '2':
          case '3':
          case '4':
          case '5':
          case '6':
          case '7':
            ungetc (cc, stdin);
            scanf ("%o", &tmp);
            yylval = tmp;
            return NUM;
          default:
            ungetc (cc, stdin);
            yylval = 0.0;
            return NUM;
        }
    }

  if (c == '.' || isdigit (c))                
    {
      ungetc (c, stdin);
      scanf ("%lf", &yylval);
      return NUM;
    }

  if (c == EOF)                            
    return 0;

  return c;                                
}

yyerrprint ()
{
  printf ("syntax error\n");
}

yyerror (s)
     char *s;
{
  printf ("%s\n", s);
}

main ()
{
  yyparse ();
}
