#include <sys/stat.h>
#include <pwd.h>
#include <signal.h>
#include <string.h>
#include <arpa/inet.h>
#include <netinet/protocols.h>
#include <syslog.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <unistd.h>
#include <stdio.h>
#include <netinet/in.h>
#include <netdb.h>
#include <fcntl.h>
#include <stdlib.h>
#include "method.h"

#ifndef RUN_USER
#define RUN_USER "nobody"
#endif

#ifndef RUN_GROUP
#define RUN_GROUP "tty"
#endif

#ifndef GROUP_LINE_LEN
#define GROUP_LINE_LEN 256
#endif

#ifndef TELL_PORT
#define TELL_PORT 4224
#endif

#define STAT_MASK ~07777

extern void obsluz(int s);

int method = 0;

void terminated(int snum)
{
	openlog("telld", LOG_PID | LOG_CONS, LOG_DAEMON);
	syslog(LOG_INFO | LOG_DAEMON, "exiting on signal %d", snum);
	closelog();
	exit(0);
}

int readline(FILE *f)
{
	char buf[GROUP_LINE_LEN];
	char c;
	int i;

	for ( i = 0 ; ((c = getc(f)) != EOF) && (c != ':') &&
		(i < GROUP_LINE_LEN - 1) ; ++i )
			buf[i] = c;
	buf[i] = 0;

	if (strcmp(buf, RUN_GROUP))
	{
		while (((c = getc(f)) != '\n') && (c != EOF));
		if (c == EOF) return -2;
		else return -1;
	}

	while (((c = getc(f)) != EOF) && (c != ':'));
	for ( i = 0 ; (i < 8) && ((c = getc(f)) != EOF) && (c != ':') ; ++i )
		buf[i] = c;
	buf[i] = 0;
	
	sscanf(buf, "%d", &i);
	return i;
}

int main(int argc, char *argv[])
{
	FILE *fgr;
	int r;
	mode_t sk;
	struct stat sck;
	struct passwd *pa;
	int standalone = 0;
	int conn, bo;
	int s = 0;
	int i, j;
	struct servent *srvnt;
	struct sockaddr_in sa, caller;	
	int sil = sizeof(sa);
	int fl = sizeof(caller);
	char ch[4096];

	/* TEST IF FILEDES 0 IS CHARACTER DEVICE OR SOCKET */
	/* IF CHARACTER DEVICE WE ARE IN STANDALONE MODE   */
 	/* IF SOCKET WE ARE IN INETD MODE                  */

#ifndef DEBUG
	if (fstat(s, &sck) < 0)
	{
		openlog("telld", LOG_PID | LOG_CONS, LOG_DAEMON);
		syslog(LOG_DAEMON | LOG_ERR, "fstat");
		closelog();
		exit(-1);
	}

	
	sk = sck.st_mode & STAT_MASK;
	if (sk == S_IFCHR) standalone = 1;
	if ((sk != S_IFCHR) && (sk != S_IFSOCK))
	{
		openlog("telld", LOG_PID | LOG_CONS, LOG_DAEMON);
		syslog(LOG_DAEMON | LOG_ERR,
			"fd 0 is nor a stdin nor a socket");
		closelog();closelog();
		exit(-1);
	}
#endif

	/* NOW WE KNOW IN WHICH MODE WE ARE */

	/* PARSE FILE ARGUMENTS */

	if (argc > 1)
	{
		for( j = 1 ; j < argc ; ++j )
		{
			if (argv[j][0] == '-')
			for( i = 1 ; i < strlen(argv[j]) ; ++i )
			{
				if (argv[j][i] == '-')
				{
					argc = j;
					break;
				}
				switch (argv[j][i])
				{
				  case 'a':	method |= WRITE_TO_ALL;
						break;
				  case 'f':	method |= WRITE_TO_FIRST;
						break;
				  case 'n':	method |= DO_NOT_LOG_AUTH;
						break;
				  case 'l':	method |= DO_NOT_CUT_DOMAIN;
						break;
				  case 'q':	method |= QUIET_MODE;
						break;
				}
			}
		}
	}

	/* FILE ARGUMENTS PARSED */

	/* MAIN SERVER ROUTINE */

	signal(SIGCHLD, SIG_IGN);

	if (standalone)
	{
		if ((fgr = fopen("/etc/group", "rt")) == NULL)
		{
			fprintf(stderr,
				"%s: cannot open file /etc/group\n", argv[0]);
			exit(-1);
		}

		while ((r = readline(fgr)) == -1);
		fclose(fgr);

		if (r < 0)
		{
			fprintf(stderr,
				"%s: cannot find group %s in /etc/group\n",
				argv[0], RUN_GROUP);
			exit(-1);
		}

		if (setgid((gid_t) r) < 0)
		{
			fprintf(stderr,
				"%s: You must be root to run %s\n",
				argv[0], argv[0]);
			exit(-1);
		}
			
		if ((pa = getpwnam(RUN_USER)) == NULL)
		{
			fprintf(stderr,
				"%s: user %s does not exist\n",
				argv[0], RUN_USER);
			exit(-1);
		}

		if (setuid(pa->pw_uid) < 0)
		{
			fprintf(stderr,
				"%s: You must be root to run %s\n",
				argv[0], argv[0]);
			exit(-1);
		}
		
		if ((conn = socket(AF_INET, SOCK_STREAM, IP_TCP)) < 0)
		{
			sprintf(ch, "%s: socket", argv[0]);
			perror(ch);
			exit(-1);
		}

		srvnt = getservbyname("tell", "tcp");

		sa.sin_family = AF_INET;
		if (srvnt) sa.sin_port = (unsigned short) srvnt->s_port;
		else sa.sin_port = htons(TELL_PORT);
		sa.sin_addr.s_addr = INADDR_ANY;

		if ((bo = bind(conn, (struct sockaddr*) &sa, sizeof(sa))) < 0)
		{
			sprintf(ch, "%s: bind", argv[0]);
			perror(ch);
			exit(-1);
		}

		if (getsockname(conn, (struct sockaddr*) &sa, (int*) &sil) < 0)
		{
			sprintf(ch, "%s: getsockname", argv[0]);
			perror(ch);
			exit(-1);
		}
	
		if (fork()) exit(0);

		signal(SIGCHLD, SIG_IGN);

		if (!(method & QUIET_MODE))
		{
			signal(SIGINT, terminated);
			signal(SIGQUIT, terminated);
			signal(SIGILL, terminated);
			signal(SIGABRT, terminated);
			signal(SIGFPE, terminated);
			signal(SIGTERM, terminated);
			openlog("telld", LOG_PID | LOG_CONS, LOG_DAEMON);
			syslog(LOG_INFO | LOG_DAEMON,
				"running in standalone mode");
			closelog();
		}

		while(1)
		{
			listen(conn, 1);
			if ((s = accept(conn,
				(struct sockaddr*) &caller, &fl)) < 0)
			{
				openlog("telld", LOG_PID | LOG_CONS,
					LOG_DAEMON);
				syslog(LOG_ERR | LOG_DAEMON,
					"accept returns error");
				closelog();
				exit(-1);
			}
			if (!fork())
			{
				obsluz(s);
				exit(0);
			}
		}
	}

	obsluz(s);
	return 0;

	/* END OF MAIN SERVER ROUTINE */

}

