//-------------------------------------------------------------------
//  PROGRAM: randbeta.cpp
//-------------------------------------------------------------------

#pragma hdrstop

//--------------------------- Includes ----------------------------//

#if !defined ( _RANDBETA_HPP )
#include "randbeta.hpp"
#endif

#if !defined ( _RANDGAMA_HPP )
#include "randgama.hpp"
#endif

extern "C"
{
#include <math.h>
#include <string.h>
#include <stdio.h>
}

//-- constructors --//

RandBeta::RandBeta( double _shape1, double _shape2, double _lowerBound,
      double _upperBound, char *_name )
   : Rand( 1, _name ),
     shape1( fabs( _shape1 ) ),
     shape2( fabs( _shape2 ) ),
     lowerBound( _lowerBound ),
     upperBound( _upperBound ),
     pRNG1( NULL ),
     pRNG2( NULL )

   {
   SetDistName( "Beta" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%g", shape1 );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", shape2 );
   SetParameterB_Name( temp );

   Initialize( shape1, shape2, 1, 1 );
   }


RandBeta::RandBeta( double _shape1, double _shape2, double _lowerBound,
      double _upperBound, long _seed, char *_name )
   : Rand( 1, _seed, _name ),
     shape1( fabs( _shape1 ) ),
     shape2( fabs( _shape2 ) ),
     lowerBound( _lowerBound ),
     upperBound( _upperBound ),
     pRNG1( NULL ),
     pRNG2( NULL )

   {
   SetDistName( "Beta" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%g", shape1 );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", shape2 );
   SetParameterB_Name( temp );

   Initialize( shape1, shape2, 1, _seed );
   }

RandBeta::RandBeta( double _shape1, double _shape2, double _lowerBound,
      double _upperBound, UINT _stream, long _seed, char *_name )
   : Rand( _stream, _seed, _name ),
     shape1( fabs( _shape1 ) ),
     shape2( fabs( _shape2 ) ),
     lowerBound( _lowerBound ),
     upperBound( _upperBound ),
     pRNG1( NULL ),
     pRNG2( NULL )

   {
   SetDistName( "Beta" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%g", shape1 );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", shape2 );
   SetParameterB_Name( temp );

   Initialize( shape1, shape2, _stream, _seed );
   }


RandBeta::~RandBeta( void )
   {
   if ( pRNG1 )
      delete pRNG1;

   if ( pRNG2 )
      delete pRNG2;
   }

//-- initialize the random number generators --//
void RandBeta::Initialize( double _shape1, double _shape2, UINT _stream,
      long _seed )
   {
   pRNG1 = new RandGamma( _shape1, 1, _stream, _seed );

   //-- new stream # so this is independent of pRNG1 --//
   pRNG2 = new RandGamma( _shape2, 1, _stream + 1, _seed );

   return;
   }


//-- return a beta random number --//
double RandBeta::RandValue( void )
   {
   AddOneObservation();

   double X = 0;

   double Y1 = pRNG1->RandValue();     // get a gamma variate
   double Y2 = pRNG2->RandValue();     // get a gamma variate

   X = Y1 / ( Y1 + Y2 );

   return ( lowerBound + ( upperBound - lowerBound ) * X );
   }

