//-------------------------------------------------------------------
//  PROGRAM: randbino.cpp
//-------------------------------------------------------------------

#pragma hdrstop

//--------------------------- Includes ----------------------------//

#if !defined ( _RANDBINO_HPP )
#include "randbino.hpp"
#endif

#if !defined ( _RANDBERN_HPP )
#include "randbern.hpp"
#endif

extern "C"
{
#include <string.h>
#include <stdio.h>
}


//-- constructors --//

RandBinomial::RandBinomial( ULONG _successfullTrials, double _probability, 
      char *_name )
   : Rand( 1, _name ), 
     probability( _probability ),
     successfullTrials( _successfullTrials )
   { 
   SetDistName( "Binomial" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%Lu", successfullTrials );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", probability );
   SetParameterB_Name( temp );

   pRNG = new RandBernoulli( probability );
   }


RandBinomial::RandBinomial( ULONG _successfullTrials, double _probability,
      UINT _stream, long _seed, char *_name )
   : Rand( _stream, _seed, _name ),
     probability( _probability ),
     successfullTrials( _successfullTrials )
   {
   SetDistName( "Binomial" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%Lu", successfullTrials );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", probability );
   SetParameterB_Name( temp );

   pRNG = new RandBernoulli( probability, _stream, _seed );
   }


//-- destructor --//
RandBinomial::~RandBinomial( void )
   {
   if ( pRNG )
      delete pRNG;
   }


//-- returns a binomial variate --//
double RandBinomial::RandValue( void )
   {
   AddOneObservation();

   ULONG success = 0;

   for ( ULONG i = 1; i <= successfullTrials; i++ )
     success += pRNG->RandValue();

   return (double) success;
   }
