//-------------------------------------------------------------------
// PROGRAM: randgeo.hpp
//
// PURPOSE: Generates geometric random numbers
//
// NOTE: RandGeometric( probability )
//-------------------------------------------------------------------

/*
---------------------------------------------------------------------
   If Y1, Y2, ..., is a sequence of independent Bernoulli trials,
   then X = the number of failures before the first success.

Parameters: probability ( p ) is 0 < p < 1.

Range:      { 0, 1, ... }

Mean:       ( 1 - p ) / p

Var:        ( 1 - p ) / ( p * p )

   "Number of failures before the first success in a sequence of in-
dependent Bernoulli trials with probability p of success on each trial;
number of items inspected before encountering the first defective item;
number of items in a batch of random size; number of items demanded from 
an inventory". [ Law & Kelton, 1991 ]


References: Simulation Modeling & Analysis by Law and Kelton, 1991,
            pgs., 347 and 502.

            Discrete System Simulation by William G. Bulgren, 1982,
            pgs., 175-176.
---------------------------------------------------------------------
*/

#if !defined _RANDGEO_HPP
#define      _RANDGEO_HPP 1

//------------------------------ Includes -------------------------//

#if !defined ( _RAND_HPP )
#include "rand.hpp"
#endif

//-------------------------- Forward reference --------------------//

class RandBernoulli;



class RandGeometric : public Rand
   {

   private:

      double probability;           // probability of success at each trial

      RandBernoulli *pRNG;          // since we sum Bernoulli trials

   public:

      //-- constructors --//
      RandGeometric( double _probability,  char *_name = "-" );

      RandGeometric( double _probability, UINT _stream, 
            long _seed, char *_name = "-" );

      //-- destructor --//
      virtual ~RandGeometric( void );

      //-- returns a geometric random variable --//
      virtual double RandValue( void );

   };


#endif

