//-------------------------------------------------------------------
//  PROGRAM: randnbin.cpp
//-------------------------------------------------------------------

#pragma hdrstop

//--------------------------- Includes ----------------------------//

#if !defined ( _RANDNBIN_HPP )
#include "randnbin.hpp"
#endif

#if !defined ( _RANDGEO_HPP )
#include "randgeo.hpp"
#endif

extern "C"
{
#include <math.h>
#include <string.h>
#include <stdio.h>
}


//-- constructors --//

RandNegBinomial::RandNegBinomial( ULONG _numSuccesses, double _probability,
      char *_name )
   : Rand( 1, _name ),
     numSuccesses( _numSuccesses ),
     probability( fabs( _probability ) )
   {
   SetDistName( "NegBinom" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%Lu", numSuccesses );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", probability );
   SetParameterB_Name( temp );

   pRNG = new RandGeometric( probability );
   }


RandNegBinomial::RandNegBinomial( ULONG _numSuccesses, double _probability,
      UINT _stream, long _seed, char *_name )
   : Rand( _stream, _seed, _name ),
     numSuccesses( _numSuccesses ),
     probability( fabs( _probability ) )
   {
   SetDistName( "NegBinom" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%Lu", numSuccesses );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", probability );
   SetParameterB_Name( temp );

   pRNG = new RandGeometric( probability, _stream, _seed );
   }


//-- destructor --//
RandNegBinomial::~RandNegBinomial( void )
   {
   if ( pRNG )
      delete pRNG;
   }


double RandNegBinomial::RandValue( void )
   {
   AddOneObservation();

   //--number of failures before the sth success in a sequence of
   //  independent bernoulli trials with probability p of success
   //  on each trial

   long geometricResult = 0;

   for ( UINT i = 0; i < numSuccesses; i++ )
      geometricResult += (long) pRNG->RandValue();

   return ( (double) geometricResult );
   }
