//-------------------------------------------------------------------
//  PROGRAM: randnorm.cpp
//-------------------------------------------------------------------

#pragma hdrstop

//--------------------------- Includes ----------------------------//

#if !defined ( _RANDNORM_HPP )
#include "randnorm.hpp"
#endif

extern "C"
{
#include <math.h>
#include <string.h>
#include <stdio.h>
}



//-- constructors --//

RandNormal::RandNormal( double _meanNorm, double _stdNorm, 
      long _seed, char *_name )
   : Rand( 1, _seed, _name ),
     rand1( (UINT) 1, _seed ), // use stream 1, these should be independent!
     rand2( (UINT) 2, _seed ), // use stream 2, so use different streams
     meanNorm( _meanNorm ),
     stdNorm( fabs( _stdNorm ) ),
     varNorm( stdNorm * stdNorm )
   {
   SetDistName( "Normal" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%g", meanNorm );
   SetParameterA_Name( temp );
   sprintf( temp, "%g", stdNorm );
   SetParameterB_Name( temp );
   }


// polar method by Marsaglia & Bray (1964)
double RandNormal::RandValue( void )
   {
   AddOneObservation();

   double firstValue;
   static double secondValue;    // uses both random numbers produced
   static int secondValueFlag;   // by the polar method

   double W;         // algorithm variables
   double V1;
   double V2;

   if ( secondValueFlag == FALSE )  // No second value available
      {
      secondValueFlag = TRUE;
      do    // these are not automatically included in observations
         {  // use 2 different streams, pick two uniform numbers fron -1 to 1.
         V1 = 2 * rand1.RandValue() - 1.;
         V2 = 2 * rand2.RandValue() - 1.;
         W = V1 * V1 + V2 * V2;
         }
      while ( W >= 1. );            // Make sure they're in the unit circle.

      double Y = sqrt( -2. * ::log( W ) / W ); // Box-Muller transformation.

      firstValue =  V1 * Y;
      secondValue = V2 * Y;                // Save one number for next time.

      return( stdNorm * firstValue + meanNorm );
      }

   else
      {                             // Extra value available.
      secondValueFlag = FALSE;      // Reset the secondValueFlag.

      return( stdNorm * secondValue + meanNorm );
      }

   }


