//-------------------------------------------------------------------
// PROGRAM: randpois.hpp
//
// PURPOSE: Generates poisson distributed random numbers
//-------------------------------------------------------------------

/*
---------------------------------------------------------------------
Note: Formula derived from Law & Kelton.
      1. Let a = e ^-y, b = 1, and i = 0;
      2. Generate U(i+1) ~ U( 0, 1 ) and replace b by b*U(i+1).
         If b < a, return X = 1. Otherwise, go to step 3.
      3. Replace i by i+1 and go back to step 2. [ Law & Kelton, 1991 ]

Parameters: The mean lamda is a positive real number.

Range: [ 0, 1, 2, ..., ]

Mean: lamda
Var:  lamda

   "The Poisson distribution is a discrete distribution that is often
used to model the number of random events occurring in an interval
of time. If the time between events is exponentially distributed,
then the number of events that occur in a fixed time interval has a
Poisson distribution. The Poisson distribution is also used to model
random variations in batch size." [ Pegden et al, 1990 ]

Reference: Introduction to Simulation using SIMAN by C. Dennis Pegden,
           Robert E. Shannon, and Randall P. Sadowski, 1990., pg., 565.

           Simulation Modeling & Analysis by Averill M. Law and W. David 
           Kelton, 1991, pg., 503.
---------------------------------------------------------------------
*/

#if !defined _RANDPOIS_HPP
#define      _RANDPOIS_HPP 1

//---------------------------- Includes ---------------------------//

#if !defined ( _RAND_HPP )
#include "rand.hpp"
#endif


class RandPoisson : public Rand
   {

   private:

      double mean;

      double a;               // algorithm coefficients, See Law & Kelton                                                                                                                                 

   public:

      //-- constructors --//
      RandPoisson( double _mean, char *_name = "-" );
      RandPoisson( double _mean, UINT _stream, long _seed, char *_name = "-" );

      //-- destructor --//
      virtual ~RandPoisson( void ) { }

      //-- returns a poisson random number --//
      virtual double RandValue( void );

   };


#endif
