//-------------------------------------------------------------------
//  PROGRAM: rand_t.cpp
//-------------------------------------------------------------------

#pragma hdrstop

//--------------------------- Includes ----------------------------//

#if !defined ( _RAND_T_HPP )
#include "rand_t.hpp"
#endif

#if !defined ( _RANDGAMA_HPP )
#include "randgama.hpp"
#endif

#if !defined ( _RANDNORM_HPP )
#include "randnorm.hpp"
#endif

extern "C"
{
#include <math.h>
#include <string.h>
#include <stdio.h>
}


//-- constructor --//
Rand_T::Rand_T( UINT _degreesOfFreedom, long _seed, char *_name )
   : Rand( 1, _seed, _name ),
     pRNGGamma( NULL ),
     pRNGNorm( NULL ),
     degreesOfFreedom( _degreesOfFreedom )
   {
   SetDistName( "T-dist" );

   //-- set the coefficients --//
   char temp[ 40 ];
   sprintf( temp, "%u", degreesOfFreedom );
   SetParameterA_Name( temp );

   //-- run the constructor for the gamma distribution --//
   pRNGGamma = new RandGamma( (double) degreesOfFreedom / 2.0, 2.0, _seed );

   //-- run the constructor for the normal distribution --//
   pRNGNorm = new RandNormal( 0, 1, _seed );
   }


//-- destructor --//
Rand_T::~Rand_T( void )
   {
   if ( pRNGGamma )
      delete pRNGGamma;

   if ( pRNGNorm )
      delete pRNGNorm;
   }


double Rand_T::RandValue( void )
   {
   AddOneObservation();

   double Y = pRNGNorm->RandValue();
   double Z = pRNGGamma->RandValue();

   double X = Y / ( sqrt( Z / (double) degreesOfFreedom ) );

   return( X );
   }



