/***************************************************************************/
/*                      Korekcia textu poruseneho sumom.                   */
/* cez LEFT RIGHT Chaos Sequenece Representation of the text1              */
/* na ktorom bola natrenovane Kohonenova siet, prezenie iny poruseny text2 */
/* a podla blizkosti klzaveho okna k codebook vektorom robi korekciu       */
/*-------------------------------------------------------------------------*/
/* Vyberie sa vzdy najpravdepodobnejsia moznost!                           */
/* Pocet codebook vectorov moze byt aj vacsi.                              */
/* Codebooks su v operacnej pamati                                         */     
/*-------------------------------------------------------------------------*/
/* sequence text2 in file *.trs                                            */
/* codebook vectors coding task1.csr in *.kst                              */
/* number of symbols in the alphabet must be pow(2,N), info file: task.cst */
/*-------------------------------------------------------------------------*/
/* vysledny text je v subore correct.txt                                   */
/***************************************************************************/

#define MAX_DIM                   10      /* maximalna dimenzia */
#define MAX_SYM                   40      /* maximalny pocet symbolov v abecede */
#define MAX_LEN_WINDOW            100     /* maximalna dlzka okna */
#define MAX_LENGTH_CORRUPTED_TEXT 300     /* maximalna dlzka poruseneho textu */
#define MAXFLOAT 100
#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <string.h>

void  main(int argc, char *argv[]);
FILE  *otvor_subor(char *nazov_sub, char *mod);
int   code_of_the_symbol(char symbol);
int   read_k_symbols_from_file(FILE *fp, char *string, int k);
int   ini_koh_weights_file(void);
void  report_koh_weights(void);
float pow_2(float x);
float min_left_dist_from_codebook(float *point);
float min_right_dist_from_codebook(float *point);
void  allocate_memory(void);
void  free_memory(void);
void  report_parameters(void);
void  report_parameters_cst(void);
void  allocate_memory_read_symbol_codes(void); 
int  find_better_symbol(char *);

char  corrupt_text[80],
	  left_codebooks[80],
	  right_codebooks[80], 
	  symb_coef[80],
	  left_window[MAX_LEN_WINDOW],
	  right_window[MAX_LEN_WINDOW],
	  best_right_window[MAX_LEN_WINDOW];
char  SYM_CODE[MAX_SYM],
      ssymbol[5];
char  CORRUPTED_TEXT[MAX_LENGTH_CORRUPTED_TEXT],
      CORRECTED_TEXT[MAX_LENGTH_CORRUPTED_TEXT];
char  **POSSIBLE_CONTEXTS;      
float X_pov[MAX_DIM],
      X[MAX_DIM],
      sym_left_csr[MAX_DIM],
      sym_right_csr[MAX_DIM];
int   NUM_SYMBOLS;
int   DIMENSION;
float ***A,
      **T,
      **W_left,
      **W_right;
int   LEN_WINDOW;
long  left_num_codebooks,
      right_num_codebooks;
float LEFT_DIST_THRESHOLD,
      MIN_LEFT_DIST_THRESHOLD,
      RIGHT_DIST_THRESHOLD,
      MIN_RIGHT_DIST_THRESHOLD,
      MAX_RIGHT_DIST_THRESHOLD;
int   length_corrupted_text,
      CORRECTED_SYMBOLS_SO_FAR,
      BACK_CORRECTION_DEPTH;
float SCALE_RIGHT;

void main(int argc, char *argv[])
{
	FILE  *fp_seq,*fp_corr;
	int   sym,sym_pos,c,s,ss;
	char  symbol,next_symbol;
	int   symbol_kod,next_symbol_int;
	float pom,left_min_dist,right_min_dist;
	int   BackTrack=0,PocetOprav=0;
	char  field_of_winner1[6],field_of_winner2[6];
	
	printf("\n\n\ncorrupted text: ");
	scanf("%s",corrupt_text);
	printf("\n# of codebooks covering left csr: ");
	scanf("%ld",&left_num_codebooks);
	printf("\ncodebooks covering left csr in file: ");
	scanf("%s",left_codebooks);
	printf("\n# of codebooks covering right csr: ");
	scanf("%ld",&right_num_codebooks);
	printf("\ncodebooks covering right csr in file: ");
	scanf("%s",right_codebooks);
	printf("\nsymbol coeficients (*.cst): ");
	scanf("%s",symb_coef);
	printf("\nleft distance threshold: ");
	scanf("%f",&LEFT_DIST_THRESHOLD);
	printf("\nmin. left distance threshold to consider: ");
	scanf("%f",&MIN_LEFT_DIST_THRESHOLD);
	printf("\nright distance threshold: ");
	scanf("%f",&RIGHT_DIST_THRESHOLD);
	printf("\nmin. right distance threshold to consider: ");
	scanf("%f",&MIN_RIGHT_DIST_THRESHOLD);
	printf("\nmax. right distance threshold to consider: ");
	scanf("%f",&MAX_RIGHT_DIST_THRESHOLD);
	printf("\nscaling coef. for right distance [0,1]: ");
	scanf("%f",&SCALE_RIGHT);
	
	allocate_memory_read_symbol_codes();
	ini_koh_weights_file();
	
	fp_seq=otvor_subor(corrupt_text,"r");
	length_corrupted_text=0;
	
	do
	{
		next_symbol_int=read_k_symbols_from_file(fp_seq,&next_symbol,1);
		CORRUPTED_TEXT[length_corrupted_text]=next_symbol;
		length_corrupted_text++;
	}while(next_symbol_int != EOF);

	CORRUPTED_TEXT[length_corrupted_text]='\0'; 
	length_corrupted_text--;
	fclose(fp_seq);
	printf("\nlength_corrupted_text=%d",length_corrupted_text);
	
	printf("\n\n\nCorrupted text:\n");
	
	for(sym=1; sym<=length_corrupted_text; sym++)
		if(CORRUPTED_TEXT[sym-1] != '+')
			printf("%c", CORRUPTED_TEXT[sym-1]);
		else
			printf(" ");
		
	printf("\n\n");
		
	for(sym=1; sym<=length_corrupted_text; sym++)
		CORRECTED_TEXT[sym-1]=CORRUPTED_TEXT[sym-1];
	
	for(sym_pos=LEN_WINDOW; sym_pos<=length_corrupted_text-LEN_WINDOW+1; sym_pos++)
	{ /* read the left and right contexts */
		printf("\nContext: ");

		for(ss=0,s=sym_pos-LEN_WINDOW; s<sym_pos;ss++,s++)
			left_window[ss]=CORRECTED_TEXT[s];

		if(left_window[LEN_WINDOW-1]=='+' && left_window[LEN_WINDOW-2]=='+')
		{
			for(ss=LEN_WINDOW-1;ss>0;ss--)
				left_window[ss]=left_window[ss-1];
			
			left_window[0]=CORRECTED_TEXT[sym_pos-LEN_WINDOW]; 
		}
		
		left_window[LEN_WINDOW]='\0';
		printf("left: %s  ", left_window);  
		
		/* read the right window at current position */
		
		for(ss=0,s=sym_pos-1; s<sym_pos+LEN_WINDOW-1; s++,ss++)
			right_window[ss]=CORRECTED_TEXT[s];
		
		right_window[LEN_WINDOW]='\0';
		printf("right: %s", right_window);  
		
		/* map the left_window as a point in the factal LEFT CSR */
		for( s=0; s<DIMENSION; s++)
			X_pov[s]=0.5;
		
		for(sym=0; sym<LEN_WINDOW; sym++)
		{
			symbol=left_window[sym];
			symbol_kod=code_of_the_symbol(symbol);
			
			if(symbol_kod != -1)
			{
				for( s=0; s<DIMENSION; s++)
				{
					pom=0;
					for( c=0; c<DIMENSION; c++)
						pom=pom+A[symbol_kod][s][c]*X_pov[c];
					
					X[s]=pom + T[symbol_kod][s];
					
					if (sym == LEN_WINDOW-1)
						sym_left_csr[s]=X[s];
				} 
				
				for(s=0; s<DIMENSION; s++)
					X_pov[s]=X[s];
			}
		} 
		
		/* map the right_window as a point in the factal RIGHT CSR */
		for( s=0; s<DIMENSION; s++)
			X_pov[s]=0.5;

		for(sym=LEN_WINDOW; sym>0; sym--)
		{
			symbol=right_window[sym-1];
			symbol_kod=code_of_the_symbol(symbol);
			
			if(symbol_kod != -1)
			{
				for(s=0;s<DIMENSION;s++)
				{
					pom=0;
					
					for(c=0;c<DIMENSION;c++)
						pom=pom+A[symbol_kod][s][c]*X_pov[c];
					
					X[s]=pom+T[symbol_kod][s];
					
					if (sym==1)
						sym_right_csr[s]=X[s];
				}

				for(s=0;s<DIMENSION;s++)
					X_pov[s]=X[s];
			}
		}    
		
		/* compuite the distance of the point sym_left_csr from the fractal LEFT CSR of the training set 
		and the distance of the point sym_right_csr from the training set fractal RIGHT CSR */
		left_min_dist=min_left_dist_from_codebook(sym_left_csr);
		right_min_dist=min_right_dist_from_codebook(sym_right_csr); 
		printf("\nmin. distance: left=%f right=%f",left_min_dist, right_min_dist);
		
		/* if the distances are high, corrections are needed */
		if ((left_min_dist >= LEFT_DIST_THRESHOLD) || 
			(right_min_dist >= RIGHT_DIST_THRESHOLD && right_min_dist <= MAX_RIGHT_DIST_THRESHOLD &&
			left_min_dist >= MIN_LEFT_DIST_THRESHOLD))
		{ 
			if(BackTrack==0)
			{
				if((find_better_symbol(&field_of_winner1[0]))&&(field_of_winner1[0]!=CORRECTED_TEXT[sym_pos-1]))
				{
					BackTrack++;
					printf("\n\nMaking corrections...\n");
					field_of_winner1[5]=CORRECTED_TEXT[sym_pos-1];
					CORRECTED_TEXT[sym_pos-1]=field_of_winner1[0];
				}
			}
			else
			{
				if(BackTrack==1)
				{
					if((find_better_symbol(&field_of_winner2[0]))&&(field_of_winner2[0]!=CORRECTED_TEXT[sym_pos-1]))
					{	
						BackTrack++;
						printf("\n\nMaking corrections...\n");
//						find_better_symbol(&field_of_winner2[0]);
//
 						if(PocetOprav==0)
							field_of_winner2[5]=CORRECTED_TEXT[sym_pos-1];

						CORRECTED_TEXT[sym_pos-1]=field_of_winner2[0];
					}
					else
					{
						if(PocetOprav==0)
						{
							field_of_winner2[5]=CORRECTED_TEXT[sym_pos-1];
							BackTrack++;
						}
						else
						{
							BackTrack++;
						}

						//CORRECTED_TEXT[sym_pos-1]=field_of_winner2[0];

					}
				}
				else
				{				
					if(BackTrack==2)
					{
						sym_pos-=2;

						if(PocetOprav!=4)
						{
							CORRECTED_TEXT[sym_pos-1]=field_of_winner1[PocetOprav+1];
							CORRECTED_TEXT[sym_pos]=field_of_winner2[5];
							printf("\nBackTracking...\n");
							BackTrack=1;
							PocetOprav++;
						}
						else
						{
							printf("\nBackTracking FAIL...\n");
							CORRECTED_TEXT[sym_pos-1]=field_of_winner1[5];
							CORRECTED_TEXT[sym_pos]=field_of_winner2[5];
							BackTrack=0;
							PocetOprav=0;							
						}
					}
				}
			}
		}
		else
		{
			printf("\nNerobimOpravy...");
			BackTrack=0;
			PocetOprav=0;
		}

		
	} /* end for - the main loop */
	
	fp_corr=otvor_subor("correct.txt","w");
	printf("\n\nCorrected text:\n");
	
	for(sym=1; sym<=length_corrupted_text; sym++)
	{
		fprintf(fp_corr,"%c", CORRECTED_TEXT[sym-1]);
		
		if(CORRECTED_TEXT[sym-1] != '+')
			printf("%c", CORRECTED_TEXT[sym-1]);
		else
			printf(" ");
	}  

	printf("\n\n");
	fclose(fp_corr);
	free_memory();
}

FILE *otvor_subor(char *nazov_sub, char *mod)
{ 
	FILE *fp;
	
	fp=fopen(nazov_sub, mod);
	
	if(fp == NULL)
	{
		printf("\ncan't find file %s !",nazov_sub);
		exit(0);
	}
	
	return(fp);
}

int code_of_the_symbol(char symbol)  /* returns -1 if does not find the symbol */
{ 
	int i,code,found;
	
	found=0;
	code=0;

	for(i=0; i<NUM_SYMBOLS; i++)
	{ 
		if (SYM_CODE[i]==symbol)
		{ 
			code=i;
			found=1;
		}
	}

	if (found==0) code=-1;

	return(code);
}

int read_k_symbols_from_file(FILE *fp, char *string, int k)
{
	int  i,symbol_int;
	char aux_string[2];
	
	for(i=1; i<=k; i++)
	{
		do
		{
			symbol_int=fgetc(fp);
			sprintf(aux_string,"%c",symbol_int);
		}
		while(!((aux_string[0]>='A' && aux_string[0]<='z') || (symbol_int == EOF) || (aux_string[0]>='+')));
		
		*(string+i-1)=aux_string[0];
	}

	*(string+k)='\0';
	return(symbol_int);
}

float min_left_dist_from_codebook(float *point)
{
	int   i;
	long  j;
	float sum, lmd;
	
	lmd=MAXFLOAT;
	
	for(j=1; j<=left_num_codebooks; j++)
	{ 
		sum=0;
		for(i=1; i<=DIMENSION; i++)
			sum=sum+pow_2(point[i-1]-W_left[j-1][i-1]);
		if(sum < lmd)
			lmd=sum;
	} 
	
	return((float)sqrt(lmd));
}

float min_right_dist_from_codebook(float *point)
{ 
	int   i;
	long  j;
	float sum, rmd;
	
	rmd=MAXFLOAT;
	
	for(j=1; j<=right_num_codebooks; j++)
	{ 
		sum=0;
		
		for(i=1; i<=DIMENSION; i++)
			sum=sum+pow_2(point[i-1]-W_right[j-1][i-1]);
		
		if(sum < rmd)
			rmd=sum;
	}
	
	return((float)sqrt(rmd));
}

int ini_koh_weights_file(void)
{
	int  i,ep;
	long  j;
	FILE *fp;
	
	fp=otvor_subor(left_codebooks,"r");
	
	for (j=1;j<=left_num_codebooks;j++)
	{
		for (i=1;i<=DIMENSION;i++)
			fscanf(fp,"%f ",&(W_left[j-1][i-1]));
		
		fscanf(fp,"\n"); 
	}
	
	fclose(fp);
	
	fp=otvor_subor(right_codebooks,"r");
	for (j=1;j<=right_num_codebooks;j++)
	{ 
		for (i=1;i<=DIMENSION;i++)
			fscanf(fp,"%f ",&(W_right[j-1][i-1]));
		
		fscanf(fp,"\n"); 
	}
	
	fclose(fp);
	ep=1;
	/* report_koh_weights(); */
	return(ep);
}

void report_koh_weights(void)
{
	int  i;
	long  j;
	
	printf("\n\nLEFT QUANTIZATION CENTERS:\n");
	
	for (j=1;j<=left_num_codebooks;j++)
	{
		for (i=1;i<=DIMENSION;i++)
			printf("%f ",W_left[j-1][i-1]);
		
		printf("\n"); 
	}
	
	printf("\n\nRIGHT QUANTIZATION CENTERS:\n");
	
	for (j=1;j<=right_num_codebooks;j++)
	{
		for (i=1;i<=DIMENSION;i++)
			printf("%f ",W_right[j-1][i-1]);
		
		printf("\n"); 
	} 
}   

float pow_2(float x)
{
	return(x*x);
}

void  allocate_memory(void)
{
	int i,j;
/* ++++++++++++++++++++++++++++ A +++++++++++++++++++++++++++++++++ */
	if ((A=malloc((NUM_SYMBOLS+1)*sizeof(float **))) == NULL)
    {
		printf("\nNot enough memory when allocating ***A\n");
		exit(1);
    }
	
	for (i = 1; i <= NUM_SYMBOLS; i++)
		if ((A[i-1]=malloc((DIMENSION+1)*sizeof(float *))) == NULL)
		{
			printf("\nNot enough memory when allocating **A[%d]\n",i-1);
			exit(1);
		}

	for(i = 1; i <= NUM_SYMBOLS; i++)
	{
		for (j = 1; j <= DIMENSION; j++)
			if ((A[i-1][j-1]=malloc((DIMENSION+1)*sizeof(float))) == NULL)
			{ 
				printf("\nNot enough memory when allocating *A[%d][%d]\n",i-1, j-1);
				exit(1);
			}
	}
/* ++++++++++++++++++++++++++++ T +++++++++++++++++++++++++++++++++ */
	if((T=malloc((NUM_SYMBOLS+1)*sizeof(float *))) == NULL)
	{
		printf("\nNot enough memory when allocating **T\n");
		exit(1);
	}
	for(i = 1; i <= NUM_SYMBOLS; i++)
		if((T[i-1]=malloc((DIMENSION+1)*sizeof(float ))) == NULL)
		{ 
			printf("\nNot enough memory when allocating *T[%d]\n",i-1);
			exit(1);
		}

/* ++++++++++++++++++++++++++++ W_left +++++++++++++++++++++++++++++++++ */
	if((W_left=malloc((left_num_codebooks+1)*sizeof(float *))) == NULL)
	{ 
		printf("\nNot enough memory when allocating **W_left\n");
		exit(1);
	}
	
	for(i = 1; i <= left_num_codebooks; i++)
		if((W_left[i-1]=malloc((DIMENSION+1)*sizeof(float ))) == NULL)
		{
			printf("\nNot enough memory when allocating *W_left[%ld]\n",i-1);
			exit(1);
		}
			
/* ++++++++++++++++++++++++++++ W_right +++++++++++++++++++++++++++++++++ */
	if((W_right=malloc((right_num_codebooks+1)*sizeof(float *))) == NULL)
	{ 
		printf("\nNot enough memory when allocating **W_right\n");
		exit(1);
	}
	
	for(i = 1; i <= right_num_codebooks; i++)
		if((W_right[i-1]=malloc((DIMENSION+1)*sizeof(float ))) == NULL)
		{ 
			printf("\nNot enough memory when allocating *W_right[%ld]\n",i-1);
			exit(1);
		}
}

void free_memory(void)
{
	free(T);
	free(A);
	free(W_left);
	free(W_right); 
}

void report_parameters(void)
{
	printf("\n\nPARAMETERS");
	printf("\ncorrupted text in %s",corrupt_text);
	printf("\n# of codebooks covering left csr: %ld",left_num_codebooks);
	printf("\ncodebooks covering left csr in %s",left_codebooks);
	printf("\n# of codebooks covering right csr: %ld",right_num_codebooks);
	printf("\ncodebooks covering right csr in %s",right_codebooks);
	printf("\nsymbol coeficients in %s",symb_coef);
	printf("\nleft distance threshold: %f",LEFT_DIST_THRESHOLD);
	printf("\nmin. left distance threshold to consider: %f",MIN_LEFT_DIST_THRESHOLD);
	printf("\nright distance threshold: %f",RIGHT_DIST_THRESHOLD);
	printf("\nmin. right distance threshold to consider : %f",MIN_RIGHT_DIST_THRESHOLD);
	printf("\nmax. right distance threshold to consider : %f",MAX_RIGHT_DIST_THRESHOLD);
	printf("\nscaling coef. for right distance: %f",SCALE_RIGHT);
	printf("\nlength of input window: %d",LEN_WINDOW);
	printf("\nnumber of symbols in the alphabet: %d",NUM_SYMBOLS);
	printf("\ndimension of csr: %d",DIMENSION);
}

void report_parameters_cst(void)
{
	int sym,r,c;
	
	printf("\n\nParameters of %s", symb_coef);
	
	for(sym=1;sym<=NUM_SYMBOLS;sym++)
	{ 
		printf("\nSYMBOL: %c", SYM_CODE[sym-1]);
		
		for(r=1;r<=DIMENSION;r++)
		{
			printf("\n");
			
			for(c=1;c<=DIMENSION;c++)
				printf("A%d,%d=%1.2f ",r,c,A[sym-1][r-1][c-1]);
			
			printf("T%d=%1.2f",r,T[sym-1][r-1]);
		}
	}
}                                                  

void allocate_memory_read_symbol_codes(void)
{
	FILE *fp_csi;
	int  sym,
		r,c,
		pomd;
	char symbol;
	
	fp_csi=otvor_subor(symb_coef,"r");
	fscanf(fp_csi,"\nLENGTH OF INPUT WINDOW: %d",&LEN_WINDOW);
	fscanf(fp_csi,"\nNUMBER OF SYMBOLS IN THE ALPHABET: %d",&NUM_SYMBOLS);
	fscanf(fp_csi,"\nDIMENSION: %d",&DIMENSION);
	report_parameters();
	
	allocate_memory();
	
	for( sym=1; sym<=NUM_SYMBOLS; sym++)
	{
		fscanf(fp_csi,"\nSYMBOL %c - COEFFICIENTS OF THE AFFINE MAPPING:",&symbol);
		SYM_CODE[sym-1]=symbol;
		
		for(r=1;r<=DIMENSION;r++)
		{ 
			fscanf(fp_csi,"\n");
			
			for(c=1;c<=DIMENSION;c++)
				fscanf(fp_csi,"A%d,%d=%f ",&pomd,&pomd,&(A[sym-1][r-1][c-1]));
			
			fscanf(fp_csi,"T%d=%f",&pomd,&(T[sym-1][r-1]));
		}
	}
	
	fclose(fp_csi);
	/* report_parameters_cst(); */
}

int find_better_symbol(char *win_symbol)
{
	int   symb,sym,s,c,i,j,pom_index,symbol_kod;
	float pom,pom_min_dist;
	char  symbol;
	float best_min_dist_pom[27],
		 left_min_dist_pom[27],
		 right_min_dist_pom[27],
		 left_min_dist[5],
		 right_min_dist[5],
		 best_min_dist[5];
	char win_symbol_pom[27];
	long NUM_CONTEXTS_BELLOW_THRESHOLD,
		 NUM_RIGHT_CONTEXTS_BELLOW_THRESHOLD,
         NUM_LEFT_CONTEXTS_BELLOW_THRESHOLD;
            
	NUM_CONTEXTS_BELLOW_THRESHOLD=1;//new
	NUM_RIGHT_CONTEXTS_BELLOW_THRESHOLD=0;
	NUM_LEFT_CONTEXTS_BELLOW_THRESHOLD=0;
	//best_min_dist=MAXFLOAT;
	//win_symbol=left_window[LEN_WINDOW-1];	//new
	/* check all the symbols */
	for(symb=0; symb<NUM_SYMBOLS; symb++)
	{ /* left window first */
		left_window[LEN_WINDOW-1]=SYM_CODE[symb];
		/* compute a point in CSR corresponding to the left window */
		
		for(s=0; s<DIMENSION; s++)
			X_pov[s]=0.5;
		
		for(sym=0;sym<LEN_WINDOW;sym++)
		{
			symbol=left_window[sym];
			symbol_kod=code_of_the_symbol(symbol);
			
			if (symbol_kod != -1)
			{
				for( s=0; s<DIMENSION; s++)
				{
					pom=0;
					
					for(c=0;c<DIMENSION;c++)
						pom=pom+A[symbol_kod][s][c]*X_pov[c];
					
					X[s]=pom + T[symbol_kod][s];
					
					if(sym == LEN_WINDOW-1)
						sym_left_csr[s]=X[s];
				}
				
				for(s=0;s<DIMENSION;s++)
					X_pov[s]=X[s];
			}
			else
			{
				printf("\n\ncan't find a code for the symbol %c!\n", symbol);
				exit(-1);
			}
		}
		
		/* now the right window */
		right_window[0]=SYM_CODE[symb];
		/* compute a point in CSR corresponding to the right window */
		
		for(s=0; s<DIMENSION; s++)
			X_pov[s]=0.5;
		
		for(sym=LEN_WINDOW; sym>0; sym--)
		{
			symbol=right_window[sym-1];
			symbol_kod=code_of_the_symbol(symbol);
			if (symbol_kod != -1)
			{
				for(s=0;s<DIMENSION;s++)
				{
					pom=0;
					
					for(c=0;c<DIMENSION;c++)
						pom=pom+A[symbol_kod][s][c]*X_pov[c];
					
					X[s]=pom + T[symbol_kod][s];
					
					if (sym == 1)
						sym_right_csr[s]=X[s];
				}
				
				for(s=0;s<DIMENSION;s++)
					X_pov[s]=X[s];
			}
			else
			{
				printf("\n\ncan't find a code for the symbol %c!\n", symbol);
				exit(-1);
			}
		}
   		/* compuite the distance of the point sym_left_csr from the fractal LEFT CSR of the training set 
		and the distance of the point sym_right_csr from the training set fractal RIGHT CSR */
		left_min_dist_pom[symb]=min_left_dist_from_codebook(sym_left_csr);
		right_min_dist_pom[symb]=min_right_dist_from_codebook(sym_right_csr);
		best_min_dist_pom[symb]=left_min_dist_pom[symb] + SCALE_RIGHT*right_min_dist_pom[symb];
		win_symbol_pom[symb]=left_window[LEN_WINDOW-1];
	}// end for - check all the symbols 

	for(i=0;i<NUM_SYMBOLS;i++)
	{
		printf("%c:%f\t",win_symbol_pom[i],best_min_dist_pom[i]);
		if(!i%4) printf("\n");
	}

	for(i=0;i<5;i++)
	{
		pom_min_dist=best_min_dist_pom[NUM_SYMBOLS-1];
		pom_index=NUM_SYMBOLS-1;

		for(j=NUM_SYMBOLS-2;j>=i;j--)
		{
			if(best_min_dist_pom[j]<pom_min_dist)
			{
				pom_min_dist=best_min_dist_pom[j];
				pom_index=j;
			}
		}

		best_min_dist_pom[pom_index]=1;
		best_min_dist[i]=pom_min_dist;
		win_symbol[i]=win_symbol_pom[pom_index];
		left_min_dist[i]=left_min_dist_pom[pom_index];
		right_min_dist[i]=right_min_dist_pom[pom_index];
	}
	
	printf("---------Adepts---------\n");
	
	for(i=0;i<5;i++)
		printf("%c:left:%f  right:%f  best:%f\n",win_symbol[i],left_min_dist[i], right_min_dist[i],best_min_dist[i]);

	if((left_min_dist[0] >= LEFT_DIST_THRESHOLD) || 
			(right_min_dist[0] >= RIGHT_DIST_THRESHOLD && right_min_dist[0] <= MAX_RIGHT_DIST_THRESHOLD &&
			left_min_dist[0] >= MIN_LEFT_DIST_THRESHOLD))
			return 0;
	return 1;

}
