function [ret,x0,str,ts,xts]=mlps(t,x,u,flag);
%MLPS	is the M-file description of the SIMULINK system named MLPS.
%	The block-diagram can be displayed by typing: MLPS.
%
%	SYS=MLPS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes MLPS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling MLPS with a FLAG of zero:
%	[SIZES]=MLPS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,730,452])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '0.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'Delay Time','0.18',...
		'position',[285,40,325,70])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[20,40,40,60])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[85,45,105,65])


%     Subsystem  'PID Controller'.

new_system([sys,'/','PID Controller'])
set_param([sys,'/','PID Controller'],'Location',[0,0,362,244])

add_block('built-in/Sum',[sys,'/','PID Controller/Sum'])
set_param([sys,'/','PID Controller/Sum'],...
		'inputs','+++',...
		'position',[245,57,265,93])

add_block('built-in/Gain',[sys,'/','PID Controller/D'])
set_param([sys,'/','PID Controller/D'],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Gain',[sys,'/','PID Controller/Proportional'])
set_param([sys,'/','PID Controller/Proportional'],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Transfer Fcn',[sys,'/','PID Controller/Integral'])
set_param([sys,'/','PID Controller/Integral'],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Derivative',[sys,'/','PID Controller/Derivative'])
set_param([sys,'/','PID Controller/Derivative'],...
		'position',[150,128,190,152])

add_block('built-in/Outport',[sys,'/','PID Controller/Out_1'])
set_param([sys,'/','PID Controller/Out_1'],...
		'position',[290,65,310,85])

add_block('built-in/Inport',[sys,'/','PID Controller/In_1'])
set_param([sys,'/','PID Controller/In_1'],...
		'position',[25,65,45,85])
add_line([sys,'/','PID Controller'],[120,140;145,140])
add_line([sys,'/','PID Controller'],[270,75;285,75])
add_line([sys,'/','PID Controller'],[50,75;105,75])
add_line([sys,'/','PID Controller'],[65,75;65,140;90,140])
add_line([sys,'/','PID Controller'],[80,75;80,25;115,25])
add_line([sys,'/','PID Controller'],[195,140;215,140;215,85;240,85])
add_line([sys,'/','PID Controller'],[150,75;240,75])
add_line([sys,'/','PID Controller'],[145,25;210,25;210,65;240,65])
set_param([sys,'/','PID Controller'],...
		'Mask Display','PID',...
		'Mask Type','PID Controller',...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:')
set_param([sys,'/','PID Controller'],...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/','PID Controller'],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/','PID Controller'],...
		'Mask Entries','P\/I\/D\/')


%     Finished composite block 'PID Controller'.

set_param([sys,'/','PID Controller'],...
		'position',[135,39,175,71])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'Numerator','[0.5 1]',...
		'Denominator','[0.5 0.55 1]',...
		'position',[205,35,265,75])

add_block('built-in/Saturation',[sys,'/','Saturation'])
set_param([sys,'/','Saturation'],...
		'Lower Limit','-1000000',...
		'Upper Limit','1000000',...
		'position',[350,43,380,67])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'buffer','10000',...
		'position',[480,47,530,63])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'mat-name','ys',...
		'buffer','10000',...
		'position',[495,232,545,248])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn1'])
set_param([sys,'/','Transfer Fcn1'],...
		'Numerator','[0.5 1]',...
		'Denominator','[0.5 0.55 1]',...
		'position',[220,220,280,260])


%     Subsystem  'PID Controller1'.

new_system([sys,'/','PID Controller1'])
set_param([sys,'/','PID Controller1'],'Location',[0,0,362,244])

add_block('built-in/Inport',[sys,'/','PID Controller1/In_1'])
set_param([sys,'/','PID Controller1/In_1'],...
		'position',[25,65,45,85])

add_block('built-in/Outport',[sys,'/','PID Controller1/Out_1'])
set_param([sys,'/','PID Controller1/Out_1'],...
		'position',[290,65,310,85])

add_block('built-in/Derivative',[sys,'/','PID Controller1/Derivative'])
set_param([sys,'/','PID Controller1/Derivative'],...
		'position',[150,128,190,152])

add_block('built-in/Transfer Fcn',[sys,'/','PID Controller1/Integral'])
set_param([sys,'/','PID Controller1/Integral'],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Gain',[sys,'/','PID Controller1/Proportional'])
set_param([sys,'/','PID Controller1/Proportional'],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Gain',[sys,'/','PID Controller1/D'])
set_param([sys,'/','PID Controller1/D'],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Sum',[sys,'/','PID Controller1/Sum'])
set_param([sys,'/','PID Controller1/Sum'],...
		'inputs','+++',...
		'position',[245,57,265,93])
add_line([sys,'/','PID Controller1'],[145,25;210,25;210,65;240,65])
add_line([sys,'/','PID Controller1'],[150,75;240,75])
add_line([sys,'/','PID Controller1'],[195,140;215,140;215,85;240,85])
add_line([sys,'/','PID Controller1'],[50,75;105,75])
add_line([sys,'/','PID Controller1'],[80,75;80,25;115,25])
add_line([sys,'/','PID Controller1'],[65,75;65,140;90,140])
add_line([sys,'/','PID Controller1'],[270,75;285,75])
add_line([sys,'/','PID Controller1'],[120,140;145,140])
set_param([sys,'/','PID Controller1'],...
		'Mask Display','PID',...
		'Mask Type','PID Controller',...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:')
set_param([sys,'/','PID Controller1'],...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/','PID Controller1'],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/','PID Controller1'],...
		'Mask Entries','0.8\/1.05\/0.7\/')


%     Finished composite block 'PID Controller1'.

set_param([sys,'/','PID Controller1'],...
		'position',[150,224,190,256])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'inputs','+-',...
		'position',[100,230,120,250])

add_block('built-in/Step Fcn',[sys,'/','Step Input1'])
set_param([sys,'/','Step Input1'],...
		'Time','0',...
		'position',[35,225,55,245])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay1']])
set_param([sys,'/',['Transport',13,'Delay1']],...
		'Delay Time','0.18',...
		'position',[300,225,340,255])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'mat-name','t',...
		'buffer','10000',...
		'position',[65,182,115,198])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[20,180,40,200])

add_block('built-in/To Workspace',[sys,'/','dde'])
set_param([sys,'/','dde'],...
		'mat-name','dde',...
		'buffer','10000',...
		'position',[295,172,345,188])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'mat-name','de',...
		'buffer','10000',...
		'position',[295,135,345,155])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','e',...
		'buffer','10000',...
		'position',[295,107,345,123])

add_block('built-in/Derivative',[sys,'/','Derivative1'])
set_param([sys,'/','Derivative1'],...
		'position',[215,170,245,190])

add_block('built-in/Derivative',[sys,'/','Derivative'])
set_param([sys,'/','Derivative'],...
		'position',[145,135,175,155])
add_line(sys,[45,50;80,50])
add_line(sys,[110,55;130,55])
add_line(sys,[180,55;200,55])
add_line(sys,[110,55;115,55;115,115;290,115])
add_line(sys,[270,55;280,55])
add_line(sys,[330,55;345,55])
add_line(sys,[385,55;475,55])
add_line(sys,[385,55;410,55;410,105;65,105;65,60;80,60])
add_line(sys,[45,190;60,190])
add_line(sys,[345,240;420,240;420,305;80,305;80,245;95,245])
add_line(sys,[285,240;295,240])
add_line(sys,[195,240;215,240])
add_line(sys,[125,240;145,240])
add_line(sys,[60,235;95,235])
add_line(sys,[345,240;490,240])
add_line(sys,[250,180;290,180])
add_line(sys,[115,115;115,145;140,145])
add_line(sys,[180,145;290,145])
add_line(sys,[180,145;190,145;190,180;210,180])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
