function [ret,x0,str,ts,xts]=acmodam(t,x,u,flag);
%ACMODAM	is the M-file description of the SIMULINK system named ACMODAM.
%	The block-diagram can be displayed by typing: ACMODAM.
%
%	SYS=ACMODAM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes ACMODAM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling ACMODAM with a FLAG of zero:
%	[SIZES]=ACMODAM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[209,405,822,705])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'I_model AM'.

new_system([sys,'/','I_model AM'])
set_param([sys,'/','I_model AM'],'Location',[4,70,870,589])
open_system([sys,'/','I_model AM'])

add_block('built-in/Inport',[sys,'/','I_model AM/in_2'])
set_param([sys,'/','I_model AM/in_2'],...
		'Port','2',...
		'position',[30,90,50,110])

add_block('built-in/Transfer Fcn',[sys,'/','I_model AM/Transfer Fcn'])
set_param([sys,'/','I_model AM/Transfer Fcn'],...
		'Numerator','[Tr]',...
		'Denominator','[Tr 1]',...
		'position',[235,85,285,125])

add_block('built-in/Sum',[sys,'/','I_model AM/Sum2'])
set_param([sys,'/','I_model AM/Sum2'],...
		'inputs','+-',...
		'position',[195,95,215,115])

add_block('built-in/Product',[sys,'/','I_model AM/Product2'])
set_param([sys,'/','I_model AM/Product2'],...
		'orientation',3,...
		'position',[163,295,207,320])

add_block('built-in/Product',[sys,'/','I_model AM/Product'])
set_param([sys,'/','I_model AM/Product'],...
		'position',[340,95,365,130])

add_block('built-in/Product',[sys,'/','I_model AM/Product1'])
set_param([sys,'/','I_model AM/Product1'],...
		'position',[340,205,365,240])

add_block('built-in/Inport',[sys,'/','I_model AM/in_3'])
set_param([sys,'/','I_model AM/in_3'],...
		'Port','3',...
		'position',[30,215,50,235])

add_block('built-in/Product',[sys,'/','I_model AM/Product3'])
set_param([sys,'/','I_model AM/Product3'],...
		'orientation',3,...
		'position',[88,295,132,320])

add_block('built-in/Gain',[sys,'/','I_model AM/Gain7'])
set_param([sys,'/','I_model AM/Gain7'],...
		'Gain','Lm/Tr',...
		'position',[135,187,185,263])

add_block('built-in/Gain',[sys,'/','I_model AM/Gain6'])
set_param([sys,'/','I_model AM/Gain6'],...
		'Gain','Lm/Tr',...
		'position',[130,62,180,138])

add_block('built-in/Inport',[sys,'/','I_model AM/in_1'])
set_param([sys,'/','I_model AM/in_1'],...
		'position',[30,36,50,54])

add_block('built-in/Note',[sys,'/','I_model AM/Mz'])
set_param([sys,'/','I_model AM/Mz'],...
		'position',[75,25,80,30])

add_block('built-in/To Workspace',[sys,'/','I_model AM/To Workspace'])
set_param([sys,'/','I_model AM/To Workspace'],...
		'mat-name','Mm',...
		'buffer','100000',...
		'position',[540,212,590,228])

add_block('built-in/Outport',[sys,'/','I_model AM/out_5'])
set_param([sys,'/','I_model AM/out_5'],...
		'Port','5',...
		'position',[560,0,580,20])

add_block('built-in/Outport',[sys,'/','I_model AM/out_1'])
set_param([sys,'/','I_model AM/out_1'],...
		'position',[825,45,845,65])

add_block('built-in/Note',[sys,'/','I_model AM/omega-m'])
set_param([sys,'/','I_model AM/omega-m'],...
		'position',[800,20,805,25])

add_block('built-in/Outport',[sys,'/','I_model AM/out_2'])
set_param([sys,'/','I_model AM/out_2'],...
		'Port','2',...
		'position',[830,105,850,125])

add_block('built-in/Note',[sys,'/','I_model AM/omega'])
set_param([sys,'/','I_model AM/omega'],...
		'position',[805,85,810,90])

add_block('built-in/Outport',[sys,'/','I_model AM/out_3'])
set_param([sys,'/','I_model AM/out_3'],...
		'Port','3',...
		'position',[830,155,850,175])

add_block('built-in/Outport',[sys,'/','I_model AM/out_4'])
set_param([sys,'/','I_model AM/out_4'],...
		'Port','4',...
		'position',[825,275,845,295])

add_block('built-in/Note',[sys,'/','I_model AM/PSI rb'])
set_param([sys,'/','I_model AM/PSI rb'],...
		'position',[775,265,780,270])

add_block('built-in/Note',[sys,'/','I_model AM/PSI ral'])
set_param([sys,'/','I_model AM/PSI ral'],...
		'position',[780,140,785,145])

add_block('built-in/Integrator',[sys,'/','I_model AM/Integrator'])
set_param([sys,'/','I_model AM/Integrator'],...
		'position',[690,105,710,125])

add_block('built-in/Gain',[sys,'/','I_model AM/Gain5'])
set_param([sys,'/','I_model AM/Gain5'],...
		'Gain','p/J',...
		'position',[610,88,640,142])

add_block('built-in/Sum',[sys,'/','I_model AM/Sum'])
set_param([sys,'/','I_model AM/Sum'],...
		'inputs','-+',...
		'position',[565,105,585,125])

add_block('built-in/Gain',[sys,'/','I_model AM/Gain'])
set_param([sys,'/','I_model AM/Gain'],...
		'Gain','3/2*p*kr',...
		'position',[430,94,505,146])

add_block('built-in/Sum',[sys,'/','I_model AM/Sum1'])
set_param([sys,'/','I_model AM/Sum1'],...
		'inputs','+-',...
		'position',[395,110,415,130])

add_block('built-in/Transfer Fcn',[sys,'/','I_model AM/Transfer Fcn1'])
set_param([sys,'/','I_model AM/Transfer Fcn1'],...
		'Numerator','[Tr]',...
		'Denominator','[Tr 1]',...
		'position',[240,210,290,250])

add_block('built-in/Sum',[sys,'/','I_model AM/Sum3'])
set_param([sys,'/','I_model AM/Sum3'],...
		'position',[200,220,220,240])

add_block('built-in/Note',[sys,'/','I_model AM/isal'])
set_param([sys,'/','I_model AM/isal'],...
		'position',[75,75,80,80])

add_block('built-in/Note',[sys,'/',['I_model AM/isb',13,'']])
set_param([sys,'/',['I_model AM/isb',13,'']],...
		'position',[70,195,75,200])
add_line([sys,'/','I_model AM'],[510,120;560,120])
add_line([sys,'/','I_model AM'],[517,120;515,220;535,220])
add_line([sys,'/','I_model AM'],[510,120;510,10;555,10])
add_line([sys,'/','I_model AM'],[370,225;380,225;390,125])
add_line([sys,'/','I_model AM'],[55,45;550,45;560,110])
add_line([sys,'/','I_model AM'],[715,115;825,115])
add_line([sys,'/','I_model AM'],[55,225;130,225])
add_line([sys,'/','I_model AM'],[120,225;120,175;260,175;315,120;335,120])
add_line([sys,'/','I_model AM'],[185,290;195,235])
add_line([sys,'/','I_model AM'],[225,230;235,230])
add_line([sys,'/','I_model AM'],[220,105;230,105])
add_line([sys,'/','I_model AM'],[370,115;390,115])
add_line([sys,'/','I_model AM'],[420,120;425,120])
add_line([sys,'/','I_model AM'],[590,115;605,115])
add_line([sys,'/','I_model AM'],[645,115;685,115])
add_line([sys,'/','I_model AM'],[715,115;715,370;100,370;100,325])
add_line([sys,'/','I_model AM'],[175,370;175,325])
add_line([sys,'/','I_model AM'],[290,105;335,105])
add_line([sys,'/','I_model AM'],[320,105;320,335;195,325])
add_line([sys,'/','I_model AM'],[320,165;825,165])
add_line([sys,'/','I_model AM'],[645,115;645,55;820,55])
add_line([sys,'/','I_model AM'],[190,225;195,225])
add_line([sys,'/','I_model AM'],[185,100;190,100])
add_line([sys,'/','I_model AM'],[295,230;335,230])
add_line([sys,'/','I_model AM'],[300,230;300,345;120,345;120,325])
add_line([sys,'/','I_model AM'],[300,285;820,285])
add_line([sys,'/','I_model AM'],[110,290;110,150;180,150;190,110])
add_line([sys,'/','I_model AM'],[55,100;125,100])
add_line([sys,'/','I_model AM'],[95,100;95,165;260,165;310,215;335,215])
set_param([sys,'/','I_model AM'],...
		'Mask Display','I-MODEL  AM')


%     Finished composite block 'I_model AM'.

set_param([sys,'/','I_model AM'],...
		'position',[395,5,530,205])


%     Subsystem  'Trans U-I'.

new_system([sys,'/','Trans U-I'])
set_param([sys,'/','Trans U-I'],'Location',[10,58,750,679])

add_block('built-in/Inport',[sys,'/','Trans U-I/in_2'])
set_param([sys,'/','Trans U-I/in_2'],...
		'Port','2',...
		'position',[30,150,50,170])

add_block('built-in/Transfer Fcn',[sys,'/','Trans U-I/Transfer Fcn2'])
set_param([sys,'/','Trans U-I/Transfer Fcn2'],...
		'Numerator','[1/R1]',...
		'Denominator','[T1 1]',...
		'position',[210,281,270,319])

add_block('built-in/Gain',[sys,'/','Trans U-I/Gain2'])
set_param([sys,'/','Trans U-I/Gain2'],...
		'orientation',2,...
		'Gain','kr',...
		'position',[165,219,195,261])

add_block('built-in/Product',[sys,'/','Trans U-I/Product3'])
set_param([sys,'/','Trans U-I/Product3'],...
		'orientation',2,...
		'position',[235,229,260,251])

add_block('built-in/Note',[sys,'/','Trans U-I/omega'])
set_param([sys,'/','Trans U-I/omega'],...
		'position',[80,315,85,320])

add_block('built-in/Sum',[sys,'/','Trans U-I/Sum4'])
set_param([sys,'/','Trans U-I/Sum4'],...
		'inputs','-++',...
		'position',[140,276,160,324])

add_block('built-in/Product',[sys,'/','Trans U-I/Product6'])
set_param([sys,'/','Trans U-I/Product6'],...
		'orientation',2,...
		'position',[235,159,260,181])

add_block('built-in/Sum',[sys,'/','Trans U-I/Sum3'])
set_param([sys,'/','Trans U-I/Sum3'],...
		'inputs','+++',...
		'position',[140,91,160,129])

add_block('built-in/Gain',[sys,'/','Trans U-I/Gain5'])
set_param([sys,'/','Trans U-I/Gain5'],...
		'orientation',2,...
		'Gain','kr/Tr',...
		'position',[170,34,220,76])

add_block('built-in/Transfer Fcn',[sys,'/','Trans U-I/Transfer Fcn1'])
set_param([sys,'/','Trans U-I/Transfer Fcn1'],...
		'Numerator','[1/R1]',...
		'Denominator','[T1 1]',...
		'position',[210,91,270,129])

add_block('built-in/Gain',[sys,'/','Trans U-I/Gain1'])
set_param([sys,'/','Trans U-I/Gain1'],...
		'orientation',2,...
		'Gain','kr',...
		'position',[165,149,195,191])

add_block('built-in/Inport',[sys,'/','Trans U-I/in_1'])
set_param([sys,'/','Trans U-I/in_1'],...
		'position',[30,100,50,120])

add_block('built-in/Inport',[sys,'/','Trans U-I/in_6'])
set_param([sys,'/','Trans U-I/in_6'],...
		'Port','3',...
		'position',[30,200,50,220])

add_block('built-in/Inport',[sys,'/','Trans U-I/in_4'])
set_param([sys,'/','Trans U-I/in_4'],...
		'Port','4',...
		'position',[30,255,50,275])

add_block('built-in/Gain',[sys,'/','Trans U-I/Gain6'])
set_param([sys,'/','Trans U-I/Gain6'],...
		'orientation',2,...
		'Gain','kr/Tr',...
		'position',[175,344,225,386])

add_block('built-in/Inport',[sys,'/','Trans U-I/in_8'])
set_param([sys,'/','Trans U-I/in_8'],...
		'Port','5',...
		'position',[30,325,50,345])

add_block('built-in/Outport',[sys,'/','Trans U-I/out_1'])
set_param([sys,'/','Trans U-I/out_1'],...
		'position',[470,100,490,120])

add_block('built-in/Outport',[sys,'/','Trans U-I/out_2'])
set_param([sys,'/','Trans U-I/out_2'],...
		'Port','2',...
		'position',[475,290,495,310])

add_block('built-in/Note',[sys,'/','Trans U-I/isal'])
set_param([sys,'/','Trans U-I/isal'],...
		'position',[445,80,450,85])

add_block('built-in/Note',[sys,'/','Trans U-I/isb'])
set_param([sys,'/','Trans U-I/isb'],...
		'position',[445,270,450,275])

add_block('built-in/Note',[sys,'/','Trans U-I/PSI rb'])
set_param([sys,'/','Trans U-I/PSI rb'],...
		'position',[75,245,80,250])

add_block('built-in/Note',[sys,'/','Trans U-I/PSI ral'])
set_param([sys,'/','Trans U-I/PSI ral'],...
		'position',[70,185,75,190])

add_block('built-in/Note',[sys,'/','Trans U-I/Usb'])
set_param([sys,'/','Trans U-I/Usb'],...
		'position',[65,135,70,140])

add_block('built-in/Note',[sys,'/',['Trans U-I/Usal',13,'']])
set_param([sys,'/',['Trans U-I/Usal',13,'']],...
		'position',[70,85,75,90])
add_line([sys,'/','Trans U-I'],[55,160;100,160;100,300;135,300])
add_line([sys,'/','Trans U-I'],[160,170;125,170;135,120])
add_line([sys,'/','Trans U-I'],[160,240;125,240;135,285])
add_line([sys,'/','Trans U-I'],[275,300;470,300])
add_line([sys,'/','Trans U-I'],[275,110;465,110])
add_line([sys,'/','Trans U-I'],[165,110;205,110])
add_line([sys,'/','Trans U-I'],[165,300;205,300])
add_line([sys,'/','Trans U-I'],[170,365;125,365;135,315])
add_line([sys,'/','Trans U-I'],[165,55;125,55;135,100])
add_line([sys,'/','Trans U-I'],[55,110;135,110])
add_line([sys,'/','Trans U-I'],[230,170;200,170])
add_line([sys,'/','Trans U-I'],[230,240;200,240])
add_line([sys,'/','Trans U-I'],[55,335;305,335;305,175;265,175])
add_line([sys,'/','Trans U-I'],[305,245;265,245])
add_line([sys,'/','Trans U-I'],[55,210;345,210;345,235;265,235])
add_line([sys,'/','Trans U-I'],[345,210;345,55;225,55])
add_line([sys,'/','Trans U-I'],[55,265;325,265;325,365;230,365])
add_line([sys,'/','Trans U-I'],[325,265;325,165;265,165])
set_param([sys,'/','Trans U-I'],...
		'Mask Display','us->is')


%     Finished composite block 'Trans U-I'.

set_param([sys,'/','Trans U-I'],...
		'position',[130,24,270,216])

add_block('built-in/Note',[sys,'/','Mz'])
set_param([sys,'/','Mz'],...
		'position',[380,10,385,15])

add_block('built-in/Note',[sys,'/','Usal'])
set_param([sys,'/','Usal'],...
		'position',[100,15,105,20])

add_block('built-in/Note',[sys,'/','Usb'])
set_param([sys,'/','Usb'],...
		'position',[105,55,110,60])

add_block('built-in/Note',[sys,'/','PSIral'])
set_param([sys,'/','PSIral'],...
		'position',[100,95,105,100])

add_block('built-in/Note',[sys,'/','PSIrb'])
set_param([sys,'/','PSIrb'],...
		'position',[100,140,105,145])

add_block('built-in/Note',[sys,'/','omega'])
set_param([sys,'/','omega'],...
		'position',[100,180,105,185])

add_block('built-in/Note',[sys,'/','omegam'])
set_param([sys,'/','omegam'],...
		'position',[575,0,580,5])

add_block('built-in/Note',[sys,'/','omega_'])
set_param([sys,'/','omega_'],...
		'position',[575,40,580,45])

add_block('built-in/Note',[sys,'/','PSIral_'])
set_param([sys,'/','PSIral_'],...
		'position',[575,80,580,85])

add_block('built-in/Note',[sys,'/','PSIrb_'])
set_param([sys,'/','PSIrb_'],...
		'position',[570,125,575,130])

add_block('built-in/Note',[sys,'/','Mm'])
set_param([sys,'/','Mm'],...
		'position',[560,160,565,165])
add_line(sys,[275,75;390,105])
add_line(sys,[275,170;390,170])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
