function [ret,x0,str,ts,xts]=pianfis1(t,x,u,flag);
%PIANFIS1	is the M-file description of the SIMULINK system named PIANFIS1.
%	The block-diagram can be displayed by typing: PIANFIS1.
%
%	SYS=PIANFIS1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PIANFIS1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PIANFIS1 with a FLAG of zero:
%	[SIZES]=PIANFIS1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,42,795,370])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[5,230,25,250])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'buffer','[50000,0.5]',...
		'position',[55,232,105,248])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'mat-name','y',...
		'buffer','[50000,0.5]',...
		'position',[630,62,680,78])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay1']])
set_param([sys,'/',['Transport',13,'Delay1']],...
		'Delay Time','1',...
		'position',[510,55,550,85])

add_block('built-in/Zero-Pole',[sys,'/','Zero-Pole1'])
set_param([sys,'/','Zero-Pole1'],...
		'Zeros','[-2]',...
		'Poles','[-10; -1]',...
		'position',[395,45,465,95])

add_block('built-in/Gain',[sys,'/','I1'])
set_param([sys,'/','I1'],...
		'Gain','3.5',...
		'position',[335,60,355,80])

add_block('built-in/Scope',[sys,'/','Scope1'])
set_param([sys,'/','Scope1'],...
		'Vgain','3.000000',...
		'Hgain','20.000000',...
		'Vmax','6.000000',...
		'Hmax','40.000000',...
		'Window',[95,0,424,183],...
		'position',[620,110,650,140])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'mat-name','u',...
		'buffer','[50000,0.5]',...
		'position',[345,162,395,178])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'After','0.5',...
		'position',[25,45,45,65])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[190,51,220,84])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'position',[140,65,160,85])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'inputs','+-',...
		'position',[85,50,105,70])

add_block('built-in/S-Function',[sys,'/','FLC1'])
set_param([sys,'/','FLC1'],...
		'function name','sffis',...
		'parameters','fismatrix',...
		'Mask Display','plot(0, -0.3, 6, -0.3, 0, 1.2, 6, 1.2, [0 6], [0 0], [1 2 3],[0 1 0],[2 3 4],[0 1 0],[3 4 5],[0 1 0])',...
		'Mask Type','FIS')
set_param([sys,'/','FLC1'],...
		'Mask Dialogue','FIS|FIS Matrix:',...
		'Mask Translate','fismatrix = @1;',...
		'Mask Help','Fuzzy Inference System',...
		'Mask Entries','nfs\/',...
		'position',[255,54,285,86])
add_line(sys,[30,240;50,240])
add_line(sys,[555,70;625,70])
add_line(sys,[580,70;580,125;615,125])
add_line(sys,[580,125;580,220;70,220;80,65])
add_line(sys,[290,70;330,70])
add_line(sys,[320,70;320,170;340,170])
add_line(sys,[470,70;505,70])
add_line(sys,[360,70;390,70])
add_line(sys,[50,55;80,55])
add_line(sys,[225,70;250,70])
add_line(sys,[110,60;185,60])
add_line(sys,[165,75;185,75])
add_line(sys,[120,60;120,75;135,75])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
