function [ret,x0,str,ts,xts]=pidanfis(t,x,u,flag);
%PIDANFIS	is the M-file description of the SIMULINK system named PIDANFIS.
%	The block-diagram can be displayed by typing: PIDANFIS.
%
%	SYS=PIDANFIS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PIDANFIS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PIDANFIS with a FLAG of zero:
%	[SIZES]=PIDANFIS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[159,239,954,518])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'mat-name','y',...
		'buffer','[50000,0.5]',...
		'position',[665,27,715,43])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'Delay Time','1',...
		'position',[545,20,585,50])

add_block('built-in/Zero-Pole',[sys,'/','Zero-Pole'])
set_param([sys,'/','Zero-Pole'],...
		'Zeros','[-2]',...
		'Poles','[-10; -1]',...
		'position',[430,10,500,60])

add_block('built-in/Gain',[sys,'/','I'])
set_param([sys,'/','I'],...
		'Gain','3.5',...
		'position',[370,25,390,45])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[5,230,25,250])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'buffer','[50000,0.5]',...
		'position',[55,232,105,248])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[200,25,220,45])


%     Subsystem  'PID Controller'.

new_system([sys,'/','PID Controller'])
set_param([sys,'/','PID Controller'],'Location',[4,42,366,286])

add_block('built-in/Sum',[sys,'/','PID Controller/Sum'])
set_param([sys,'/','PID Controller/Sum'],...
		'position',[245,57,265,93])

add_block('built-in/Gain',[sys,'/','PID Controller/Proportional'])
set_param([sys,'/','PID Controller/Proportional'],...
		'Gain','0.85',...
		'position',[120,13,140,37])

add_block('built-in/Transfer Fcn',[sys,'/','PID Controller/Integral'])
set_param([sys,'/','PID Controller/Integral'],...
		'Numerator','[1.05]',...
		'Denominator','[1 0]',...
		'position',[110,67,145,103])

add_block('built-in/Outport',[sys,'/','PID Controller/Out_1'])
set_param([sys,'/','PID Controller/Out_1'],...
		'position',[290,65,310,85])

add_block('built-in/Inport',[sys,'/','PID Controller/In_1'])
set_param([sys,'/','PID Controller/In_1'],...
		'position',[25,75,45,95])

add_block('built-in/To Workspace',[sys,'/','PID Controller/To Workspace3'])
set_param([sys,'/','PID Controller/To Workspace3'],...
		'mat-name','i',...
		'buffer','[50000,0.5]',...
		'position',[260,117,310,133])

add_block('built-in/To Workspace',[sys,'/','PID Controller/To Workspace2'])
set_param([sys,'/','PID Controller/To Workspace2'],...
		'mat-name','e',...
		'buffer','[50000,0.5]',...
		'position',[90,137,140,153])
add_line([sys,'/','PID Controller'],[270,75;285,75])
add_line([sys,'/','PID Controller'],[50,85;105,85])
add_line([sys,'/','PID Controller'],[80,85;80,25;115,25])
add_line([sys,'/','PID Controller'],[150,85;240,85])
add_line([sys,'/','PID Controller'],[185,85;185,125;255,125])
add_line([sys,'/','PID Controller'],[145,25;225,25;225,65;240,65])
add_line([sys,'/','PID Controller'],[50,85;50,145;85,145])


%     Finished composite block 'PID Controller'.

set_param([sys,'/','PID Controller'],...
		'position',[275,19,315,51])

add_block('built-in/Scope',[sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'Vgain','3.000000',...
		'Hgain','20.000000',...
		'Vmax','6.000000',...
		'Hmax','40.000000',...
		'Window',[95,0,424,183])
open_system([sys,'/','Scope'])
set_param([sys,'/','Scope'],...
		'position',[655,75,685,105])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'mat-name','u',...
		'buffer','[50000,0.5]',...
		'position',[380,127,430,143])


%     Subsystem  'Gen'.

new_system([sys,'/','Gen'])
set_param([sys,'/','Gen'],'Location',[105,75,435,405])

add_block('built-in/Outport',[sys,'/','Gen/out_1'])
set_param([sys,'/','Gen/out_1'],...
		'position',[270,155,290,175])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input8'])
set_param([sys,'/','Gen/Step Input8'],...
		'Time','80',...
		'After','0.5',...
		'position',[130,255,150,275])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input7'])
set_param([sys,'/','Gen/Step Input7'],...
		'Time','70',...
		'After','0.5',...
		'position',[80,230,100,250])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input6'])
set_param([sys,'/','Gen/Step Input6'],...
		'Time','60',...
		'After','0.5',...
		'position',[125,200,145,220])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input5'])
set_param([sys,'/','Gen/Step Input5'],...
		'Time','50',...
		'After','-1',...
		'position',[75,180,95,200])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input4'])
set_param([sys,'/','Gen/Step Input4'],...
		'Time','40',...
		'After','-0.5',...
		'position',[130,155,150,175])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input3'])
set_param([sys,'/','Gen/Step Input3'],...
		'Time','30',...
		'After','-0.5',...
		'position',[75,130,95,150])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input2'])
set_param([sys,'/','Gen/Step Input2'],...
		'Time','20',...
		'After','-0.5',...
		'position',[135,105,155,125])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input1'])
set_param([sys,'/','Gen/Step Input1'],...
		'Time','10',...
		'position',[75,80,95,100])

add_block('built-in/Step Fcn',[sys,'/','Gen/Step Input'])
set_param([sys,'/','Gen/Step Input'],...
		'Time','0',...
		'position',[140,55,160,75])

add_block('built-in/Sum',[sys,'/','Gen/Sum'])
set_param([sys,'/','Gen/Sum'],...
		'inputs','+++++++++',...
		'position',[220,58,240,272])
add_line([sys,'/','Gen'],[245,165;265,165])
add_line([sys,'/','Gen'],[155,265;215,265])
add_line([sys,'/','Gen'],[105,240;215,240])
add_line([sys,'/','Gen'],[150,210;175,210;175,215;215,215])
add_line([sys,'/','Gen'],[100,190;215,190])
add_line([sys,'/','Gen'],[155,165;215,165])
add_line([sys,'/','Gen'],[100,140;215,140])
add_line([sys,'/','Gen'],[160,115;215,115])
add_line([sys,'/','Gen'],[100,90;215,90])
add_line([sys,'/','Gen'],[165,65;215,65])
set_param([sys,'/','Gen'],...
		'Mask Display','Generator')


%     Finished composite block 'Gen'.

set_param([sys,'/','Gen'],...
		'position',[45,7,130,53])
add_line(sys,[395,35;425,35])
add_line(sys,[30,240;50,240])
add_line(sys,[505,35;540,35])
add_line(sys,[590,35;660,35])
add_line(sys,[135,30;195,30])
add_line(sys,[320,35;365,35])
add_line(sys,[225,35;270,35])
add_line(sys,[615,35;615,90;650,90])
add_line(sys,[355,35;355,135;375,135])
add_line(sys,[615,90;615,185;170,185;170,40;195,40])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
