function [ret,x0,str,ts,xts]=pranfis(t,x,u,flag);
%PRANFIS	is the M-file description of the SIMULINK system named PRANFIS.
%	The block-diagram can be displayed by typing: PRANFIS.
%
%	SYS=PRANFIS(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PRANFIS to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PRANFIS with a FLAG of zero:
%	[SIZES]=PRANFIS([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[145,413,940,692])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'mat-name','y',...
		'buffer','[50000,1]',...
		'position',[665,27,715,43])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'Delay Time','0.5',...
		'position',[545,20,585,50])

add_block('built-in/Zero-Pole',[sys,'/','Zero-Pole'])
set_param([sys,'/','Zero-Pole'],...
		'Zeros','[-2]',...
		'Poles','[-10; -1]',...
		'position',[430,10,500,60])

add_block('built-in/Gain',[sys,'/','I'])
set_param([sys,'/','I'],...
		'Gain','3.5',...
		'position',[370,25,390,45])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+++++++++',...
		'position',[300,18,320,232])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[220,15,240,35])

add_block('built-in/Step Fcn',[sys,'/','Step Input1'])
set_param([sys,'/','Step Input1'],...
		'Time','10',...
		'position',[155,40,175,60])

add_block('built-in/Step Fcn',[sys,'/','Step Input2'])
set_param([sys,'/','Step Input2'],...
		'Time','20',...
		'After','-0.5',...
		'position',[215,65,235,85])

add_block('built-in/Step Fcn',[sys,'/','Step Input3'])
set_param([sys,'/','Step Input3'],...
		'Time','30',...
		'After','-0.5',...
		'position',[155,90,175,110])

add_block('built-in/Step Fcn',[sys,'/','Step Input4'])
set_param([sys,'/','Step Input4'],...
		'Time','40',...
		'After','-0.5',...
		'position',[210,115,230,135])

add_block('built-in/Step Fcn',[sys,'/','Step Input5'])
set_param([sys,'/','Step Input5'],...
		'Time','50',...
		'After','-1',...
		'position',[155,140,175,160])

add_block('built-in/Step Fcn',[sys,'/','Step Input6'])
set_param([sys,'/','Step Input6'],...
		'Time','60',...
		'After','0.5',...
		'position',[205,160,225,180])

add_block('built-in/Step Fcn',[sys,'/','Step Input7'])
set_param([sys,'/','Step Input7'],...
		'Time','70',...
		'After','0.5',...
		'position',[160,190,180,210])

add_block('built-in/Step Fcn',[sys,'/','Step Input8'])
set_param([sys,'/','Step Input8'],...
		'Time','80',...
		'After','0.5',...
		'position',[210,215,230,235])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[5,230,25,250])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'buffer','[50000,1]',...
		'position',[55,232,105,248])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'mat-name','w',...
		'buffer','[50000,1]',...
		'position',[660,102,710,118])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay1']])
set_param([sys,'/',['Transport',13,'Delay1']],...
		'Delay Time','0.5',...
		'position',[470,95,510,125])
add_line(sys,[395,35;425,35])
add_line(sys,[30,240;50,240])
add_line(sys,[505,35;540,35])
add_line(sys,[590,35;660,35])
add_line(sys,[325,125;340,125;340,35;365,35])
add_line(sys,[245,25;295,25])
add_line(sys,[180,50;295,50])
add_line(sys,[240,75;295,75])
add_line(sys,[180,100;295,100])
add_line(sys,[235,125;295,125])
add_line(sys,[180,150;295,150])
add_line(sys,[230,170;255,170;255,175;295,175])
add_line(sys,[185,200;295,200])
add_line(sys,[235,225;295,225])
add_line(sys,[515,110;655,110])
add_line(sys,[340,110;465,110])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
