function [ret,x0,str,ts,xts]=pranfis1(t,x,u,flag);
%PRANFIS1	is the M-file description of the SIMULINK system named PRANFIS1.
%	The block-diagram can be displayed by typing: PRANFIS1.
%
%	SYS=PRANFIS1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes PRANFIS1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling PRANFIS1 with a FLAG of zero:
%	[SIZES]=PRANFIS1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[113,47,923,256])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Sum',[sys,'/','e1'])
set_param([sys,'/','e1'],...
		'position',[175,84,195,131])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'mat-name','y',...
		'buffer','[50000,2]',...
		'position',[600,102,650,118])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay1']])
set_param([sys,'/',['Transport',13,'Delay1']],...
		'Delay Time','0.5',...
		'position',[520,95,560,125])

add_block('built-in/Zero-Pole',[sys,'/','Zero-Pole1'])
set_param([sys,'/','Zero-Pole1'],...
		'Zeros','[-2]',...
		'Poles','[-10; -1]',...
		'position',[415,85,485,135])

add_block('built-in/Gain',[sys,'/','I1'])
set_param([sys,'/','I1'],...
		'Gain','3.5',...
		'position',[370,100,390,120])

add_block('built-in/Step Fcn',[sys,'/','Zmena w6'])
set_param([sys,'/','Zmena w6'],...
		'Time','0',...
		'position',[70,85,90,105])

add_block('built-in/Step Fcn',[sys,'/','Zmena w5'])
set_param([sys,'/','Zmena w5'],...
		'Time','60',...
		'After','-0.3',...
		'position',[65,110,85,130])

add_block('built-in/Clock',[sys,'/','Clock1'])
set_param([sys,'/','Clock1'],...
		'position',[530,40,550,60])

add_block('built-in/To Workspace',[sys,'/','To Workspace8'])
set_param([sys,'/','To Workspace8'],...
		'mat-name','t',...
		'buffer','[50000,2]',...
		'position',[610,42,660,58])

add_block('built-in/To Workspace',[sys,'/','To Workspace9'])
set_param([sys,'/','To Workspace9'],...
		'mat-name','u',...
		'buffer','[50000,2]',...
		'position',[380,17,430,33])

add_block('built-in/S-Function',[sys,'/','FLC1'])
set_param([sys,'/','FLC1'],...
		'function name','sffis',...
		'parameters','fismatrix',...
		'Mask Display','plot(0, -0.3, 6, -0.3, 0, 1.2, 6, 1.2, [0 6], [0 0], [1 2 3],[0 1 0],[2 3 4],[0 1 0],[3 4 5],[0 1 0])',...
		'Mask Type','FIS')
set_param([sys,'/','FLC1'],...
		'Mask Dialogue','FIS|FIS Matrix:',...
		'Mask Translate','fismatrix = @1;',...
		'Mask Help','Fuzzy Inference System',...
		'Mask Entries','nfs\/',...
		'position',[265,94,295,126])
add_line(sys,[565,110;595,110])
add_line(sys,[490,110;515,110])
add_line(sys,[555,50;605,50])
add_line(sys,[395,110;410,110])
add_line(sys,[300,110;365,110])
add_line(sys,[200,110;260,110])
add_line(sys,[95,95;170,95])
add_line(sys,[340,110;340,25;375,25])
add_line(sys,[90,120;170,120])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
