% Demo pre modelovanie systemov pomocou neurovovych sieti
% Priklad trenovania trojvrstvovej perceptron siete s nasledovnymi parametrami:
% z1 - trenovacie data v tvare z1=[y u]
% z2 - testovacie data v tvare z2=[y u]
% n - pocet vzoriek testovacich dat 
% nu - rad vstupu
% ny - rad vystupu
% nk - rad dopr. oneskorenia
% Nh - pocet neuronov skrytej vrstve	
% epochds - zobrazovanie epoch
% Nepoch - pocet trenovacich epoch
% ErrMin - ukoncovacia podmienka pre odchylku
% in - matica vstupov rozmerov (nu+ny) x n
% out - vektor vystupu rozmerov 1 x n

% Definovanie parametrov trenovania
n = 640;
nu = 4;
ny = 4;
nk = 0; na=3; nb=2;
Nh = 10;
epochds = 5;
Nepoch = 50;
ErrMin = 1e-5;

% Nacitanie dat zo systemu v tvare z1=[y u]
load systdat1;
in=zeros(n+1,nu+ny);
indx=1;
for ii=nu:-1:1,
   in(:,indx)=z1(ii:n+ii,2);
   indx=indx+1;
end
for ii=ny:-1:1,
   in(:,indx)=z1(ii:n+ii,1);
   indx=indx+1;
end
in=in';
%in=[z1(4:704,2),z1(3:703,2),z1(2:702,2),z1(1:701,2),z1(4:704,1),z1(3:703,1),z1(2:702,1),z1(1:701,1)];
%Vstup tvoreny [u(i-1) u(i-2) ... u(i-nu) y(i-1) y(i-2) ... y(i-ny)]

out=z1(ny+1:n+ny+1,1);
out=out'; 
% Vystup y(k) 

% Zobrazenie dat
idplot(z1)
disp('------dalej stac klavesu------')
pause

% Inicializacia N-siete 
%[w1,b1,w2,b2]=initff([-1,1;-1,1;-1,1;-1,1;-1,1;-1,1;-1,1;-1,1],10,'tansig',1,'purelin');
LimIn=-ones(nu+ny,1);
LimIn(:,2)=ones(nu+ny,1);
[w1,b1,w2,b2]=initff(LimIn,Nh,'tansig',1,'purelin');

% Trenovanie Levember.-Mark.
[w1,b1,w2,b2,te,tr]=trainlm(w1,b1,'tansig',w2,b2,'purelin',in,out,[epochds,Nepoch,ErrMin]);
disp('------dalej stac klavesu------')
pause


% Simulacia vystupu z NN
% Trenovacie data
y2=z1(:,1);
u2=z1(:,2);
N=length(u2);
NVystup1=z1(1:ny,1);
for ii=ny+1:1:N,
   for jj=1:nu,
      Nin(jj,1)=z1(ii-jj,2);
   end
   for jj=1:ny,
      Nin(nu+jj,1)=NVystup1(ii-jj);
   end

   NVystup1(ii)=simuff(Nin,w1,b1,'tansig',w2,b2,'purelin');
end

h=figure;
plot([y2 NVystup1])
title('Trenovacie data   modra=system  zelena=N-siet')
disp('------dalej stac klavesu------')
pause

% Testovacie data
y2=z2(:,1);
u2=z2(:,2);
N=length(u2);
NVystup2=z2(1:ny,1);
for ii=ny+1:1:N,
   for jj=1:nu,
      Nin(jj,1)=z2(ii-jj,2);
   end
   for jj=1:ny,
      Nin(nu+jj,1)=NVystup2(ii-jj);
   end

   NVystup2(ii)=simuff(Nin,w1,b1,'tansig',w2,b2,'purelin');
end

h=figure;
plot([y2 NVystup2])
title('Testovacie data   modra=system   zelena=N-siet')
disp('------dalej stac klavesu------')
pause

% Porovnanie s ARX-modelom
th=arx(z1(1:n,:),[na nb nk]);
y3=idsim(u2,th);
plot([y2 NVystup2 y3])
title('modra=system   zelena=N-siet   cervena=ARX ')

