function [ret,x0,str,ts,xts]=s(t,x,u,flag);
%S	is the M-file description of the SIMULINK system named S.
%	The block-diagram can be displayed by typing: S.
%
%	SYS=S(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S with a FLAG of zero:
%	[SIZES]=S([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[108,159,608,449])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '80')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'Delay Time','0.3',...
		'position',[265,40,305,70])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'Numerator','[0.85 1]',...
		'Denominator','[0.85 0.65 1]',...
		'position',[140,35,250,75])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[340,37,370,108])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','pom',...
		'buffer','10000',...
		'position',[400,67,450,83])


%     Subsystem  ['Band-Limited',13,'White Noise'].

new_system([sys,'/',['Band-Limited',13,'White Noise']])
set_param([sys,'/',['Band-Limited',13,'White Noise']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Band-Limited',13,'White Noise/Out_1']])
set_param([sys,'/',['Band-Limited',13,'White Noise/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Band-Limited',13,'White Noise/Gain']])
set_param([sys,'/',['Band-Limited',13,'White Noise/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Band-Limited',13,'White Noise/Zero-Order',13,'Hold']])
set_param([sys,'/',['Band-Limited',13,'White Noise/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Band-Limited',13,'White Noise/White Noise']])
set_param([sys,'/',['Band-Limited',13,'White Noise/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Band-Limited',13,'White Noise']],[50,50;80,50])
add_line([sys,'/',['Band-Limited',13,'White Noise']],[200,50;225,50])
add_line([sys,'/',['Band-Limited',13,'White Noise']],[125,50;150,50])
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Entries','[1]\/7\/[8001]\/')


%     Finished composite block ['Band-Limited',13,'White Noise'].

set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'position',[30,37,75,73])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[40,135,60,155])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'buffer','10000',...
		'position',[125,137,175,153])
add_line(sys,[80,55;135,55])
add_line(sys,[255,55;260,55])
add_line(sys,[310,55;335,55])
add_line(sys,[375,75;395,75])
add_line(sys,[95,55;95,90;335,90])
add_line(sys,[65,145;120,145])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
