function [ret,x0,str,ts,xts]=snonlin(t,x,u,flag);
%SNONLIN	is the M-file description of the SIMULINK system named SNONLIN.
%	The block-diagram can be displayed by typing: SNONLIN.
%
%	SYS=SNONLIN(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SNONLIN to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SNONLIN with a FLAG of zero:
%	[SIZES]=SNONLIN([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,600,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '80')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')


%     Subsystem  ['Band-Limited',13,'White Noise'].

new_system([sys,'/',['Band-Limited',13,'White Noise']])
set_param([sys,'/',['Band-Limited',13,'White Noise']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Band-Limited',13,'White Noise/Out_1']])
set_param([sys,'/',['Band-Limited',13,'White Noise/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Band-Limited',13,'White Noise/Gain']])
set_param([sys,'/',['Band-Limited',13,'White Noise/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Band-Limited',13,'White Noise/Zero-Order',13,'Hold']])
set_param([sys,'/',['Band-Limited',13,'White Noise/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Band-Limited',13,'White Noise/White Noise']])
set_param([sys,'/',['Band-Limited',13,'White Noise/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Band-Limited',13,'White Noise']],[50,50;80,50])
add_line([sys,'/',['Band-Limited',13,'White Noise']],[200,50;225,50])
add_line([sys,'/',['Band-Limited',13,'White Noise']],[125,50;150,50])
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'Mask Entries','[1]\/50\/[8001]\/')


%     Finished composite block ['Band-Limited',13,'White Noise'].

set_param([sys,'/',['Band-Limited',13,'White Noise']],...
		'position',[30,2,75,38])


%     Subsystem  ['Band-Limited',13,'White Noise1'].

new_system([sys,'/',['Band-Limited',13,'White Noise1']])
set_param([sys,'/',['Band-Limited',13,'White Noise1']],'Location',[54,341,339,470])

add_block('built-in/Outport',[sys,'/',['Band-Limited',13,'White Noise1/Out_1']])
set_param([sys,'/',['Band-Limited',13,'White Noise1/Out_1']],...
		'position',[230,40,250,60])

add_block('built-in/Gain',[sys,'/',['Band-Limited',13,'White Noise1/Gain']])
set_param([sys,'/',['Band-Limited',13,'White Noise1/Gain']],...
		'Gain','[sqrt(Cov)]/[sqrt(Ts)]',...
		'position',[155,31,195,69])

add_block('built-in/Zero-Order Hold',[sys,'/',['Band-Limited',13,'White Noise1/Zero-Order',13,'Hold']])
set_param([sys,'/',['Band-Limited',13,'White Noise1/Zero-Order',13,'Hold']],...
		'Sample time','Ts',...
		'position',[85,34,120,66])

add_block('built-in/White Noise',[sys,'/',['Band-Limited',13,'White Noise1/White Noise']])
set_param([sys,'/',['Band-Limited',13,'White Noise1/White Noise']],...
		'Seed','seed',...
		'position',[25,40,45,60])
add_line([sys,'/',['Band-Limited',13,'White Noise1']],[50,50;80,50])
add_line([sys,'/',['Band-Limited',13,'White Noise1']],[200,50;225,50])
add_line([sys,'/',['Band-Limited',13,'White Noise1']],[125,50;150,50])
set_param([sys,'/',['Band-Limited',13,'White Noise1']],...
		'Mask Display','plot(t(:),r2(:))',...
		'Mask Type','Continuous White Noise.')
set_param([sys,'/',['Band-Limited',13,'White Noise1']],...
		'Mask Dialogue','White noise for continuous (s-domain) systems.\nBand-limited using zero-order-hold.|Noise Power:|Sample Time:|Seed')
set_param([sys,'/',['Band-Limited',13,'White Noise1']],...
		'Mask Translate','Cov = @1; Ts = @2; seed = @3; r = rand(1,12); r2 = [r(1),r;r,r(12)]; t =[1:13;1:13];')
set_param([sys,'/',['Band-Limited',13,'White Noise1']],...
		'Mask Help','Implemented using white noise into Zero-Order Hold block. The seed and power can be vectors of the same length to produce a vector of white noise sources. For faster simulation, set sample time to the highest value possible but in accordance with the fastest dynamics of system.')
set_param([sys,'/',['Band-Limited',13,'White Noise1']],...
		'Mask Entries','[1]\/30\/[23341]\/')


%     Finished composite block ['Band-Limited',13,'White Noise1'].

set_param([sys,'/',['Band-Limited',13,'White Noise1']],...
		'position',[30,72,75,108])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'position',[95,45,115,65])

add_block('built-in/Product',[sys,'/','Product'])
set_param([sys,'/','Product'],...
		'position',[165,48,195,72])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'Delay Time','0.18',...
		'position',[345,45,385,75])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'Numerator','[0.5 1]',...
		'Denominator','[0.5 0.55 1]',...
		'position',[220,40,330,80])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[420,42,450,113])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','pom',...
		'buffer','10000',...
		'position',[480,72,530,88])

add_block('built-in/Constant',[sys,'/','Constant'])
set_param([sys,'/','Constant'],...
		'orientation',2,...
		'position',[360,165,380,185])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',2,...
		'position',[270,139,295,186])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'orientation',2,...
		'Gain','0.5',...
		'position',[320,135,350,165])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'orientation',2,...
		'Gain','2',...
		'position',[190,150,220,180])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[35,230,55,250])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'buffer','10000',...
		'position',[120,232,170,248])
add_line(sys,[335,60;340,60])
add_line(sys,[390,60;415,60])
add_line(sys,[455,80;475,80])
add_line(sys,[60,240;115,240])
add_line(sys,[80,90;90,60])
add_line(sys,[80,20;90,50])
add_line(sys,[120,55;125,55;125,95;415,95])
add_line(sys,[120,55;160,55])
add_line(sys,[200,60;215,60])
add_line(sys,[355,175;300,175])
add_line(sys,[315,150;300,150])
add_line(sys,[265,165;225,165])
add_line(sys,[185,165;140,165;140,65;160,65])
add_line(sys,[400,60;400,150;355,150])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
