function [ret,x0,str,ts,xts]=cv1pr12(t,x,u,flag);
%CV1PR12	is the M-file description of the SIMULINK system named CV1PR12.
%	The block-diagram can be displayed by typing: CV1PR12.
%
%	SYS=CV1PR12(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes CV1PR12 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling CV1PR12 with a FLAG of zero:
%	[SIZES]=CV1PR12([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[350,43,780,581])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '.1')
set_param(sys,'Max step size', '.1')
set_param(sys,'Relative error','1e-5')
set_param(sys,'Return vars',   '')

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[50,15,70,35])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','t',...
		'buffer','100000',...
		'position',[115,17,165,33])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,105,135,125])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'Gain','c12',...
		'position',[155,102,180,128])

add_block('built-in/Fcn',[sys,'/','Fcn2'])
set_param([sys,'/','Fcn2'],...
		'hide name',0,...
		'Expr','K*u',...
		'position',[255,105,295,125])


%     Subsystem  ['Discrete-Time',13,'Integrator2'].

new_system([sys,'/',['Discrete-Time',13,'Integrator2']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator2/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator2/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator2/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator2/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator2'].

set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'hide name',0,...
		'position',[200,94,240,136])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','y12',...
		'buffer','100000',...
		'position',[365,107,415,123])

add_block('built-in/Step Fcn',[sys,'/','Step Input2'])
set_param([sys,'/','Step Input2'],...
		'hide name',0,...
		'Time','0',...
		'After','w12',...
		'position',[40,100,60,120])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,155,135,175])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'hide name',0,...
		'Gain','c13',...
		'position',[155,152,180,178])

add_block('built-in/Fcn',[sys,'/','Fcn3'])
set_param([sys,'/','Fcn3'],...
		'hide name',0,...
		'Expr','K*u',...
		'position',[255,155,295,175])


%     Subsystem  ['Discrete-Time',13,'Integrator3'].

new_system([sys,'/',['Discrete-Time',13,'Integrator3']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator3/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator3/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator3/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator3/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator3'].

set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'hide name',0,...
		'position',[200,144,240,186])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','y13',...
		'buffer','100000',...
		'position',[365,157,415,173])

add_block('built-in/Step Fcn',[sys,'/','Step Input3'])
set_param([sys,'/','Step Input3'],...
		'hide name',0,...
		'Time','0',...
		'After','w13',...
		'position',[40,150,60,170])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,55,135,75])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Gain','c11',...
		'position',[155,52,180,78])

add_block('built-in/Fcn',[sys,'/','Fcn'])
set_param([sys,'/','Fcn'],...
		'hide name',0,...
		'Expr','K*u',...
		'position',[255,55,295,75])


%     Subsystem  ['Discrete-Time',13,'Integrator'].

new_system([sys,'/',['Discrete-Time',13,'Integrator']])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator'].

set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'hide name',0,...
		'position',[200,44,240,86])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'mat-name','y11',...
		'buffer','100000',...
		'position',[365,57,415,73])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'After','w11',...
		'position',[40,50,60,70])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,230,135,250])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','y21',...
		'buffer','100000',...
		'position',[365,232,415,248])

add_block('built-in/Step Fcn',[sys,'/','Step Input1'])
set_param([sys,'/','Step Input1'],...
		'hide name',0,...
		'Time','0',...
		'position',[40,225,60,245])

add_block('built-in/Fcn',[sys,'/','Fcn1'])
set_param([sys,'/','Fcn1'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[295,230,335,250])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','c21',...
		'position',[150,227,175,253])

add_block('built-in/Sum',[sys,'/','Sum4'])
set_param([sys,'/','Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,280,135,300])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','y22',...
		'buffer','100000',...
		'position',[365,282,415,298])

add_block('built-in/Step Fcn',[sys,'/','Step Input4'])
set_param([sys,'/','Step Input4'],...
		'hide name',0,...
		'Time','0',...
		'After','.01',...
		'position',[40,275,60,295])

add_block('built-in/Fcn',[sys,'/','Fcn4'])
set_param([sys,'/','Fcn4'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[295,280,335,300])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'hide name',0,...
		'Gain','c22',...
		'position',[150,277,175,303])


%     Subsystem  ['Discrete-Time',13,'Integrator4'].

new_system([sys,'/',['Discrete-Time',13,'Integrator4']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator4/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator4/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator4/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator4/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator4/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'Mask Entries','1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator4'].

set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'hide name',0,...
		'position',[190,269,230,311])

add_block('built-in/Saturation',[sys,'/','Saturation3'])
set_param([sys,'/','Saturation3'],...
		'hide name',0,...
		'Lower Limit','0',...
		'Upper Limit','1.1',...
		'position',[245,328,275,352])


%     Subsystem  ['Discrete-Time',13,'Integrator6'].

new_system([sys,'/',['Discrete-Time',13,'Integrator6']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator6/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator6/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator6/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator6/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator6/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'Mask Entries','.1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator6'].

set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'hide name',0,...
		'position',[190,319,230,361])

add_block('built-in/Gain',[sys,'/','Gain6'])
set_param([sys,'/','Gain6'],...
		'hide name',0,...
		'Gain','c23',...
		'position',[150,327,175,353])

add_block('built-in/Fcn',[sys,'/','Fcn6'])
set_param([sys,'/','Fcn6'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[295,330,335,350])

add_block('built-in/Step Fcn',[sys,'/','Step Input6'])
set_param([sys,'/','Step Input6'],...
		'hide name',0,...
		'Time','0',...
		'position',[40,325,60,345])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'hide name',0,...
		'mat-name','y23',...
		'buffer','100000',...
		'position',[365,332,415,348])

add_block('built-in/Sum',[sys,'/','Sum6'])
set_param([sys,'/','Sum6'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,330,135,350])

add_block('built-in/Saturation',[sys,'/','Saturation2'])
set_param([sys,'/','Saturation2'],...
		'hide name',0,...
		'Lower Limit','0',...
		'Upper Limit','1.1',...
		'position',[245,378,275,402])


%     Subsystem  ['Discrete-Time',13,'Integrator5'].

new_system([sys,'/',['Discrete-Time',13,'Integrator5']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator5/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator5/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator5/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator5/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator5/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Entries','1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator5'].

set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'hide name',0,...
		'position',[190,369,230,411])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'hide name',0,...
		'Gain','c24',...
		'position',[150,377,175,403])

add_block('built-in/Fcn',[sys,'/','Fcn5'])
set_param([sys,'/','Fcn5'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[295,380,335,400])

add_block('built-in/Step Fcn',[sys,'/','Step Input5'])
set_param([sys,'/','Step Input5'],...
		'hide name',0,...
		'Time','0',...
		'After','0.01',...
		'position',[40,375,60,395])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','y24',...
		'buffer','100000',...
		'position',[365,382,415,398])

add_block('built-in/Sum',[sys,'/','Sum5'])
set_param([sys,'/','Sum5'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,380,135,400])

add_block('built-in/Saturation',[sys,'/','Saturation4'])
set_param([sys,'/','Saturation4'],...
		'hide name',0,...
		'Lower Limit','0',...
		'Upper Limit','1.1',...
		'position',[245,278,275,302])


%     Subsystem  ['Discrete-Time',13,'Limited Integrator'].

new_system([sys,'/',['Discrete-Time',13,'Limited Integrator']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator']],'Location',[137,84,904,403])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Limited Integrator/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[605,150,655,170])

add_block('built-in/Switch',[sys,'/',['Discrete-Time',13,'Limited Integrator/Switch1']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Switch1']],...
		'hide name',0,...
		'Threshold','0.5',...
		'position',[520,110,555,210])

add_block('built-in/Constant',[sys,'/',['Discrete-Time',13,'Limited Integrator/Constant1']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Constant1']],...
		'hide name',0,...
		'Value','lower_limit',...
		'position',[140,218,210,242])

add_block('built-in/Relational Operator',[sys,'/',['Discrete-Time',13,'Limited Integrator/Relational',13,'operator1']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Relational',13,'operator1']],...
		'hide name',0,...
		'Operator','>',...
		'position',[450,142,480,173])

add_block('built-in/Relational Operator',[sys,'/',['Discrete-Time',13,'Limited Integrator/Relational',13,'operator']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Relational',13,'operator']],...
		'hide name',0,...
		'Operator','<',...
		'position',[245,131,270,164])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Limited Integrator/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Gain']],...
		'Gain','Ts',...
		'position',[110,106,140,144])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Limited Integrator/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Sum']],...
		'hide name',0,...
		'position',[170,95,195,135])

add_block('built-in/Switch',[sys,'/',['Discrete-Time',13,'Limited Integrator/Switch']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Switch']],...
		'hide name',0,...
		'Threshold','0.5',...
		'position',[315,99,340,201])

add_block('built-in/Constant',[sys,'/',['Discrete-Time',13,'Limited Integrator/Constant']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/Constant']],...
		'hide name',0,...
		'Value','upper_limit',...
		'position',[140,174,210,196])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Limited Integrator/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/in_1']],...
		'position',[60,115,80,135])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Limited Integrator/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator/out_1']],...
		'position',[685,150,705,170])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[660,160;680,160])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[670,160;670,70;150,70;150,105;165,105])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[560,160;600,160])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[215,230;430,230;430,165;445,165])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[430,195;515,195])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[485,160;515,160])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[345,150;445,150])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[380,150;380,125;515,125])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[215,185;310,185])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[215,185;220,185;220,155;240,155])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[145,125;165,125])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[200,115;310,115])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[220,115;220,140;240,140])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[275,150;310,150])
add_line([sys,'/',['Discrete-Time',13,'Limited Integrator']],[85,125;105,125])
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator']],...
		'Mask Display','plot(-1,-0.2,3.5,1.2,[0,1,2,2.9],[0,0,1,1],[0,1],[0.5,0.5], [.5,.5], [.8,.6], [.05,.35,.05,.35],[.4,.4,.2,.2], [.45,.65],[.3,.3], [.9,.9],[.2,.4]);')
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator']],...
		'Mask Type','Discrete-Time Limited Integrator.',...
		'Mask Dialogue','Discrete-Time Limited Integrator.|Lower bound:|Upper bound:|Initial condition:|Sampling Time:')
set_param([sys,'/',['Discrete-Time',13,'Limited Integrator']],...
		'Mask Translate','lower_limit=@1;upper_limit=@2;X0=@3;Ts=@4;',...
		'Mask Help','Discrete-Time Limited Integrator. Unmask to see details.',...
		'Mask Entries','0\/1.1\/0.1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Limited Integrator'].

set_param([sys,'/',['Discrete-Time',13,'Limited Integrator']],...
		'hide name',0,...
		'position',[195,217,240,263])
add_line(sys,[75,25;110,25])
add_line(sys,[185,65;195,65])
add_line(sys,[140,65;150,65])
add_line(sys,[65,60;110,60])
add_line(sys,[245,65;250,65])
add_line(sys,[300,65;360,65])
add_line(sys,[320,65;320,90;95,90;95,70;110,70])
add_line(sys,[340,240;360,240])
add_line(sys,[65,235;110,235])
add_line(sys,[140,240;145,240])
add_line(sys,[180,240;190,240])
add_line(sys,[340,240;350,240;350,265;95,265;95,245;110,245])
add_line(sys,[300,115;360,115])
add_line(sys,[320,115;320,140;95,140;95,120;110,120])
add_line(sys,[245,115;250,115])
add_line(sys,[65,110;110,110])
add_line(sys,[140,115;150,115])
add_line(sys,[185,115;195,115])
add_line(sys,[185,165;195,165])
add_line(sys,[140,165;150,165])
add_line(sys,[65,160;110,160])
add_line(sys,[245,165;250,165])
add_line(sys,[300,165;360,165])
add_line(sys,[320,165;320,190;95,190;95,170;110,170])
add_line(sys,[340,290;350,290;350,315;95,315;95,295;110,295])
add_line(sys,[180,290;185,290])
add_line(sys,[140,290;145,290])
add_line(sys,[65,285;110,285])
add_line(sys,[340,290;360,290])
add_line(sys,[340,390;360,390])
add_line(sys,[65,385;110,385])
add_line(sys,[140,390;145,390])
add_line(sys,[180,390;185,390])
add_line(sys,[235,390;240,390])
add_line(sys,[280,390;290,390])
add_line(sys,[340,390;350,390;350,415;95,415;95,395;110,395])
add_line(sys,[340,340;350,340;350,365;95,365;95,345;110,345])
add_line(sys,[280,340;290,340])
add_line(sys,[235,340;240,340])
add_line(sys,[180,340;185,340])
add_line(sys,[140,340;145,340])
add_line(sys,[65,335;110,335])
add_line(sys,[340,340;360,340])
add_line(sys,[235,290;240,290])
add_line(sys,[280,290;290,290])
add_line(sys,[245,240;290,240])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
