function [ret,x0,str,ts,xts]=cv1pr3(t,x,u,flag);
%CV1PR3	is the M-file description of the SIMULINK system named CV1PR3.
%	The block-diagram can be displayed by typing: CV1PR3.
%
%	SYS=CV1PR3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes CV1PR3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling CV1PR3 with a FLAG of zero:
%	[SIZES]=CV1PR3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[19,46,646,555])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-5')
set_param(sys,'Return vars',   't')

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'mat-name','y1',...
		'buffer','100000',...
		'position',[450,77,500,93])

add_block('built-in/Fcn',[sys,'/','Fcn'])
set_param([sys,'/','Fcn'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[350,75,390,95])

add_block('built-in/Fcn',[sys,'/','Fcn1'])
set_param([sys,'/','Fcn1'],...
		'hide name',0,...
		'Expr','(m1*sqrt(w1)+(1-m1)*u(2))*u(1)',...
		'position',[215,75,255,95])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','2',...
		'position',[165,66,195,99])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'After','w1',...
		'position',[30,60,50,80])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,65,125,85])


%     Subsystem  ['Discrete-Time',13,'Integrator'].

new_system([sys,'/',['Discrete-Time',13,'Integrator']])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Entries','0.1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator'].

set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'hide name',0,...
		'position',[275,64,315,106])


%     Subsystem  ['Discrete-Time',13,'Integrator1'].

new_system([sys,'/',['Discrete-Time',13,'Integrator1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator1/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator1/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator1/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator1/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Entries','1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator1'].

set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'hide name',0,...
		'position',[275,139,315,181])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,140,125,160])

add_block('built-in/Step Fcn',[sys,'/','Step Input1'])
set_param([sys,'/','Step Input1'],...
		'hide name',0,...
		'Time','0',...
		'After','w2',...
		'position',[30,135,50,155])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'hide name',0,...
		'inputs','2',...
		'position',[165,141,195,174])

add_block('built-in/Fcn',[sys,'/','Fcn2'])
set_param([sys,'/','Fcn2'],...
		'hide name',0,...
		'Expr','(m1*sqrt(w2)+(1-m1)*u(2))*u(1)',...
		'position',[215,150,255,170])

add_block('built-in/Fcn',[sys,'/','Fcn3'])
set_param([sys,'/','Fcn3'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[350,150,390,170])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','y2',...
		'buffer','100000',...
		'position',[450,152,500,168])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','y4',...
		'buffer','100000',...
		'position',[450,297,500,313])

add_block('built-in/Fcn',[sys,'/','Fcn4'])
set_param([sys,'/','Fcn4'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[350,295,390,315])

add_block('built-in/Fcn',[sys,'/','Fcn5'])
set_param([sys,'/','Fcn5'],...
		'hide name',0,...
		'Expr','(m2*sqrt(w2)+(1-m2)*u(2))*u(1)',...
		'position',[215,295,255,315])

add_block('built-in/Mux',[sys,'/','Mux2'])
set_param([sys,'/','Mux2'],...
		'hide name',0,...
		'inputs','2',...
		'position',[165,286,195,319])

add_block('built-in/Step Fcn',[sys,'/','Step Input2'])
set_param([sys,'/','Step Input2'],...
		'hide name',0,...
		'Time','0',...
		'After','w2',...
		'position',[30,280,50,300])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,285,125,305])


%     Subsystem  ['Discrete-Time',13,'Integrator2'].

new_system([sys,'/',['Discrete-Time',13,'Integrator2']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator2/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator2/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator2/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator2/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Entries','1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator2'].

set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'hide name',0,...
		'position',[275,284,315,326])


%     Subsystem  ['Discrete-Time',13,'Integrator3'].

new_system([sys,'/',['Discrete-Time',13,'Integrator3']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator3/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator3/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator3/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator3/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Entries','0.1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator3'].

set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'hide name',0,...
		'position',[275,209,315,251])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,210,125,230])

add_block('built-in/Step Fcn',[sys,'/','Step Input3'])
set_param([sys,'/','Step Input3'],...
		'hide name',0,...
		'Time','0',...
		'After','w1',...
		'position',[30,205,50,225])

add_block('built-in/Mux',[sys,'/','Mux3'])
set_param([sys,'/','Mux3'],...
		'hide name',0,...
		'inputs','2',...
		'position',[165,211,195,244])

add_block('built-in/Fcn',[sys,'/','Fcn6'])
set_param([sys,'/','Fcn6'],...
		'hide name',0,...
		'Expr','(m2*sqrt(w1)+(1-m2)*u(2))*u(1)',...
		'position',[215,220,255,240])

add_block('built-in/Fcn',[sys,'/','Fcn7'])
set_param([sys,'/','Fcn7'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[350,220,390,240])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','y3',...
		'buffer','100000',...
		'position',[450,222,500,238])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','y5',...
		'buffer','100000',...
		'position',[450,367,500,383])

add_block('built-in/Fcn',[sys,'/','Fcn8'])
set_param([sys,'/','Fcn8'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[350,365,390,385])

add_block('built-in/Fcn',[sys,'/','Fcn9'])
set_param([sys,'/','Fcn9'],...
		'hide name',0,...
		'Expr','(m3*sqrt(w1)+(1-m3)*u(2))*u(1)',...
		'position',[215,365,255,385])

add_block('built-in/Mux',[sys,'/','Mux4'])
set_param([sys,'/','Mux4'],...
		'hide name',0,...
		'inputs','2',...
		'position',[165,356,195,389])

add_block('built-in/Step Fcn',[sys,'/','Step Input4'])
set_param([sys,'/','Step Input4'],...
		'hide name',0,...
		'Time','0',...
		'After','w1',...
		'position',[30,350,50,370])

add_block('built-in/Sum',[sys,'/','Sum4'])
set_param([sys,'/','Sum4'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,355,125,375])


%     Subsystem  ['Discrete-Time',13,'Integrator4'].

new_system([sys,'/',['Discrete-Time',13,'Integrator4']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator4/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator4/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator4/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator4/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator4/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator4/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator4']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'Mask Entries','0.1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator4'].

set_param([sys,'/',['Discrete-Time',13,'Integrator4']],...
		'hide name',0,...
		'position',[275,354,315,396])


%     Subsystem  ['Discrete-Time',13,'Integrator5'].

new_system([sys,'/',['Discrete-Time',13,'Integrator5']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator5/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator5/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator5/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator5/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator5/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Entries','1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator5'].

set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'hide name',0,...
		'position',[275,429,315,471])

add_block('built-in/Sum',[sys,'/','Sum5'])
set_param([sys,'/','Sum5'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,430,125,450])

add_block('built-in/Step Fcn',[sys,'/','Step Input5'])
set_param([sys,'/','Step Input5'],...
		'hide name',0,...
		'Time','0',...
		'After','w2',...
		'position',[30,425,50,445])

add_block('built-in/Mux',[sys,'/','Mux5'])
set_param([sys,'/','Mux5'],...
		'hide name',0,...
		'inputs','2',...
		'position',[165,431,195,464])

add_block('built-in/Fcn',[sys,'/','Fcn10'])
set_param([sys,'/','Fcn10'],...
		'hide name',0,...
		'Expr','(m3*sqrt(w2)+(1-m3)*u(2))*u(1)',...
		'position',[215,440,255,460])

add_block('built-in/Fcn',[sys,'/','Fcn11'])
set_param([sys,'/','Fcn11'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[350,440,390,460])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','y6',...
		'buffer','100000',...
		'position',[450,442,500,458])
add_line(sys,[55,70;100,70])
add_line(sys,[320,85;345,85])
add_line(sys,[395,85;445,85])
add_line(sys,[260,85;270,85])
add_line(sys,[200,85;210,85])
add_line(sys,[130,75;160,75])
add_line(sys,[330,85;330,115;145,115;145,90;160,90])
add_line(sys,[415,85;415,130;80,130;80,80;100,80])
add_line(sys,[395,160;445,160])
add_line(sys,[415,160;415,205;80,205;80,155;100,155])
add_line(sys,[320,160;345,160])
add_line(sys,[330,160;330,190;145,190;145,165;160,165])
add_line(sys,[130,150;160,150])
add_line(sys,[200,160;210,160])
add_line(sys,[260,160;270,160])
add_line(sys,[55,145;100,145])
add_line(sys,[55,290;100,290])
add_line(sys,[320,305;345,305])
add_line(sys,[395,305;445,305])
add_line(sys,[260,305;270,305])
add_line(sys,[200,305;210,305])
add_line(sys,[130,295;160,295])
add_line(sys,[330,305;330,335;145,335;145,310;160,310])
add_line(sys,[415,305;415,350;80,350;80,300;100,300])
add_line(sys,[395,230;445,230])
add_line(sys,[415,230;415,275;80,275;80,225;100,225])
add_line(sys,[320,230;345,230])
add_line(sys,[330,230;330,260;145,260;145,235;160,235])
add_line(sys,[130,220;160,220])
add_line(sys,[200,230;210,230])
add_line(sys,[260,230;270,230])
add_line(sys,[55,215;100,215])
add_line(sys,[55,360;100,360])
add_line(sys,[320,375;345,375])
add_line(sys,[395,375;445,375])
add_line(sys,[260,375;270,375])
add_line(sys,[200,375;210,375])
add_line(sys,[130,365;160,365])
add_line(sys,[330,375;330,405;145,405;145,380;160,380])
add_line(sys,[415,375;415,420;80,420;80,370;100,370])
add_line(sys,[395,450;445,450])
add_line(sys,[415,450;415,495;80,495;80,445;100,445])
add_line(sys,[320,450;345,450])
add_line(sys,[330,450;330,480;145,480;145,455;160,455])
add_line(sys,[130,440;160,440])
add_line(sys,[200,450;210,450])
add_line(sys,[260,450;270,450])
add_line(sys,[55,435;100,435])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
