function [ret,x0,str,ts,xts]=cv1pr4(t,x,u,flag);
%CV1PR4	is the M-file description of the SIMULINK system named CV1PR4.
%	The block-diagram can be displayed by typing: CV1PR4.
%
%	SYS=CV1PR4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes CV1PR4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling CV1PR4 with a FLAG of zero:
%	[SIZES]=CV1PR4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[5,29,543,291])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '15')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '0.01')
set_param(sys,'Relative error','1e-5')
set_param(sys,'Return vars',   't')

add_block('built-in/Fcn',[sys,'/','Fcn10'])
set_param([sys,'/','Fcn10'],...
		'hide name',0,...
		'Expr','sqrt(u)',...
		'position',[140,690,180,710])

add_block('built-in/Sum',[sys,'/','Sum15'])
set_param([sys,'/','Sum15'],...
		'hide name',0,...
		'position',[285,725,305,745])

add_block('built-in/Sum',[sys,'/','Sum16'])
set_param([sys,'/','Sum16'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[85,720,105,740])

add_block('built-in/Step Fcn',[sys,'/','Step Input15'])
set_param([sys,'/','Step Input15'],...
		'hide name',0,...
		'Time','0',...
		'After','w2',...
		'position',[10,715,30,735])

add_block('built-in/Mux',[sys,'/','Mux10'])
set_param([sys,'/','Mux10'],...
		'hide name',0,...
		'inputs','2',...
		'position',[125,721,155,754])

add_block('built-in/Fcn',[sys,'/','Fcn16'])
set_param([sys,'/','Fcn16'],...
		'hide name',0,...
		'Expr','(m3*sqrt(w2)+(1-m3)*u(2))*u(1)',...
		'position',[170,730,210,750])


%     Subsystem  ['Discrete-Time',13,'Integrator5'].

new_system([sys,'/',['Discrete-Time',13,'Integrator5']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator5/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator5/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator5/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator5/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator5/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator5/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator5']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator5'].

set_param([sys,'/',['Discrete-Time',13,'Integrator5']],...
		'hide name',0,...
		'position',[225,719,265,761])

add_block('built-in/Fcn',[sys,'/','Fcn11'])
set_param([sys,'/','Fcn11'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[335,725,375,745])

add_block('built-in/Step Fcn',[sys,'/','Step Input16'])
set_param([sys,'/','Step Input16'],...
		'hide name',0,...
		'Time','5',...
		'After','0',...
		'position',[345,700,365,720])

add_block('built-in/Step Fcn',[sys,'/','Step Input17'])
set_param([sys,'/','Step Input17'],...
		'hide name',0,...
		'Time','10',...
		'After','0',...
		'position',[345,680,365,700])

add_block('built-in/Sum',[sys,'/','Sum17'])
set_param([sys,'/','Sum17'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[395,697,415,743])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','y7',...
		'buffer','100000',...
		'position',[450,712,500,728])

add_block('built-in/Fcn',[sys,'/','Fcn17'])
set_param([sys,'/','Fcn17'],...
		'hide name',0,...
		'Expr','sqrt(u)',...
		'position',[140,580,180,600])

add_block('built-in/Sum',[sys,'/','Sum18'])
set_param([sys,'/','Sum18'],...
		'hide name',0,...
		'position',[285,615,305,635])

add_block('built-in/Sum',[sys,'/','Sum19'])
set_param([sys,'/','Sum19'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[85,610,105,630])

add_block('built-in/Step Fcn',[sys,'/','Step Input18'])
set_param([sys,'/','Step Input18'],...
		'hide name',0,...
		'Time','0',...
		'After','w1',...
		'position',[10,605,30,625])

add_block('built-in/Mux',[sys,'/','Mux11'])
set_param([sys,'/','Mux11'],...
		'hide name',0,...
		'inputs','2',...
		'position',[125,611,155,644])

add_block('built-in/Fcn',[sys,'/','Fcn18'])
set_param([sys,'/','Fcn18'],...
		'hide name',0,...
		'Expr','(m3*sqrt(w1)+(1-m3)*u(2))*u(1)',...
		'position',[170,620,210,640])


%     Subsystem  ['Discrete-Time',13,'Integrator6'].

new_system([sys,'/',['Discrete-Time',13,'Integrator6']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator6/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator6/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator6/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator6/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator6/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator6/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator6']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator6'].

set_param([sys,'/',['Discrete-Time',13,'Integrator6']],...
		'hide name',0,...
		'position',[225,609,265,651])

add_block('built-in/Fcn',[sys,'/','Fcn19'])
set_param([sys,'/','Fcn19'],...
		'hide name',0,...
		'Expr','u^2',...
		'position',[335,615,375,635])

add_block('built-in/Step Fcn',[sys,'/','Step Input19'])
set_param([sys,'/','Step Input19'],...
		'hide name',0,...
		'Time','5',...
		'After','0',...
		'position',[345,590,365,610])

add_block('built-in/Step Fcn',[sys,'/','Step Input20'])
set_param([sys,'/','Step Input20'],...
		'hide name',0,...
		'Time','10',...
		'After','0',...
		'position',[345,570,365,590])

add_block('built-in/Sum',[sys,'/','Sum20'])
set_param([sys,'/','Sum20'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[395,587,415,633])

add_block('built-in/To Workspace',[sys,'/','To Workspace7'])
set_param([sys,'/','To Workspace7'],...
		'hide name',0,...
		'mat-name','y6',...
		'buffer','100000',...
		'position',[450,602,500,618])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'mat-name','y1',...
		'buffer','10000',...
		'position',[450,27,500,43])

add_block('built-in/Sum',[sys,'/','Sum21'])
set_param([sys,'/','Sum21'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[370,14,390,66])

add_block('built-in/Fcn',[sys,'/','Fcn'])
set_param([sys,'/','Fcn'],...
		'hide name',0,...
		'Expr','u(1)^2',...
		'position',[290,35,330,55])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'position',[10,30,30,50])


%     Subsystem  ['Discrete-Time',13,'Integrator'].

new_system([sys,'/',['Discrete-Time',13,'Integrator']])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator'].

set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'hide name',0,...
		'position',[170,24,210,66])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Gain','.5',...
		'position',[125,32,150,58])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[85,35,105,55])

add_block('built-in/Fcn',[sys,'/','Fcn2'])
set_param([sys,'/','Fcn2'],...
		'hide name',0,...
		'Expr','u(1)^2',...
		'position',[305,180,345,200])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'position',[260,180,280,200])

add_block('built-in/Step Fcn',[sys,'/','Step Input2'])
set_param([sys,'/','Step Input2'],...
		'hide name',0,...
		'Time','0',...
		'position',[10,180,30,200])


%     Subsystem  ['Discrete-Time',13,'Integrator1'].

new_system([sys,'/',['Discrete-Time',13,'Integrator1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator1/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator1/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator1/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator1/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator1'].

set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'hide name',0,...
		'position',[170,174,210,216])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','.5',...
		'position',[125,182,150,208])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[85,185,105,205])

add_block('built-in/Fcn',[sys,'/','Fcn3'])
set_param([sys,'/','Fcn3'],...
		'hide name',0,...
		'Expr','sqrt(u(1))',...
		'position',[110,150,150,170])

add_block('built-in/Step Fcn',[sys,'/','Step Input4'])
set_param([sys,'/','Step Input4'],...
		'hide name',0,...
		'Time','9',...
		'After','-0.1',...
		'position',[310,200,330,220])

add_block('built-in/Sum',[sys,'/','Sum22'])
set_param([sys,'/','Sum22'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[365,156,390,224])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y2',...
		'buffer','10000',...
		'position',[450,177,500,193])

add_block('built-in/Step Fcn',[sys,'/','Step Input3'])
set_param([sys,'/','Step Input3'],...
		'hide name',0,...
		'Time','4',...
		'After','0.1',...
		'position',[310,155,330,175])

add_block('built-in/Step Fcn',[sys,'/','Step Input5'])
set_param([sys,'/','Step Input5'],...
		'hide name',0,...
		'Time','9',...
		'After','-0.1',...
		'position',[295,55,315,75])

add_block('built-in/Step Fcn',[sys,'/','Step Input6'])
set_param([sys,'/','Step Input6'],...
		'hide name',0,...
		'Time','4',...
		'After','0.1',...
		'position',[300,10,320,30])
add_line(sys,[35,40;80,40])
add_line(sys,[110,45;120,45])
add_line(sys,[155,45;165,45])
add_line(sys,[395,40;445,35])
add_line(sys,[215,45;285,45])
add_line(sys,[415,38;415,90;65,90;65,50;80,50])
add_line(sys,[420,610;445,610])
add_line(sys,[35,615;80,615])
add_line(sys,[50,615;50,590;135,590])
add_line(sys,[270,630;280,630])
add_line(sys,[310,625;330,625])
add_line(sys,[160,630;165,630])
add_line(sys,[215,630;220,630])
add_line(sys,[110,620;120,620])
add_line(sys,[310,625;315,660;110,660;120,635])
add_line(sys,[430,610;430,675;65,675;65,625;80,625])
add_line(sys,[380,625;390,625])
add_line(sys,[370,600;375,600;375,610;390,610])
add_line(sys,[370,580;375,580;375,595;390,595])
add_line(sys,[185,590;270,590;280,620])
add_line(sys,[185,700;270,700;280,730])
add_line(sys,[370,690;375,690;375,705;390,705])
add_line(sys,[370,710;375,710;375,720;390,720])
add_line(sys,[380,735;390,735])
add_line(sys,[420,720;445,720])
add_line(sys,[430,720;430,785;65,785;65,735;80,735])
add_line(sys,[310,735;330,735])
add_line(sys,[310,735;315,770;110,770;120,745])
add_line(sys,[110,730;120,730])
add_line(sys,[215,740;220,740])
add_line(sys,[160,740;165,740])
add_line(sys,[270,740;280,740])
add_line(sys,[35,725;80,725])
add_line(sys,[50,725;50,700;135,700])
add_line(sys,[335,45;365,40])
add_line(sys,[325,20;365,25])
add_line(sys,[335,165;360,170])
add_line(sys,[350,190;360,190])
add_line(sys,[395,190;445,185])
add_line(sys,[415,188;415,235;65,235;65,200;80,200])
add_line(sys,[35,190;80,190])
add_line(sys,[50,190;50,160;105,160])
add_line(sys,[215,195;255,195])
add_line(sys,[155,160;215,160;215,185;255,185])
add_line(sys,[285,190;300,190])
add_line(sys,[155,195;165,195])
add_line(sys,[110,195;120,195])
add_line(sys,[335,210;360,210])
add_line(sys,[320,65;335,65;335,55;365,55])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
