function [ret,x0,str,ts,xts]=schb2(t,x,u,flag);
%SCHB2	is the M-file description of the SIMULINK system named SCHB2.
%	The block-diagram can be displayed by typing: SCHB2.
%
%	SYS=SCHB2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCHB2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCHB2 with a FLAG of zero:
%	[SIZES]=SCHB2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[98,62,737,493])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Step Fcn',[sys,'/','vstup'])
set_param([sys,'/','vstup'],...
		'Time','0',...
		'Before','0.1',...
		'position',[20,30,40,50])

add_block('built-in/Sum',[sys,'/','_'])
set_param([sys,'/','_'],...
		'inputs','+-',...
		'position',[80,35,100,55])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y1',...
		'buffer','10000',...
		'position',[395,37,445,53])

add_block('built-in/Fcn',[sys,'/','c'])
set_param([sys,'/','c'],...
		'Expr','5*u(1)',...
		'position',[115,34,165,56])

add_block('built-in/Fcn',[sys,'/','c1'])
set_param([sys,'/','c1'],...
		'Expr','u(1)*u(1)',...
		'position',[310,35,350,55])

add_block('built-in/Saturation',[sys,'/','Saturation'])
set_param([sys,'/','Saturation'],...
		'Lower Limit','0',...
		'Upper Limit','1.1',...
		'position',[250,31,280,59])


%     Subsystem  ['Discrete-Time',13,'Integrator'].

new_system([sys,'/',['Discrete-Time',13,'Integrator']])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'Mask Entries','0.1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator'].

set_param([sys,'/',['Discrete-Time',13,'Integrator']],...
		'position',[180,24,220,66])


%     Subsystem  ['Discrete-Time',13,'Integrator1'].

new_system([sys,'/',['Discrete-Time',13,'Integrator1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator1/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator1/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator1/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator1/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Entries','0.1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator1'].

set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'position',[185,204,225,246])

add_block('built-in/Step Fcn',[sys,'/','vstup1'])
set_param([sys,'/','vstup1'],...
		'Time','0',...
		'Before','0.1',...
		'position',[20,210,40,230])

add_block('built-in/Sum',[sys,'/','_1'])
set_param([sys,'/','_1'],...
		'inputs','+-',...
		'position',[80,215,100,235])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','y3',...
		'buffer','10000',...
		'position',[395,217,445,233])

add_block('built-in/Fcn',[sys,'/','c3'])
set_param([sys,'/','c3'],...
		'Expr','0.5*u(1)',...
		'position',[115,214,165,236])

add_block('built-in/Fcn',[sys,'/','c2'])
set_param([sys,'/','c2'],...
		'Expr','u(1)*u(1)',...
		'position',[310,215,350,235])

add_block('built-in/Saturation',[sys,'/','Saturation1'])
set_param([sys,'/','Saturation1'],...
		'Lower Limit','0',...
		'Upper Limit','1.1',...
		'position',[250,211,280,239])


%     Subsystem  ['Discrete-Time',13,'Integrator2'].

new_system([sys,'/',['Discrete-Time',13,'Integrator2']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator2/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator2/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator2/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator2/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Entries','1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator2'].

set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'position',[180,109,220,151])

add_block('built-in/Saturation',[sys,'/','Saturation2'])
set_param([sys,'/','Saturation2'],...
		'Lower Limit','0',...
		'Upper Limit','1.1',...
		'position',[250,116,280,144])

add_block('built-in/Fcn',[sys,'/','c4'])
set_param([sys,'/','c4'],...
		'Expr','u(1)*u(1)',...
		'position',[310,120,350,140])

add_block('built-in/Fcn',[sys,'/','c5'])
set_param([sys,'/','c5'],...
		'Expr','5*u(1)',...
		'position',[115,119,165,141])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'mat-name','y1',...
		'buffer','10000',...
		'position',[395,122,445,138])

add_block('built-in/Sum',[sys,'/','_2'])
set_param([sys,'/','_2'],...
		'inputs','+-',...
		'position',[80,120,100,140])

add_block('built-in/Step Fcn',[sys,'/','vstup2'])
set_param([sys,'/','vstup2'],...
		'Time','0',...
		'Before','1',...
		'After','0.1',...
		'position',[20,115,40,135])

add_block('built-in/Saturation',[sys,'/','Saturation3'])
set_param([sys,'/','Saturation3'],...
		'Lower Limit','0',...
		'Upper Limit','1.1',...
		'position',[250,301,280,329])

add_block('built-in/Fcn',[sys,'/','c6'])
set_param([sys,'/','c6'],...
		'Expr','u(1)*u(1)',...
		'position',[310,305,350,325])

add_block('built-in/Fcn',[sys,'/','c7'])
set_param([sys,'/','c7'],...
		'Expr','0.5*u(1)',...
		'position',[115,304,165,326])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'mat-name','y4',...
		'buffer','10000',...
		'position',[395,307,445,323])

add_block('built-in/Sum',[sys,'/','_3'])
set_param([sys,'/','_3'],...
		'inputs','+-',...
		'position',[80,305,100,325])

add_block('built-in/Step Fcn',[sys,'/','vstup3'])
set_param([sys,'/','vstup3'],...
		'Time','0',...
		'Before','1',...
		'After','0.1',...
		'position',[20,300,40,320])


%     Subsystem  ['Discrete-Time',13,'Integrator3'].

new_system([sys,'/',['Discrete-Time',13,'Integrator3']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator3/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator3/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator3/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator3/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Entries','1\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator3'].

set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'position',[185,294,225,336])
add_line(sys,[45,40;75,40])
add_line(sys,[105,45;110,45])
add_line(sys,[170,45;175,45])
add_line(sys,[355,45;390,45])
add_line(sys,[355,45;355,100;260,100;140,100;55,100;55,50;75,50])
add_line(sys,[285,45;305,45])
add_line(sys,[225,45;245,45])
add_line(sys,[230,225;245,225])
add_line(sys,[285,225;305,225])
add_line(sys,[355,225;390,225])
add_line(sys,[355,225;355,280;55,280;55,230;75,230])
add_line(sys,[170,225;180,225])
add_line(sys,[105,225;110,225])
add_line(sys,[45,220;75,220])
add_line(sys,[225,130;245,130])
add_line(sys,[285,130;305,130])
add_line(sys,[355,130;390,130])
add_line(sys,[355,130;355,185;55,185;55,135;75,135])
add_line(sys,[170,130;175,130])
add_line(sys,[105,130;110,130])
add_line(sys,[45,125;75,125])
add_line(sys,[45,310;75,310])
add_line(sys,[105,315;110,315])
add_line(sys,[170,315;180,315])
add_line(sys,[355,315;390,315])
add_line(sys,[355,315;355,370;55,370;55,320;75,320])
add_line(sys,[285,315;305,315])
add_line(sys,[230,315;245,315])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
