function [ret,x0,str,ts,xts]=labak12(t,x,u,flag);
%LABAK12	is the M-file description of the SIMULINK system named LABAK12.
%	The block-diagram can be displayed by typing: LABAK12.
%
%	SYS=LABAK12(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes LABAK12 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling LABAK12 with a FLAG of zero:
%	[SIZES]=LABAK12([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[0,38,784,556])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-6')
set_param(sys,'Return vars',   't')

add_block('built-in/Integrator',[sys,'/','Integrator2'])
set_param([sys,'/','Integrator2'],...
		'Initial','0.00001',...
		'position',[235,195,255,215])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'Initial','0.00001',...
		'position',[235,130,255,150])

add_block('built-in/Fcn',[sys,'/','Fcn'])
set_param([sys,'/','Fcn'],...
		'Expr','sqrt(u[1])',...
		'position',[370,170,410,190])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'inputs','+-',...
		'position',[310,170,330,190])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'Gain','beta1',...
		'position',[435,167,460,193])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'Gain','beta2',...
		'position',[435,222,460,248])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'inputs','+-',...
		'position',[505,230,525,250])

add_block('built-in/Fcn',[sys,'/','Fcn1'])
set_param([sys,'/','Fcn1'],...
		'Expr','sqrt(u[1])',...
		'position',[345,275,385,295])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'Gain','beta3',...
		'position',[435,272,460,298])

add_block('built-in/Note',[sys,'/','dh2//dt'])
set_param([sys,'/','dh2//dt'],...
		'position',[545,220,550,225])

add_block('built-in/Note',[sys,'/','dh1//dt'])
set_param([sys,'/','dh1//dt'],...
		'position',[555,145,560,150])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'inputs','+-',...
		'position',[530,165,550,185])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'position',[310,94,340,126])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'buffer','20000',...
		'position',[330,222,380,238])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'After','h2w',...
		'position',[190,85,210,105])

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'MATLAB Fcn','reg(u(1),u(2),u(3),u(4))',...
		'Output Width','1',...
		'position',[360,93,420,127])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'Gain','1/S1',...
		'position',[465,97,490,123])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','aa',...
		'buffer','20000',...
		'position',[485,22,535,38])
add_line(sys,[260,205;295,205;305,185])
add_line(sys,[335,180;365,180])
add_line(sys,[260,140;295,140;305,175])
add_line(sys,[415,180;430,180])
add_line(sys,[415,180;415,235;430,235])
add_line(sys,[465,235;500,235])
add_line(sys,[275,205;275,285;340,285])
add_line(sys,[390,285;430,285])
add_line(sys,[465,285;475,285;475,245;500,245])
add_line(sys,[530,240;570,240;570,375;180,375;180,205;230,205])
add_line(sys,[465,180;525,180])
add_line(sys,[495,110;515,110;525,170])
add_line(sys,[555,175;575,175;575,80;180,80;180,140;230,140])
add_line(sys,[345,110;355,110])
add_line(sys,[215,95;305,95])
add_line(sys,[220,140;225,105;305,105])
add_line(sys,[200,205;200,180;275,180;275,115;305,115])
add_line(sys,[275,230;325,230])
add_line(sys,[290,140;290,125;305,125])
add_line(sys,[425,110;460,110])
add_line(sys,[440,110;440,30;480,30])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
