function [ret,x0,str,ts,xts]=schema(t,x,u,flag);
%SCHEMA	is the M-file description of the SIMULINK system named SCHEMA.
%	The block-diagram can be displayed by typing: SCHEMA.
%
%	SYS=SCHEMA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCHEMA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCHEMA with a FLAG of zero:
%	[SIZES]=SCHEMA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[33,307,665,608])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '200')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Hydraul.sust.'.

new_system([sys,'/','Hydraul.sust.'])
set_param([sys,'/','Hydraul.sust.'],'Location',[232,190,762,420])

add_block('built-in/Note',[sys,'/','Hydraul.sust./h2'])
set_param([sys,'/','Hydraul.sust./h2'],...
		'position',[420,80,425,85])

add_block('built-in/Outport',[sys,'/','Hydraul.sust./out_2'])
set_param([sys,'/','Hydraul.sust./out_2'],...
		'Port','2',...
		'position',[455,45,475,65])

add_block('built-in/Outport',[sys,'/','Hydraul.sust./out_1'])
set_param([sys,'/','Hydraul.sust./out_1'],...
		'position',[285,45,305,65])

add_block('built-in/Inport',[sys,'/','Hydraul.sust./in_1'])
set_param([sys,'/','Hydraul.sust./in_1'],...
		'position',[35,80,55,100])

add_block('built-in/Integrator',[sys,'/','Hydraul.sust./Integrator'])
set_param([sys,'/','Hydraul.sust./Integrator'],...
		'Initial','.00001',...
		'position',[220,85,240,105])

add_block('built-in/Sum',[sys,'/','Hydraul.sust./Sum'])
set_param([sys,'/','Hydraul.sust./Sum'],...
		'inputs','+-',...
		'position',[160,85,180,105])

add_block('built-in/Gain',[sys,'/','Hydraul.sust./Gain'])
set_param([sys,'/','Hydraul.sust./Gain'],...
		'Gain','1/S1',...
		'position',[105,80,125,100])

add_block('built-in/Fcn',[sys,'/','Hydraul.sust./Fcn'])
set_param([sys,'/','Hydraul.sust./Fcn'],...
		'orientation',2,...
		'Expr','beta1*sqrt(u(1)-u(2))',...
		'position',[180,147,225,163])

add_block('built-in/Mux',[sys,'/','Hydraul.sust./Mux'])
set_param([sys,'/','Hydraul.sust./Mux'],...
		'orientation',1,...
		'inputs','2',...
		'position',[437,140,468,175])

add_block('built-in/Fcn',[sys,'/','Hydraul.sust./Fcn1'])
set_param([sys,'/','Hydraul.sust./Fcn1'],...
		'orientation',2,...
		'Expr','beta2*sqrt(u(1)-u(2))-beta3*sqrt(u(2))',...
		'position',[355,147,400,163])

add_block('built-in/Integrator',[sys,'/','Hydraul.sust./Integrator1'])
set_param([sys,'/','Hydraul.sust./Integrator1'],...
		'Initial','.000001',...
		'position',[380,85,400,105])

add_block('built-in/Note',[sys,'/','Hydraul.sust./h1'])
set_param([sys,'/','Hydraul.sust./h1'],...
		'position',[255,80,260,85])

add_block('built-in/Note',[sys,'/','Hydraul.sust./dh2//dt'])
set_param([sys,'/','Hydraul.sust./dh2//dt'],...
		'position',[345,75,350,80])

add_block('built-in/Note',[sys,'/','Hydraul.sust./dh1//dt'])
set_param([sys,'/','Hydraul.sust./dh1//dt'],...
		'position',[195,75,200,80])

add_block('built-in/Note',[sys,'/','Hydraul.sust./1//S1'])
set_param([sys,'/','Hydraul.sust./1//S1'],...
		'position',[110,55,115,60])

add_block('built-in/Note',[sys,'/','Hydraul.sust./q1'])
set_param([sys,'/','Hydraul.sust./q1'],...
		'position',[75,65,80,70])

add_block('built-in/Note',[sys,'/','Hydraul.sust./beta1*sqrt....'])
set_param([sys,'/','Hydraul.sust./beta1*sqrt....'],...
		'position',[180,175,185,180])

add_block('built-in/Note',[sys,'/','Hydraul.sust./beta2*....-beta3*.....'])
set_param([sys,'/','Hydraul.sust./beta2*....-beta3*.....'],...
		'position',[365,190,370,195])

add_block('built-in/Outport',[sys,'/','Hydraul.sust./out_3'])
set_param([sys,'/','Hydraul.sust./out_3'],...
		'Port','3',...
		'position',[365,40,385,60])
add_line([sys,'/','Hydraul.sust.'],[405,95;435,95;435,55;450,55])
add_line([sys,'/','Hydraul.sust.'],[245,95;270,95;280,55])
add_line([sys,'/','Hydraul.sust.'],[60,90;100,90])
add_line([sys,'/','Hydraul.sust.'],[185,95;215,95])
add_line([sys,'/','Hydraul.sust.'],[175,155;140,155;140,100;155,100])
add_line([sys,'/','Hydraul.sust.'],[130,90;155,90])
add_line([sys,'/','Hydraul.sust.'],[350,155;315,155;315,95;375,95])
add_line([sys,'/','Hydraul.sust.'],[245,95;260,95;260,125;445,135])
add_line([sys,'/','Hydraul.sust.'],[405,95;460,95;460,135])
add_line([sys,'/','Hydraul.sust.'],[455,180;455,185;240,185;230,155])
add_line([sys,'/','Hydraul.sust.'],[415,185;405,155])
add_line([sys,'/','Hydraul.sust.'],[325,95;325,50;360,50])
set_param([sys,'/','Hydraul.sust.'],...
		'Mask Display','plot ([-10 10],[0 0],[-7.5 -7.5 7.5 7.5],[5 0 0 5],[-4 -4 4 4],[5 0.5 0.5 5],[-7.5 -4],[4 4],[4 7.5],[2 2])')


%     Finished composite block 'Hydraul.sust.'.

set_param([sys,'/','Hydraul.sust.'],...
		'position',[275,67,330,123])


%     Subsystem  'regulator'.

new_system([sys,'/','regulator'])
set_param([sys,'/','regulator'],'Location',[90,289,427,552])

add_block('built-in/Mux',[sys,'/','regulator/Mux'])
set_param([sys,'/','regulator/Mux'],...
		'position',[65,47,95,83])

add_block('built-in/MATLAB Fcn',[sys,'/','regulator/MATLAB Fcn'])
set_param([sys,'/','regulator/MATLAB Fcn'],...
		'MATLAB Fcn','spojity(u,m1,m2,pol1,pol2,Umin,Umax,S1,beta1,beta2,beta3)',...
		'Output Width','1',...
		'position',[120,48,180,82])

add_block('built-in/Outport',[sys,'/','regulator/out_1'])
set_param([sys,'/','regulator/out_1'],...
		'position',[205,55,225,75])

add_block('built-in/Inport',[sys,'/','regulator/in_3'])
set_param([sys,'/','regulator/in_3'],...
		'Port','3',...
		'position',[15,65,35,85])

add_block('built-in/Inport',[sys,'/','regulator/in_1'])
set_param([sys,'/','regulator/in_1'],...
		'position',[15,15,35,35])

add_block('built-in/Inport',[sys,'/','regulator/in_2'])
set_param([sys,'/','regulator/in_2'],...
		'Port','2',...
		'position',[15,45,35,65])

add_block('built-in/Inport',[sys,'/','regulator/in_4'])
set_param([sys,'/','regulator/in_4'],...
		'Port','4',...
		'position',[15,115,35,135])
add_line([sys,'/','regulator'],[100,65;115,65])
add_line([sys,'/','regulator'],[40,25;60,50])
add_line([sys,'/','regulator'],[185,65;200,65])
add_line([sys,'/','regulator'],[40,55;60,60])
add_line([sys,'/','regulator'],[40,75;60,70])
add_line([sys,'/','regulator'],[40,125;45,125;45,80;60,80])


%     Finished composite block 'regulator'.

set_param([sys,'/','regulator'],...
		'position',[195,77,235,113])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','h',...
		'position',[545,162,595,178])

add_block('built-in/Note',[sys,'/','h2'])
set_param([sys,'/','h2'],...
		'position',[350,85,355,90])

add_block('built-in/Step Fcn',[sys,'/','Zelana hladina h2[m]'])
set_param([sys,'/','Zelana hladina h2[m]'],...
		'Time','0',...
		'After','0.1',...
		'position',[60,98,80,122])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','2',...
		'position',[435,70,470,110])


%     Subsystem  ['Double click',13,'on this for demo.4'].

new_system([sys,'/',['Double click',13,'on this for demo.4']])
set_param([sys,'/',['Double click',13,'on this for demo.4']],'Location',[4,307,131,460])
set_param([sys,'/',['Double click',13,'on this for demo.4']],...
		'Mask Display','INICIALIZACIA',...
		'Mask Dialogue','eval(''datasch'')')


%     Finished composite block ['Double click',13,'on this for demo.4'].

set_param([sys,'/',['Double click',13,'on this for demo.4']],...
		'hide name',0,...
		'position',[30,230,130,261])


%     Subsystem  'Graph'.

new_system([sys,'/','Graph'])
set_param([sys,'/','Graph'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Graph/x'])
set_param([sys,'/','Graph/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Graph'],[90,65;125,65])
set_param([sys,'/','Graph'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph'],...
		'Mask Entries','200\/0\/0.25\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Graph'.

set_param([sys,'/','Graph'],...
		'position',[535,71,565,109])

add_block('built-in/Note',[sys,'/','h1'])
set_param([sys,'/','h1'],...
		'position',[350,50,355,55])


%     Subsystem  'Graph1'.

new_system([sys,'/','Graph1'])
set_param([sys,'/','Graph1'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Graph1/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Graph1/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Graph1/x'])
set_param([sys,'/','Graph1/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Graph1'],[90,65;125,65])
set_param([sys,'/','Graph1'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Graph1'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Graph1'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Graph1'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Graph1'],...
		'Mask Entries','200\/-2e-5\/2e-5\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Graph1'.

set_param([sys,'/','Graph1'],...
		'position',[295,11,325,49])

add_block('built-in/Note',[sys,'/','derivacia h2'])
set_param([sys,'/','derivacia h2'],...
		'position',[280,185,285,190])
add_line(sys,[335,95;370,95;370,165;145,165;145,90;190,90])
add_line(sys,[335,75;395,75;395,150;165,150;165,80;190,80])
add_line(sys,[240,95;270,95])
add_line(sys,[395,80;430,80])
add_line(sys,[370,105;415,105;430,100])
add_line(sys,[475,90;530,90])
add_line(sys,[475,90;505,90;505,170;540,170])
add_line(sys,[335,115;350,115;350,205;130,205;130,100;190,100])
add_line(sys,[85,110;190,110])
add_line(sys,[250,95;250,30;290,30])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
