function [ret,x0,str,ts,xts]=s03(t,x,u,flag);
%S03	is the M-file description of the SIMULINK system named S03.
%	The block-diagram can be displayed by typing: S03.
%
%	SYS=S03(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S03 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S03 with a FLAG of zero:
%	[SIZES]=S03([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,761,656])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[145,80,165,100])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[70,75,90,95])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','C',...
		'position',[185,73,215,107])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn']],...
		'Numerator','[1 0]',...
		'Denominator','[1 -1]',...
		'Sample time','Tvzor',...
		'position',[240,72,285,108])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'orientation',2,...
		'Denominator','[6 11 6 1]',...
		'position',[330,379,455,421])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',1,...
		'hide name',0,...
		'inputs','+-',...
		'position',[270,305,290,325])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay2'])
set_param([sys,'/','Unit Delay2'],...
		'orientation',1,...
		'position',[150,240,210,270])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'orientation',1,...
		'hide name',0,...
		'Gain','K',...
		'position',[167,180,193,210])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'orientation',1,...
		'hide name',0,...
		'Gain','K',...
		'position',[367,175,393,205])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[95,475,115,495])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'buffer','10000000',...
		'position',[160,476,215,494])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'orientation',2,...
		'hide name',0,...
		'position',[245,385,265,405])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'hide name',0,...
		'Gain','K',...
		'position',[425,75,450,105])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'buffer','10000000',...
		'position',[565,82,615,98])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay'])
set_param([sys,'/','Unit Delay'],...
		'orientation',1,...
		'Sample time','(k+1)',...
		'position',[350,235,410,265])
add_line(sys,[290,90;380,90;380,155;180,155;180,175])
add_line(sys,[95,85;140,85])
add_line(sys,[220,90;235,90])
add_line(sys,[170,90;180,90])
add_line(sys,[120,485;155,485])
add_line(sys,[180,215;180,235])
add_line(sys,[380,155;380,170])
add_line(sys,[380,210;380,230])
add_line(sys,[180,275;180,280;275,280;275,300])
add_line(sys,[325,400;270,400])
add_line(sys,[280,330;280,340;280,340;280,390;270,390])
add_line(sys,[240,395;130,395;140,95])
add_line(sys,[380,90;420,90])
add_line(sys,[455,90;560,90])
add_line(sys,[510,90;510,400;460,400])
add_line(sys,[380,270;380,285;285,300])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
