function [ret,x0,str,ts,xts]=s04(t,x,u,flag);
%S04	is the M-file description of the SIMULINK system named S04.
%	The block-diagram can be displayed by typing: S04.
%
%	SYS=S04(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S04 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S04 with a FLAG of zero:
%	[SIZES]=S04([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[84,168,862,605])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','C',...
		'position',[195,68,225,102])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[155,75,175,95])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[80,70,100,90])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'position',[255,59,280,111])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'buffer','10000000',...
		'position',[600,77,650,93])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','t',...
		'buffer','10000000',...
		'position',[200,377,250,393])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[140,375,160,395])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'orientation',2,...
		'Denominator','[6 11 6 1]',...
		'position',[420,309,545,351])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'orientation',2,...
		'hide name',0,...
		'position',[270,315,290,335])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'Gain','K',...
		'position',[430,70,455,100])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'orientation',1,...
		'hide name',0,...
		'Gain','K',...
		'position',[407,160,433,190])

add_block('built-in/Transport Delay',[sys,'/','Transport Delay'])
set_param([sys,'/','Transport Delay'],...
		'orientation',1,...
		'Delay Time','Ta',...
		'position',[397,215,443,245])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',1,...
		'hide name',0,...
		'inputs','+-',...
		'position',[345,275,365,295])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'orientation',1,...
		'hide name',0,...
		'Gain','K',...
		'position',[262,190,288,220])
add_line(sys,[285,85;425,85])
add_line(sys,[105,80;150,80])
add_line(sys,[460,85;595,85])
add_line(sys,[230,85;250,85])
add_line(sys,[180,85;190,85])
add_line(sys,[165,385;195,385])
add_line(sys,[420,195;420,210])
add_line(sys,[560,85;550,330])
add_line(sys,[275,225;275,260;350,270])
add_line(sys,[420,250;420,260;360,270])
add_line(sys,[415,330;295,330])
add_line(sys,[355,300;355,320;295,320])
add_line(sys,[265,325;140,325;150,90])
add_line(sys,[350,85;350,130;275,130;275,185])
add_line(sys,[350,130;420,130;420,155])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
