function [ret,x0,str,ts,xts]=cv4_3a(t,x,u,flag);
%CV4_3A	is the M-file description of the SIMULINK system named CV4_3A.
%	The block-diagram can be displayed by typing: CV4_3A.
%
%	SYS=CV4_3A(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes CV4_3A to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling CV4_3A with a FLAG of zero:
%	[SIZES]=CV4_3A([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[145,175,778,494])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn']],...
		'Numerator','[.5 0]',...
		'Denominator','[1 -1]',...
		'Sample time','0.3',...
		'position',[140,17,185,53])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[100,25,120,45])

add_block('built-in/Gain',[sys,'/','k'])
set_param([sys,'/','k'],...
		'Gain','2',...
		'position',[420,22,445,48])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[45,20,65,40])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','y',...
		'buffer','20000',...
		'position',[495,27,545,43])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',2,...
		'position',[100,195,120,215])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'orientation',1,...
		'Gain','0.9670',...
		'position',[212,85,238,115])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn1']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn1']],...
		'orientation',1,...
		'hide name',0,...
		'Numerator','[1 -1]',...
		'Denominator','[1 0 0]',...
		'Sample time','0.3',...
		'position',[202,135,248,175])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn3'])
set_param([sys,'/','Transfer Fcn3'],...
		'orientation',2,...
		'Denominator','[6 11 6 1]',...
		'position',[315,220,435,260])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn2']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn2']],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','[1 -1.8096 0.8187]',...
		'Denominator','[0.0091 0 0]',...
		'Sample time','0.3',...
		'position',[155,219,305,261])
add_line(sys,[125,35;135,35])
add_line(sys,[450,35;490,35])
add_line(sys,[450,35;440,240])
add_line(sys,[70,30;95,30])
add_line(sys,[190,35;415,35])
add_line(sys,[95,205;75,205;75,40;95,40])
add_line(sys,[225,35;225,80])
add_line(sys,[225,120;225,130])
add_line(sys,[225,180;225,200;125,200])
add_line(sys,[310,240;310,240])
add_line(sys,[150,240;145,240;145,210;125,210])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
