function [ret,x0,str,ts,xts]=s1(t,x,u,flag);
%S1	is the M-file description of the SIMULINK system named S1.
%	The block-diagram can be displayed by typing: S1.
%
%	SYS=S1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S1 with a FLAG of zero:
%	[SIZES]=S1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[145,175,800,419])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '250')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[220,25,240,45])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'position',[40,20,60,40])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y',...
		'buffer','20000',...
		'position',[540,27,590,43])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'hide name',0,...
		'Numerator','[T1 1]',...
		'Denominator','[1 0]',...
		'position',[325,12,410,58])

add_block('built-in/Gain',[sys,'/','k1'])
set_param([sys,'/','k1'],...
		'hide name',0,...
		'Gain','C1',...
		'position',[265,17,305,53])

add_block('built-in/Gain',[sys,'/','k2'])
set_param([sys,'/','k2'],...
		'hide name',0,...
		'Gain','K',...
		'position',[445,17,485,53])

add_block('built-in/Transfer Fcn',[sys,'/','O'])
set_param([sys,'/','O'],...
		'orientation',2,...
		'Denominator','[6 11 6 1]',...
		'position',[310,82,430,128])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn1'])
set_param([sys,'/','Transfer Fcn1'],...
		'hide name',0,...
		'Denominator','[T1 1]',...
		'position',[95,8,175,52])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','t',...
		'buffer','10000000',...
		'position',[135,106,190,124])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[70,105,90,125])
add_line(sys,[490,35;535,35])
add_line(sys,[305,105;205,105;215,40])
add_line(sys,[65,30;90,30])
add_line(sys,[180,30;215,30])
add_line(sys,[415,35;440,35])
add_line(sys,[310,35;320,35])
add_line(sys,[245,35;260,35])
add_line(sys,[510,35;510,105;435,105])
add_line(sys,[95,115;130,115])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
