function [ret,x0,str,ts,xts]=s2(t,x,u,flag);
%S2	is the M-file description of the SIMULINK system named S2.
%	The block-diagram can be displayed by typing: S2.
%
%	SYS=S2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S2 with a FLAG of zero:
%	[SIZES]=S2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[145,175,669,354])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '250')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Gain',[sys,'/','k2'])
set_param([sys,'/','k2'],...
		'hide name',0,...
		'Gain','K',...
		'position',[315,22,355,58])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'hide name',0,...
		'Numerator','[ 1]',...
		'Denominator','[1 0]',...
		'position',[230,18,265,62])

add_block('built-in/Gain',[sys,'/','k1'])
set_param([sys,'/','k1'],...
		'hide name',0,...
		'Gain','C1',...
		'position',[160,22,200,58])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','t',...
		'buffer','10000000',...
		'position',[105,121,160,139])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[40,120,60,140])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'position',[35,25,55,45])

add_block('built-in/Transfer Fcn',[sys,'/','O'])
set_param([sys,'/','O'],...
		'orientation',2,...
		'Denominator','[6 11 6 1]',...
		'position',[195,87,315,133])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y',...
		'buffer','20000',...
		'position',[425,32,475,48])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,30,125,50])
add_line(sys,[360,40;420,40])
add_line(sys,[190,110;90,110;100,45])
add_line(sys,[60,35;100,35])
add_line(sys,[270,40;310,40])
add_line(sys,[205,40;225,40])
add_line(sys,[130,40;155,40])
add_line(sys,[395,40;395,110;320,110])
add_line(sys,[65,130;100,130])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
