function [ret,x0,str,ts,xts]=s3(t,x,u,flag);
%S3	is the M-file description of the SIMULINK system named S3.
%	The block-diagram can be displayed by typing: S3.
%
%	SYS=S3(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S3 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S3 with a FLAG of zero:
%	[SIZES]=S3([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[6,52,577,392])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn1']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn1']],...
		'orientation',1,...
		'hide name',0,...
		'Numerator','[1 -1]',...
		'Denominator','[1 0 0]',...
		'Sample time','Tvzor',...
		'position',[269,160,331,205])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn2']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn2']],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','[1 -(D1+D2) D1*D2]',...
		'Denominator','[1 0 0]',...
		'Sample time','Tvzor',...
		'position',[240,239,415,281])

add_block('built-in/Transfer Fcn',[sys,'/','O'])
set_param([sys,'/','O'],...
		'orientation',1,...
		'Denominator','[6 11 6 1]',...
		'position',[387,170,513,210])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'position',[20,40,40,60])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[100,45,120,65])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[20,10,40,30])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','t',...
		'buffer','10000000',...
		'position',[85,11,140,29])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn']],...
		'hide name',0,...
		'Numerator','[1 0]',...
		'Denominator','[1 -1]',...
		'Sample time','Tvzor',...
		'position',[215,34,265,76])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','C',...
		'position',[150,38,190,72])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',2,...
		'hide name',0,...
		'position',[95,191,110,284])

add_block('built-in/Gain',[sys,'/','1 // (b1+b0)'])
set_param([sys,'/','1 // (b1+b0)'],...
		'orientation',2,...
		'Gain','1/(b1+b0)',...
		'position',[155,244,205,276])

add_block('built-in/Gain',[sys,'/','K'])
set_param([sys,'/','K'],...
		'move name',0,...
		'Gain','K',...
		'position',[355,31,395,79])

add_block('built-in/Gain',[sys,'/','(b0*K) // (b1+b0)'])
set_param([sys,'/','(b0*K) // (b1+b0)'],...
		'orientation',1,...
		'Gain','(b0*K)/(b1+b0)',...
		'position',[283,90,317,140])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y',...
		'buffer','20000',...
		'position',[495,39,530,71])

add_block('built-in/Note',[sys,'/','Regultor'])
set_param([sys,'/','Regultor'],...
		'position',[190,80,195,85])
add_line(sys,[45,50;95,50])
add_line(sys,[90,240;75,240;75,60;95,60])
add_line(sys,[300,145;300,155])
add_line(sys,[300,210;300,215;115,215])
add_line(sys,[450,215;450,260;420,260])
add_line(sys,[195,55;210,55])
add_line(sys,[125,55;145,55])
add_line(sys,[400,55;490,55])
add_line(sys,[450,55;450,165])
add_line(sys,[270,55;350,55])
add_line(sys,[235,260;210,260])
add_line(sys,[150,260;115,260])
add_line(sys,[300,55;300,85])
add_line(sys,[45,20;80,20])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
