function [ret,x0,str,ts,xts]=s4(t,x,u,flag);
%S4	is the M-file description of the SIMULINK system named S4.
%	The block-diagram can be displayed by typing: S4.
%
%	SYS=S4(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes S4 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling S4 with a FLAG of zero:
%	[SIZES]=S4([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,881,610])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','t',...
		'buffer','10000000',...
		'position',[125,31,180,49])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[60,30,80,50])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[140,65,160,85])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'position',[60,60,80,80])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y',...
		'buffer','20000',...
		'position',[660,59,695,91])

add_block('built-in/Gain',[sys,'/','K'])
set_param([sys,'/','K'],...
		'move name',0,...
		'Gain','K',...
		'position',[565,51,605,99])

add_block('built-in/Transfer Fcn',[sys,'/','O'])
set_param([sys,'/','O'],...
		'orientation',1,...
		'Denominator','[6 11 6 1]',...
		'position',[567,185,693,225])

add_block('built-in/Gain',[sys,'/','(b0*K) // (b1+b0)'])
set_param([sys,'/','(b0*K) // (b1+b0)'],...
		'orientation',1,...
		'Gain','(b0*K)/(b1+b0)',...
		'position',[468,105,502,155])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn1']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn1']],...
		'orientation',1,...
		'hide name',0,...
		'Numerator','[1 -1]',...
		'Denominator','[1 0 0]',...
		'Sample time','Tvzor',...
		'position',[454,175,516,220])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'orientation',3,...
		'hide name',0,...
		'position',[88,215,137,235])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn3']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn3']],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','[1 -alfa22]',...
		'Denominator','[1 0]',...
		'Sample time','Tvzor',...
		'position',[435,334,610,376])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn']],...
		'hide name',0,...
		'Numerator','[1 0]',...
		'Denominator','[1 -1]',...
		'Sample time','Tvzor',...
		'position',[315,54,365,96])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','C',...
		'position',[235,58,275,92])

add_block('built-in/Note',[sys,'/','Regultor'])
set_param([sys,'/','Regultor'],...
		'position',[285,100,290,105])

add_block('built-in/Gain',[sys,'/','1-D1-(D1*beta2 // alfa21)'])
set_param([sys,'/','1-D1-(D1*beta2 // alfa21)'],...
		'orientation',2,...
		'Gain','1-D1-(D1*beta2/alfa21)',...
		'position',[180,244,230,276])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',2,...
		'hide name',0,...
		'position',[305,211,320,304])

add_block('built-in/Gain',[sys,'/','1 // (b1+b0)'])
set_param([sys,'/','1 // (b1+b0)'],...
		'orientation',2,...
		'Gain','1/(b1+b0)',...
		'position',[355,264,405,296])

add_block('built-in/Gain',[sys,'/','D1 // alfa21'])
set_param([sys,'/','D1 // alfa21'],...
		'orientation',2,...
		'Gain','D1 / alfa21',...
		'position',[355,339,405,371])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn2']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn2']],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','[1 -(D1+D2) D1*D2]',...
		'Denominator','[1 0 0]',...
		'Sample time','Tvzor',...
		'position',[440,259,615,301])
add_line(sys,[85,70;135,70])
add_line(sys,[485,160;485,170])
add_line(sys,[485,225;485,235;325,235])
add_line(sys,[630,230;620,280])
add_line(sys,[280,75;310,75])
add_line(sys,[165,75;230,75])
add_line(sys,[610,75;655,75])
add_line(sys,[370,75;560,75])
add_line(sys,[435,280;410,280])
add_line(sys,[350,280;325,280])
add_line(sys,[85,40;120,40])
add_line(sys,[630,75;630,180])
add_line(sys,[485,75;485,100])
add_line(sys,[300,260;235,260])
add_line(sys,[115,210;115,80;135,80])
add_line(sys,[175,260;125,260;125,240])
add_line(sys,[430,355;410,355])
add_line(sys,[350,355;100,355;100,240])
add_line(sys,[630,275;630,355;615,355])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
