function [ret,x0,str,ts,xts]=schema(t,x,u,flag);
%SCHEMA	is the M-file description of the SIMULINK system named SCHEMA.
%	The block-diagram can be displayed by typing: SCHEMA.
%
%	SYS=SCHEMA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCHEMA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCHEMA with a FLAG of zero:
%	[SIZES]=SCHEMA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[157,44,764,558])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '200')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Discrete Transfer Fcn',[sys,'/','regulator'])
set_param([sys,'/','regulator'],...
		'Denominator','[1 -1]',...
		'Sample time','Tv1',...
		'position',[225,7,270,43])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y1',...
		'buffer','10000',...
		'position',[405,17,455,33])

add_block('built-in/Fcn',[sys,'/','c'])
set_param([sys,'/','c'],...
		'Expr','cD1*u(1)',...
		'position',[145,15,185,35])

add_block('built-in/Gain',[sys,'/','c1'])
set_param([sys,'/','c1'],...
		'Gain','K',...
		'position',[315,12,340,38])

add_block('built-in/Sum',[sys,'/','_'])
set_param([sys,'/','_'],...
		'inputs','+-',...
		'position',[90,15,110,35])

add_block('built-in/Step Fcn',[sys,'/','vstup'])
set_param([sys,'/','vstup'],...
		'Time','0',...
		'position',[30,10,50,30])

add_block('built-in/Transfer Fcn',[sys,'/','oneskorenie'])
set_param([sys,'/','oneskorenie'],...
		'orientation',2,...
		'Denominator','[6    11     6     1]',...
		'position',[155,60,265,100])

add_block('built-in/Transfer Fcn',[sys,'/','oneskorenie1'])
set_param([sys,'/','oneskorenie1'],...
		'orientation',2,...
		'Denominator','[6    11     6     1]',...
		'position',[150,170,260,210])

add_block('built-in/Step Fcn',[sys,'/','vstup1'])
set_param([sys,'/','vstup1'],...
		'Time','0',...
		'position',[25,120,45,140])

add_block('built-in/Sum',[sys,'/','_1'])
set_param([sys,'/','_1'],...
		'inputs','+-',...
		'position',[85,125,105,145])

add_block('built-in/Gain',[sys,'/','c2'])
set_param([sys,'/','c2'],...
		'Gain','K',...
		'position',[310,122,335,148])

add_block('built-in/Fcn',[sys,'/','c3'])
set_param([sys,'/','c3'],...
		'Expr','cD2*u(1)',...
		'position',[140,125,180,145])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','y2',...
		'buffer','10000',...
		'position',[400,127,450,143])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','regulator1'])
set_param([sys,'/','regulator1'],...
		'Denominator','[1 -1]',...
		'Sample time','Tv2',...
		'position',[220,117,265,153])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','regulator2'])
set_param([sys,'/','regulator2'],...
		'Denominator','[1 -1]',...
		'Sample time','Tv1',...
		'position',[220,227,265,263])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'mat-name','y3',...
		'buffer','10000',...
		'position',[400,237,450,253])

add_block('built-in/Fcn',[sys,'/','c4'])
set_param([sys,'/','c4'],...
		'Expr','cK1*u(1)',...
		'position',[140,235,180,255])

add_block('built-in/Gain',[sys,'/','c5'])
set_param([sys,'/','c5'],...
		'Gain','K',...
		'position',[310,232,335,258])

add_block('built-in/Sum',[sys,'/','_2'])
set_param([sys,'/','_2'],...
		'inputs','+-',...
		'position',[85,235,105,255])

add_block('built-in/Step Fcn',[sys,'/','vstup2'])
set_param([sys,'/','vstup2'],...
		'Time','0',...
		'position',[25,230,45,250])

add_block('built-in/Transfer Fcn',[sys,'/','oneskorenie2'])
set_param([sys,'/','oneskorenie2'],...
		'orientation',2,...
		'Denominator','[6    11     6     1]',...
		'position',[150,280,260,320])

add_block('built-in/Transfer Fcn',[sys,'/','oneskorenie3'])
set_param([sys,'/','oneskorenie3'],...
		'orientation',2,...
		'Denominator','[6    11     6     1]',...
		'position',[150,615,260,655])

add_block('built-in/Step Fcn',[sys,'/','vstup3'])
set_param([sys,'/','vstup3'],...
		'Time','0',...
		'position',[25,565,45,585])

add_block('built-in/Sum',[sys,'/','_3'])
set_param([sys,'/','_3'],...
		'inputs','+-',...
		'position',[85,570,105,590])

add_block('built-in/Gain',[sys,'/','c6'])
set_param([sys,'/','c6'],...
		'Gain','K',...
		'position',[310,567,335,593])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'mat-name','y6',...
		'buffer','10000',...
		'position',[400,572,450,588])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'mat-name','y5',...
		'buffer','10000',...
		'position',[400,462,450,478])

add_block('built-in/Gain',[sys,'/','c9'])
set_param([sys,'/','c9'],...
		'Gain','K',...
		'position',[310,457,335,483])

add_block('built-in/Sum',[sys,'/','_4'])
set_param([sys,'/','_4'],...
		'inputs','+-',...
		'position',[85,460,105,480])

add_block('built-in/Step Fcn',[sys,'/','vstup4'])
set_param([sys,'/','vstup4'],...
		'Time','0',...
		'position',[25,455,45,475])

add_block('built-in/Transfer Fcn',[sys,'/','oneskorenie4'])
set_param([sys,'/','oneskorenie4'],...
		'orientation',2,...
		'Denominator','[6    11     6     1]',...
		'position',[150,505,260,545])

add_block('built-in/Transfer Fcn',[sys,'/','oneskorenie5'])
set_param([sys,'/','oneskorenie5'],...
		'orientation',2,...
		'Denominator','[6    11     6     1]',...
		'position',[155,395,265,435])

add_block('built-in/Step Fcn',[sys,'/','vstup5'])
set_param([sys,'/','vstup5'],...
		'Time','0',...
		'position',[30,345,50,365])

add_block('built-in/Sum',[sys,'/','_5'])
set_param([sys,'/','_5'],...
		'inputs','+-',...
		'position',[90,350,110,370])

add_block('built-in/Gain',[sys,'/','c10'])
set_param([sys,'/','c10'],...
		'Gain','K',...
		'position',[315,347,340,373])

add_block('built-in/Fcn',[sys,'/','c11'])
set_param([sys,'/','c11'],...
		'Expr','cK2*u(1)',...
		'position',[145,350,185,370])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'mat-name','y4',...
		'buffer','10000',...
		'position',[405,352,455,368])

add_block('built-in/Discrete Transfer Fcn',[sys,'/','regulator5'])
set_param([sys,'/','regulator5'],...
		'Denominator','[1 -1]',...
		'Sample time','Tv2',...
		'position',[225,342,270,378])

add_block('built-in/Note',[sys,'/','cD2,Tv2=2*T1'])
set_param([sys,'/','cD2,Tv2=2*T1'],...
		'position',[535,135,540,140])

add_block('built-in/Note',[sys,'/','cD1,Tv1=T1//2'])
set_param([sys,'/','cD1,Tv1=T1//2'],...
		'position',[535,30,540,35])

add_block('built-in/Note',[sys,'/','ck2,Tv2=2*T1'])
set_param([sys,'/','ck2,Tv2=2*T1'],...
		'position',[540,355,545,360])

add_block('built-in/Note',[sys,'/','ck1,Tv1=T12'])
set_param([sys,'/','ck1,Tv1=T12'],...
		'position',[535,230,540,235])

add_block('built-in/Note',[sys,'/','c1=1//(4*K*T1);'])
set_param([sys,'/','c1=1//(4*K*T1);'],...
		'position',[545,475,550,480])

add_block('built-in/Note',[sys,'/','c2=1//(exp(1)*K*T1)'])
set_param([sys,'/','c2=1//(exp(1)*K*T1)'],...
		'position',[540,590,545,595])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'Numerator','[c2]',...
		'Denominator','[1 0]',...
		'position',[190,562,225,598])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn1'])
set_param([sys,'/','Transfer Fcn1'],...
		'Numerator','[c1]',...
		'Denominator','[1 0]',...
		'position',[195,452,230,488])
add_line(sys,[55,20;85,20])
add_line(sys,[115,25;140,25])
add_line(sys,[190,25;220,25])
add_line(sys,[150,80;65,80;65,30;85,30])
add_line(sys,[275,25;310,25])
add_line(sys,[345,25;400,25])
add_line(sys,[365,25;365,80;270,80])
add_line(sys,[340,135;395,135])
add_line(sys,[360,135;360,190;265,190])
add_line(sys,[270,135;305,135])
add_line(sys,[145,190;60,190;60,140;80,140])
add_line(sys,[185,135;215,135])
add_line(sys,[110,135;135,135])
add_line(sys,[50,130;80,130])
add_line(sys,[50,240;80,240])
add_line(sys,[110,245;135,245])
add_line(sys,[185,245;215,245])
add_line(sys,[145,300;60,300;60,250;80,250])
add_line(sys,[270,245;305,245])
add_line(sys,[340,245;395,245])
add_line(sys,[360,245;360,300;265,300])
add_line(sys,[340,580;395,580])
add_line(sys,[360,580;360,635;265,635])
add_line(sys,[145,635;60,635;60,585;80,585])
add_line(sys,[110,580;185,580])
add_line(sys,[50,575;80,575])
add_line(sys,[50,465;80,465])
add_line(sys,[110,470;190,470])
add_line(sys,[145,525;60,525;60,475;80,475])
add_line(sys,[235,470;305,470])
add_line(sys,[340,470;395,470])
add_line(sys,[360,470;360,525;265,525])
add_line(sys,[345,360;400,360])
add_line(sys,[365,360;365,415;270,415])
add_line(sys,[275,360;310,360])
add_line(sys,[150,415;65,415;65,365;85,365])
add_line(sys,[190,360;220,360])
add_line(sys,[115,360;140,360])
add_line(sys,[55,355;85,355])
add_line(sys,[230,580;305,580])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
