function [ret,x0,str,ts,xts]=cv5_4b(t,x,u,flag);
%CV5_4B	is the M-file description of the SIMULINK system named CV5_4B.
%	The block-diagram can be displayed by typing: CV5_4B.
%
%	SYS=CV5_4B(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes CV5_4B to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling CV5_4B with a FLAG of zero:
%	[SIZES]=CV5_4B([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[145,175,778,494])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '.10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Gain',[sys,'/','k'])
set_param([sys,'/','k'],...
		'Gain','2',...
		'position',[420,32,445,58])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[45,30,65,50])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'mat-name','y',...
		'buffer','20000',...
		'position',[495,37,545,53])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[115,35,135,55])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn1']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn1']],...
		'Numerator','[0.5 0]',...
		'Denominator','[1 -1]',...
		'position',[160,27,205,63])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn']],...
		'orientation',1,...
		'hide name',0,...
		'Numerator','[0.574]',...
		'Denominator','[1 0 0]',...
		'Sample time','2',...
		'position',[192,115,238,155])

add_block('built-in/Gain',[sys,'/','k1'])
set_param([sys,'/','k1'],...
		'orientation',1,...
		'hide name',0,...
		'Gain','2',...
		'position',[267,120,293,150])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',1,...
		'hide name',0,...
		'inputs','-+-',...
		'position',[262,205,298,225])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn2']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn2']],...
		'orientation',1,...
		'hide name',0,...
		'Numerator','[1.426]',...
		'Denominator','[1 0]',...
		'Sample time','2',...
		'position',[332,115,378,155])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'orientation',2,...
		'position',[110,245,130,265])

add_block('built-in/Discrete Transfer Fcn',[sys,'/',['Discrete',13,'Transfer Fcn3']])
set_param([sys,'/',['Discrete',13,'Transfer Fcn3']],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','[1 -.5539]',...
		'Denominator','[(1-0.5539) 0]',...
		'Sample time','2',...
		'position',[180,254,265,296])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn3'])
set_param([sys,'/','Transfer Fcn3'],...
		'orientation',2,...
		'Denominator','[6 11 6 1]',...
		'position',[315,255,435,295])
add_line(sys,[140,45;155,45])
add_line(sys,[450,45;490,45])
add_line(sys,[450,45;440,275])
add_line(sys,[70,40;110,40])
add_line(sys,[210,45;415,45])
add_line(sys,[280,155;280,200])
add_line(sys,[215,160;215,185;270,185;270,200])
add_line(sys,[280,45;280,115])
add_line(sys,[280,90;215,90;215,110])
add_line(sys,[280,90;355,90;355,110])
add_line(sys,[355,160;355,185;290,185;290,200])
add_line(sys,[105,255;90,255;90,50;110,50])
add_line(sys,[280,230;280,250;135,250])
add_line(sys,[310,275;270,275])
add_line(sys,[175,275;170,275;170,260;135,260])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
