function [ret,x0,str,ts,xts]=mlp2(t,x,u,flag);
%MLP2	is the M-file description of the SIMULINK system named MLP2.
%	The block-diagram can be displayed by typing: MLP2.
%
%	SYS=MLP2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes MLP2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling MLP2 with a FLAG of zero:
%	[SIZES]=MLP2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[106,62,606,529])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '50')
set_param(sys,'Min step size', '0.001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'Time','0',...
		'position',[30,60,50,80])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','y',...
		'buffer','10000',...
		'position',[430,67,480,83])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'orientation',1,...
		'Numerator','[K]',...
		'Denominator','[T1 1]',...
		'position',[210,175,320,235])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'inputs','+-',...
		'position',[105,65,125,85])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn1'])
set_param([sys,'/','Transfer Fcn1'],...
		'Numerator','[c]',...
		'Denominator','[1 0]',...
		'position',[175,48,240,102])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'Gain','K',...
		'position',[270,62,295,88])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn2'])
set_param([sys,'/','Transfer Fcn2'],...
		'orientation',1,...
		'Numerator','[K]',...
		'Denominator','[T1 1]',...
		'position',[40,135,150,195])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn3'])
set_param([sys,'/','Transfer Fcn3'],...
		'orientation',2,...
		'Denominator','[6 11 6 1]',...
		'position',[370,135,480,195])

add_block('built-in/Transport Delay',[sys,'/',['Transport',13,'Delay']])
set_param([sys,'/',['Transport',13,'Delay']],...
		'orientation',1,...
		'Delay Time','1',...
		'position',[245,255,285,285])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'orientation',1,...
		'inputs','+-',...
		'position',[120,290,140,310])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'orientation',2,...
		'position',[125,330,145,350])
add_line(sys,[55,70;100,70])
add_line(sys,[130,75;170,75])
add_line(sys,[245,75;265,75])
add_line(sys,[245,75;265,75;265,170])
add_line(sys,[245,75;255,75;255,110;95,110;95,130])
add_line(sys,[265,240;265,250])
add_line(sys,[265,290;265,300;210,300;210,270;135,270;135,285])
add_line(sys,[95,200;95,235;125,235;125,285])
add_line(sys,[300,75;425,75])
add_line(sys,[300,75;335,75;335,105;505,105;505,165;485,165])
add_line(sys,[365,165;335,165;335,345;150,345])
add_line(sys,[130,315;130,325;165,325;165,335;150,335])
add_line(sys,[120,340;90,340;90,80;100,80])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
