function [ret,x0,str,ts,xts]=diskr72(t,x,u,flag);
%DISKR72	is the M-file description of the SIMULINK system named DISKR72.
%	The block-diagram can be displayed by typing: DISKR72.
%
%	SYS=DISKR72(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DISKR72 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DISKR72 with a FLAG of zero:
%	[SIZES]=DISKR72([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[105,73,920,687])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '0.05')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','t',...
		'buffer','1000000',...
		'position',[590,7,640,23])

add_block('built-in/Step Fcn',[sys,'/','Step Input2'])
set_param([sys,'/','Step Input2'],...
		'hide name',0,...
		'Time','0',...
		'position',[70,480,90,500])

add_block('built-in/To Workspace',[sys,'/','To Workspace6'])
set_param([sys,'/','To Workspace6'],...
		'hide name',0,...
		'mat-name','u3',...
		'buffer','1000000',...
		'position',[450,432,500,448])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','y3',...
		'buffer','1000000',...
		'position',[480,472,530,488])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn11'])
set_param([sys,'/','Transfer Fcn11'],...
		'hide name',0,...
		'Denominator','[3 1]',...
		'position',[540,512,575,548])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn10'])
set_param([sys,'/','Transfer Fcn10'],...
		'hide name',0,...
		'Denominator','[2 1]',...
		'position',[495,512,530,548])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn9'])
set_param([sys,'/','Transfer Fcn9'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[445,512,480,548])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn8'])
set_param([sys,'/','Transfer Fcn8'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[385,477,420,513])


%     Subsystem  ['Discrete-Time',13,'Integrator3'].

new_system([sys,'/',['Discrete-Time',13,'Integrator3']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator3/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator3/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator3/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator3/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator3/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator3']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator3'].

set_param([sys,'/',['Discrete-Time',13,'Integrator3']],...
		'hide name',0,...
		'position',[295,504,315,556])

add_block('built-in/Sum',[sys,'/','Sum7'])
set_param([sys,'/','Sum7'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[260,504,280,556])

add_block('built-in/Filter',[sys,'/','Filter7'])
set_param([sys,'/','Filter7'],...
		'hide name',0,...
		'Numerator','[1 -1]',...
		'Denominator','[1 ]',...
		'position',[205,495,240,535])

add_block('built-in/Gain',[sys,'/','Gain9'])
set_param([sys,'/','Gain9'],...
		'hide name',0,...
		'Gain','2.68375',...
		'position',[165,477,190,503])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,485,135,505])

add_block('built-in/Gain',[sys,'/','Gain8'])
set_param([sys,'/','Gain8'],...
		'hide name',0,...
		'Gain','0.6085',...
		'position',[165,532,190,558])

add_block('built-in/Filter',[sys,'/','Filter6'])
set_param([sys,'/','Filter6'],...
		'hide name',0,...
		'Numerator','[-1  2 -1]',...
		'Denominator','[1 ]',...
		'position',[200,555,235,595])

add_block('built-in/Gain',[sys,'/','Gain7'])
set_param([sys,'/','Gain7'],...
		'hide name',0,...
		'Gain','3.66777',...
		'position',[155,562,180,588])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'hide name',0,...
		'Gain','0',...
		'position',[105,377,130,403])

add_block('built-in/Filter',[sys,'/','Filter4'])
set_param([sys,'/','Filter4'],...
		'hide name',0,...
		'Numerator','[-1  2 -2]',...
		'Denominator','[1 ]',...
		'position',[150,370,185,410])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'hide name',0,...
		'Gain','0.274',...
		'position',[115,347,140,373])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[65,300,85,320])

add_block('built-in/Gain',[sys,'/','Gain6'])
set_param([sys,'/','Gain6'],...
		'hide name',0,...
		'Gain','2.104',...
		'position',[115,292,140,318])

add_block('built-in/Filter',[sys,'/','Filter5'])
set_param([sys,'/','Filter5'],...
		'hide name',0,...
		'Numerator','[1 -1]',...
		'Denominator','[1 ]',...
		'position',[155,310,190,350])

add_block('built-in/Sum',[sys,'/','Sum5'])
set_param([sys,'/','Sum5'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[210,319,230,371])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn4'])
set_param([sys,'/','Transfer Fcn4'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[335,292,370,328])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn5'])
set_param([sys,'/','Transfer Fcn5'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[395,327,430,363])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn6'])
set_param([sys,'/','Transfer Fcn6'],...
		'hide name',0,...
		'Denominator','[2 1]',...
		'position',[445,327,480,363])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn7'])
set_param([sys,'/','Transfer Fcn7'],...
		'hide name',0,...
		'Denominator','[3 1]',...
		'position',[490,327,525,363])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','y2',...
		'buffer','1000000',...
		'position',[430,287,480,303])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','u2',...
		'buffer','1000000',...
		'position',[400,247,450,263])

add_block('built-in/Step Fcn',[sys,'/','Step Input1'])
set_param([sys,'/','Step Input1'],...
		'hide name',0,...
		'Time','0',...
		'position',[20,295,40,315])

add_block('built-in/Gain',[sys,'/','Gain3'])
set_param([sys,'/','Gain3'],...
		'hide name',0,...
		'Gain','0',...
		'position',[95,192,120,218])

add_block('built-in/Filter',[sys,'/','Filter3'])
set_param([sys,'/','Filter3'],...
		'hide name',0,...
		'Numerator','[-1  2 -2]',...
		'Denominator','[1 ]',...
		'position',[140,185,175,225])

add_block('built-in/Gain',[sys,'/','Gain2'])
set_param([sys,'/','Gain2'],...
		'hide name',0,...
		'Gain','0',...
		'position',[105,162,130,188])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[55,115,75,135])

add_block('built-in/Filter',[sys,'/','Filter2'])
set_param([sys,'/','Filter2'],...
		'hide name',0,...
		'Numerator','[1 -1]',...
		'Denominator','[1 ]',...
		'position',[145,125,180,165])

add_block('built-in/Sum',[sys,'/','Sum4'])
set_param([sys,'/','Sum4'],...
		'hide name',0,...
		'inputs','+++',...
		'position',[200,134,220,186])


%     Subsystem  ['Discrete-Time',13,'Integrator1'].

new_system([sys,'/',['Discrete-Time',13,'Integrator1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],'Location',[392,641,765,859])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator1/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/in_1']],...
		'position',[25,70,45,90])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator1/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator1/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator1/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator1/out_1']],...
		'position',[320,85,340,105])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[115,80;145,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator1']],[285,95;285,165;120,165;120,110;145,110])
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator1'].

set_param([sys,'/',['Discrete-Time',13,'Integrator1']],...
		'hide name',0,...
		'position',[235,134,255,186])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[325,107,360,143])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn1'])
set_param([sys,'/','Transfer Fcn1'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[385,142,420,178])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn2'])
set_param([sys,'/','Transfer Fcn2'],...
		'hide name',0,...
		'Denominator','[2 1]',...
		'position',[435,142,470,178])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn3'])
set_param([sys,'/','Transfer Fcn3'],...
		'hide name',0,...
		'Denominator','[3 1]',...
		'position',[480,142,515,178])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y1',...
		'buffer','1000000',...
		'position',[420,102,470,118])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','u1',...
		'buffer','1000000',...
		'position',[390,62,440,78])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'position',[275,118,295,167])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'position',[10,110,30,130])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[520,10,540,30])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','2.49',...
		'position',[105,62,130,88])


%     Subsystem  ['Discrete-Time',13,'Integrator2'].

new_system([sys,'/',['Discrete-Time',13,'Integrator2']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],'Location',[392,641,765,859])

add_block('built-in/Outport',[sys,'/',['Discrete-Time',13,'Integrator2/out_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/out_1']],...
		'position',[320,85,340,105])

add_block('built-in/Gain',[sys,'/',['Discrete-Time',13,'Integrator2/Gain']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Gain']],...
		'Gain','Ts',...
		'position',[80,61,110,99])

add_block('built-in/Unit Delay',[sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Unit Delay']],...
		'Sample time','Ts',...
		'x0','X0',...
		'position',[210,85,260,105])

add_block('built-in/Sum',[sys,'/',['Discrete-Time',13,'Integrator2/Sum']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/Sum']],...
		'position',[150,63,180,127])

add_block('built-in/Inport',[sys,'/',['Discrete-Time',13,'Integrator2/in_1']])
set_param([sys,'/',['Discrete-Time',13,'Integrator2/in_1']],...
		'position',[25,70,45,90])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[265,95;315,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[285,95;285,165;120,165;120,110;145,110])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[185,95;205,95])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[50,80;75,80])
add_line([sys,'/',['Discrete-Time',13,'Integrator2']],[115,80;145,80])
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Display','dpoly(Ts,[1 -1],''z'')',...
		'Mask Type','Discrete-Time Integrator',...
		'Mask Dialogue','Discrete-Time Integrator:|Initial Condition:|Sample Time:')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Translate','X0=@1;Ts=@2;',...
		'Mask Help','Implements a zeroth order discrete\nintegration using a gain, a sum, and\na unit delay. Inputs may be scalar\nor vector.\n')
set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'Mask Entries','0\/1\/')


%     Finished composite block ['Discrete-Time',13,'Integrator2'].

set_param([sys,'/',['Discrete-Time',13,'Integrator2']],...
		'hide name',0,...
		'position',[245,316,295,374])
add_line(sys,[545,20;585,15])
add_line(sys,[35,120;50,120])
add_line(sys,[365,125;365,160;380,160])
add_line(sys,[425,160;430,160])
add_line(sys,[475,160;475,160])
add_line(sys,[520,160;520,225;40,225;50,130])
add_line(sys,[365,125;385,125;385,110;415,110])
add_line(sys,[300,145;320,125])
add_line(sys,[300,145;305,70;385,70])
add_line(sys,[225,160;230,160])
add_line(sys,[260,160;270,155])
add_line(sys,[185,145;195,145])
add_line(sys,[135,75;140,145])
add_line(sys,[135,175;185,175;195,160])
add_line(sys,[80,125;85,125;85,175;100,175])
add_line(sys,[40,205;90,205])
add_line(sys,[125,205;135,205])
add_line(sys,[180,205;185,205;195,175])
add_line(sys,[190,390;195,390;205,360])
add_line(sys,[135,390;145,390])
add_line(sys,[530,345;530,410;50,410;60,315])
add_line(sys,[50,390;100,390])
add_line(sys,[90,310;95,310;95,360;110,360])
add_line(sys,[145,360;195,360;205,345])
add_line(sys,[145,305;150,330])
add_line(sys,[195,330;205,330])
add_line(sys,[300,345;280,345;310,330;330,310])
add_line(sys,[235,345;240,345])
add_line(sys,[375,310;395,310;395,295;425,295])
add_line(sys,[485,345;485,345])
add_line(sys,[435,345;440,345])
add_line(sys,[375,310;375,345;390,345])
add_line(sys,[45,305;60,305])
add_line(sys,[95,490;110,490])
add_line(sys,[425,495;425,530;440,530])
add_line(sys,[485,530;490,530])
add_line(sys,[535,530;535,530])
add_line(sys,[580,530;580,595;100,595;110,500])
add_line(sys,[425,495;445,495;445,480;475,480])
add_line(sys,[285,530;290,530])
add_line(sys,[320,530;330,525;350,515;355,440;445,440])
add_line(sys,[245,515;255,515])
add_line(sys,[195,490;200,515])
add_line(sys,[195,545;245,545;255,530])
add_line(sys,[140,495;145,495;145,545;160,545])
add_line(sys,[100,575;150,575])
add_line(sys,[185,575;195,575])
add_line(sys,[240,575;245,575;255,545])
add_line(sys,[310,330;310,330;315,255;395,255])
add_line(sys,[350,515;360,515;380,495])
add_line(sys,[80,125;80,80;100,75])
add_line(sys,[35,120;30,10;250,10;270,130])
add_line(sys,[90,310;95,310;95,305;110,305])
add_line(sys,[140,495;145,495;145,490;160,490])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
