function [ret,x0,str,ts,xts]=diskr71(t,x,u,flag);
%DISKR71	is the M-file description of the SIMULINK system named DISKR71.
%	The block-diagram can be displayed by typing: DISKR71.
%
%	SYS=DISKR71(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DISKR71 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DISKR71 with a FLAG of zero:
%	[SIZES]=DISKR71([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[106,73,920,687])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '100')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '0.05')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'mat-name','t',...
		'buffer','1000000',...
		'position',[590,7,640,23])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[55,115,75,135])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[325,107,360,143])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y1',...
		'buffer','1000000',...
		'position',[420,102,470,118])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'hide name',0,...
		'position',[520,10,540,30])

add_block('built-in/Gain',[sys,'/','Gain4'])
set_param([sys,'/','Gain4'],...
		'hide name',0,...
		'Gain','0.45*Ku-0.5*(0.54*Ku/Pu*T)',...
		'position',[115,257,140,283])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[370,6881458,535,6881553])

add_block('built-in/Inport',[sys,'/','Subsystem1/in_1'])
set_param([sys,'/','Subsystem1/in_1'],...
		'position',[10,55,30,75])

add_block('built-in/Outport',[sys,'/','Subsystem1/out_1'])
set_param([sys,'/','Subsystem1/out_1'],...
		'position',[220,55,240,75])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem1/Transfer Fcn1'])
set_param([sys,'/','Subsystem1/Transfer Fcn1'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[60,47,95,83])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem1/Transfer Fcn2'])
set_param([sys,'/','Subsystem1/Transfer Fcn2'],...
		'hide name',0,...
		'Denominator','[2 1]',...
		'position',[110,47,145,83])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem1/Transfer Fcn3'])
set_param([sys,'/','Subsystem1/Transfer Fcn3'],...
		'hide name',0,...
		'Denominator','[3 1]',...
		'position',[155,47,190,83])
add_line([sys,'/','Subsystem1'],[35,65;55,65])
add_line([sys,'/','Subsystem1'],[195,65;215,65])
add_line([sys,'/','Subsystem1'],[100,65;105,65])
add_line([sys,'/','Subsystem1'],[150,65;150,65])


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'position',[475,320,505,370])

add_block('built-in/Step Fcn',[sys,'/','Step Input1'])
set_param([sys,'/','Step Input1'],...
		'hide name',0,...
		'Time','0',...
		'position',[20,295,40,315])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','y2',...
		'buffer','1000000',...
		'position',[430,287,480,303])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn1'])
set_param([sys,'/','Transfer Fcn1'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[335,292,370,328])

add_block('built-in/Sum',[sys,'/','Sum5'])
set_param([sys,'/','Sum5'],...
		'hide name',0,...
		'inputs','++++',...
		'position',[210,325,230,380])

add_block('built-in/Filter',[sys,'/','Filter5'])
set_param([sys,'/','Filter5'],...
		'hide name',0,...
		'Numerator','[-1 1]',...
		'Denominator','[1 ]',...
		'Sample time','T',...
		'position',[155,310,190,350])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[65,300,85,320])

add_block('built-in/Gain',[sys,'/','Gain6'])
set_param([sys,'/','Gain6'],...
		'hide name',0,...
		'Gain','0.54*Ku*T/Pu',...
		'position',[115,347,140,373])

add_block('built-in/Gain',[sys,'/','Gain7'])
set_param([sys,'/','Gain7'],...
		'hide name',0,...
		'Gain','1.2*Ku/Pu*T',...
		'position',[125,522,150,548])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[75,475,95,495])

add_block('built-in/Filter',[sys,'/','Filter6'])
set_param([sys,'/','Filter6'],...
		'hide name',0,...
		'Numerator','[-1 1]',...
		'Denominator','[1 ]',...
		'Sample time','T',...
		'position',[165,485,200,525])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn2'])
set_param([sys,'/','Transfer Fcn2'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[345,467,380,503])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','y3',...
		'buffer','1000000',...
		'position',[440,462,490,478])

add_block('built-in/Step Fcn',[sys,'/','Step Input2'])
set_param([sys,'/','Step Input2'],...
		'hide name',0,...
		'Time','0',...
		'position',[30,470,50,490])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[370,6881458,535,6881553])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Transfer Fcn3'])
set_param([sys,'/','Subsystem2/Transfer Fcn3'],...
		'hide name',0,...
		'Denominator','[3 1]',...
		'position',[155,47,190,83])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Transfer Fcn2'])
set_param([sys,'/','Subsystem2/Transfer Fcn2'],...
		'hide name',0,...
		'Denominator','[2 1]',...
		'position',[110,47,145,83])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem2/Transfer Fcn1'])
set_param([sys,'/','Subsystem2/Transfer Fcn1'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[60,47,95,83])

add_block('built-in/Outport',[sys,'/','Subsystem2/out_1'])
set_param([sys,'/','Subsystem2/out_1'],...
		'position',[220,55,240,75])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[10,55,30,75])
add_line([sys,'/','Subsystem2'],[150,65;150,65])
add_line([sys,'/','Subsystem2'],[100,65;105,65])
add_line([sys,'/','Subsystem2'],[195,65;215,65])
add_line([sys,'/','Subsystem2'],[35,65;55,65])


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'position',[485,495,515,545])

add_block('built-in/Filter',[sys,'/','Filter7'])
set_param([sys,'/','Filter7'],...
		'hide name',0,...
		'Numerator','[-1  2 -1]',...
		'Denominator','[1 ]',...
		'Sample time','T',...
		'position',[160,547,205,583])

add_block('built-in/Gain',[sys,'/','Gain8'])
set_param([sys,'/','Gain8'],...
		'hide name',0,...
		'Gain','3/(40*T)*Ku*Pu',...
		'position',[120,552,145,578])

add_block('built-in/Gain',[sys,'/','Gain9'])
set_param([sys,'/','Gain9'],...
		'hide name',0,...
		'Gain','0.6*Ku-0.5*(1.2*Ku/Pu*T)',...
		'position',[125,432,150,458])

add_block('built-in/Sum',[sys,'/','Sum6'])
set_param([sys,'/','Sum6'],...
		'hide name',0,...
		'inputs','++++',...
		'position',[230,500,250,555])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay'])
set_param([sys,'/','Unit Delay'],...
		'orientation',2,...
		'Sample time','T',...
		'position',[235,565,285,585])

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'Time','0',...
		'position',[5,110,25,130])

add_block('built-in/Unit Delay',[sys,'/','Unit Delay1'])
set_param([sys,'/','Unit Delay1'],...
		'orientation',2,...
		'Sample time','T',...
		'position',[230,385,280,405])

add_block('built-in/Gain',[sys,'/','Gain5'])
set_param([sys,'/','Gain5'],...
		'hide name',0,...
		'Gain','0',...
		'position',[85,377,110,403])

add_block('built-in/Filter',[sys,'/','Filter4'])
set_param([sys,'/','Filter4'],...
		'hide name',0,...
		'Numerator','[-1  2 -1]',...
		'Denominator','[1 ]',...
		'Sample time','T',...
		'position',[125,372,170,408])

add_block('built-in/Sum',[sys,'/','Sum7'])
set_param([sys,'/','Sum7'],...
		'hide name',0,...
		'position',[270,93,290,137])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','u1',...
		'buffer','1000000',...
		'position',[335,52,385,68])

add_block('built-in/Gain',[sys,'/','Gain1'])
set_param([sys,'/','Gain1'],...
		'hide name',0,...
		'Gain','0.5*Ku',...
		'position',[110,112,135,138])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[370,6881458,535,6881553])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem/Transfer Fcn3'])
set_param([sys,'/','Subsystem/Transfer Fcn3'],...
		'hide name',0,...
		'Denominator','[3 1]',...
		'position',[155,47,190,83])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem/Transfer Fcn2'])
set_param([sys,'/','Subsystem/Transfer Fcn2'],...
		'hide name',0,...
		'Denominator','[2 1]',...
		'position',[110,47,145,83])

add_block('built-in/Transfer Fcn',[sys,'/','Subsystem/Transfer Fcn1'])
set_param([sys,'/','Subsystem/Transfer Fcn1'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[60,47,95,83])

add_block('built-in/Outport',[sys,'/','Subsystem/out_1'])
set_param([sys,'/','Subsystem/out_1'],...
		'position',[220,55,240,75])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[10,55,30,75])
add_line([sys,'/','Subsystem'],[150,65;150,65])
add_line([sys,'/','Subsystem'],[100,65;105,65])
add_line([sys,'/','Subsystem'],[195,65;215,65])
add_line([sys,'/','Subsystem'],[35,65;55,65])


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'orientation',2,...
		'position',[190,140,220,190])
add_line(sys,[545,20;585,15])
add_line(sys,[30,120;50,120])
add_line(sys,[365,125;385,125;385,110;415,110])
add_line(sys,[140,125;265,125])
add_line(sys,[510,345;530,345;530,410;50,410;60,315])
add_line(sys,[50,345;100,345;110,270])
add_line(sys,[175,390;205,360])
add_line(sys,[115,390;120,390])
add_line(sys,[50,390;80,390])
add_line(sys,[90,310;95,310;95,360;110,360])
add_line(sys,[145,360;195,360;205,345])
add_line(sys,[145,270;150,330])
add_line(sys,[195,330;205,330])
add_line(sys,[235,355;240,355;270,345;285,320;300,345;300,310;330,310])
add_line(sys,[375,310;395,310;395,295;425,295])
add_line(sys,[375,310;375,345;470,345])
add_line(sys,[45,305;60,305])
add_line(sys,[55,480;70,480])
add_line(sys,[385,485;385,520;480,520])
add_line(sys,[520,520;540,520;540,585;60,585;70,490])
add_line(sys,[385,485;405,485;405,470;435,470])
add_line(sys,[255,530;250,530;280,520;295,495;310,520;310,485;340,485])
add_line(sys,[205,505;225,505])
add_line(sys,[155,445;160,505])
add_line(sys,[155,535;205,535;225,520])
add_line(sys,[100,485;105,485;105,535;120,535])
add_line(sys,[60,565;115,565])
add_line(sys,[150,565;155,565])
add_line(sys,[210,565;225,535])
add_line(sys,[60,520;110,520;120,445])
add_line(sys,[280,520;290,520;290,575])
add_line(sys,[230,575;215,575;225,550])
add_line(sys,[270,345;290,345;285,395])
add_line(sys,[225,395;195,395;205,375])
add_line(sys,[295,115;320,125])
add_line(sys,[30,120;40,120;40,105;265,105])
add_line(sys,[295,115;305,115;305,90;240,90;240,60;330,60])
add_line(sys,[80,125;105,125])
add_line(sys,[365,125;375,125;375,165;225,165])
add_line(sys,[185,165;30,165;30,130;50,130])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
