function [ret,x0,str,ts,xts]=schema(t,x,u,flag);
%SCHEMA	is the M-file description of the SIMULINK system named SCHEMA.
%	The block-diagram can be displayed by typing: SCHEMA.
%
%	SYS=SCHEMA(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SCHEMA to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SCHEMA with a FLAG of zero:
%	[SIZES]=SCHEMA([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[138,202,747,509])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '10')
set_param(sys,'Min step size', '1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/MATLAB Fcn',[sys,'/','MATLAB Fcn'])
set_param([sys,'/','MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','algor',...
		'Output Width','1',...
		'position',[60,43,120,77])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','u',...
		'position',[385,2,435,18])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','-7',...
		'position',[295,50,315,70])

add_block('built-in/Integrator',[sys,'/','Integrator1'])
set_param([sys,'/','Integrator1'],...
		'hide name',0,...
		'Initial','15.5',...
		'position',[410,50,430,70])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'hide name',0,...
		'mat-name','y',...
		'position',[515,52,565,68])

add_block('built-in/Saturation',[sys,'/','Saturation'])
set_param([sys,'/','Saturation'],...
		'hide name',0,...
		'Lower Limit','-1',...
		'Upper Limit','2',...
		'position',[175,48,205,72])

add_block('built-in/Note',[sys,'/','dy'])
set_param([sys,'/','dy'],...
		'position',[335,40,340,45])


%     Subsystem  'XY Graph'.

new_system([sys,'/','XY Graph'])
set_param([sys,'/','XY Graph'],'Location',[8,52,282,245])

add_block('built-in/Inport',[sys,'/','XY Graph/y'])
set_param([sys,'/','XY Graph/y'],...
		'Port','2',...
		'position',[10,100,30,120])

add_block('built-in/Inport',[sys,'/','XY Graph/x'])
set_param([sys,'/','XY Graph/x'],...
		'position',[10,30,30,50])

add_block('built-in/Mux',[sys,'/','XY Graph/Mux'])
set_param([sys,'/','XY Graph/Mux'],...
		'inputs','2',...
		'position',[100,61,130,94])

add_block('built-in/S-Function',[sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['XY Graph/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfunxy',...
		'parameters','ax, st',...
		'position',[185,70,235,90])
add_line([sys,'/','XY Graph'],[35,110;70,110;70,85;95,85])
add_line([sys,'/','XY Graph'],[35,40;70,40;70,70;95,70])
add_line([sys,'/','XY Graph'],[135,80;180,80])
set_param([sys,'/','XY Graph'],...
		'Mask Display','plot(0,0,100,100,[12,91,91,12,12],[90,90,45,45,90],[51,57,65,75,80,79,75,67,60,54,51,48,42,34,28,27,31,42,51],[71,68,66,66,72,79,83,84,81,77,71,60,54,54,58,65,71,74,71])')
set_param([sys,'/','XY Graph'],...
		'Mask Type','XY scope.',...
		'Mask Dialogue','XY scope using MATLAB graph window.\nFirst input is used as time base.\nEnter plotting ranges.|x-min:|x-max:|y-min:|y-max:')
set_param([sys,'/','XY Graph'],...
		'Mask Translate','ax = [@1, @2, @3, @4];st=-1;',...
		'Mask Help','This block can be used to explore limit cycles. Look at the m-file sfunxy.m to see how it works.',...
		'Mask Entries','-20\/20\/-10\/10\/')


%     Finished composite block 'XY Graph'.

set_param([sys,'/','XY Graph'],...
		'position',[505,111,535,149])

add_block('built-in/Filter',[sys,'/','Filter'])
set_param([sys,'/','Filter'],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','1',...
		'Denominator','1',...
		'position',[270,156,295,184])

add_block('built-in/Filter',[sys,'/','Filter1'])
set_param([sys,'/','Filter1'],...
		'orientation',2,...
		'hide name',0,...
		'Numerator','1',...
		'Denominator','1',...
		'position',[270,106,295,134])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'orientation',2,...
		'hide name',0,...
		'inputs','2',...
		'position',[90,110,125,145])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','dy',...
		'position',[455,177,505,193])
add_line(sys,[320,60;405,60])
add_line(sys,[435,60;510,60])
add_line(sys,[435,60;450,60;450,120;500,120])
add_line(sys,[320,60;350,60;350,140;500,140])
add_line(sys,[85,130;15,130;15,60;55,60])
add_line(sys,[350,125;350,170;300,170])
add_line(sys,[265,170;240,170;240,135;130,135])
add_line(sys,[265,120;130,120])
add_line(sys,[125,60;170,60])
add_line(sys,[210,60;290,60])
add_line(sys,[255,60;255,10;380,10])
add_line(sys,[350,140;425,140;425,185;450,185])
add_line(sys,[450,120;300,120])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
