function [ret,x0,str,ts,xts]=spojity7(t,x,u,flag);
%SPOJITY7	is the M-file description of the SIMULINK system named SPOJITY7.
%	The block-diagram can be displayed by typing: SPOJITY7.
%
%	SYS=SPOJITY7(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes SPOJITY7 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling SPOJITY7 with a FLAG of zero:
%	[SIZES]=SPOJITY7([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[186,171,854,723])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '60')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '0.05')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   't')

add_block('built-in/Step Fcn',[sys,'/','Step Input'])
set_param([sys,'/','Step Input'],...
		'hide name',0,...
		'position',[55,70,75,90])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,75,125,95])


%     Subsystem  'PID Controller'.

new_system([sys,'/','PID Controller'])
set_param([sys,'/','PID Controller'],'Location',[0,0,362,244])

add_block('built-in/Sum',[sys,'/','PID Controller/Sum'])
set_param([sys,'/','PID Controller/Sum'],...
		'inputs','+++',...
		'position',[245,57,265,93])

add_block('built-in/Gain',[sys,'/','PID Controller/D'])
set_param([sys,'/','PID Controller/D'],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Gain',[sys,'/','PID Controller/Proportional'])
set_param([sys,'/','PID Controller/Proportional'],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Transfer Fcn',[sys,'/','PID Controller/Integral'])
set_param([sys,'/','PID Controller/Integral'],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Derivative',[sys,'/','PID Controller/Derivative'])
set_param([sys,'/','PID Controller/Derivative'],...
		'position',[150,128,190,152])

add_block('built-in/Outport',[sys,'/','PID Controller/Out_1'])
set_param([sys,'/','PID Controller/Out_1'],...
		'position',[290,65,310,85])

add_block('built-in/Inport',[sys,'/','PID Controller/In_1'])
set_param([sys,'/','PID Controller/In_1'],...
		'position',[25,65,45,85])
add_line([sys,'/','PID Controller'],[120,140;145,140])
add_line([sys,'/','PID Controller'],[270,75;285,75])
add_line([sys,'/','PID Controller'],[50,75;105,75])
add_line([sys,'/','PID Controller'],[65,75;65,140;90,140])
add_line([sys,'/','PID Controller'],[80,75;80,25;115,25])
add_line([sys,'/','PID Controller'],[195,140;215,140;215,85;240,85])
add_line([sys,'/','PID Controller'],[150,75;240,75])
add_line([sys,'/','PID Controller'],[145,25;210,25;210,65;240,65])
set_param([sys,'/','PID Controller'],...
		'Mask Display','PID',...
		'Mask Type','PID Controller',...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:')
set_param([sys,'/','PID Controller'],...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/','PID Controller'],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/','PID Controller'],...
		'Mask Entries','Ku/2\/0\/0\/')


%     Finished composite block 'PID Controller'.

set_param([sys,'/','PID Controller'],...
		'hide name',0,...
		'position',[155,69,195,101])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn7'])
set_param([sys,'/','Transfer Fcn7'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[270,232,305,268])


%     Subsystem  'PID Controller1'.

new_system([sys,'/','PID Controller1'])
set_param([sys,'/','PID Controller1'],'Location',[0,0,362,244])

add_block('built-in/Inport',[sys,'/','PID Controller1/In_1'])
set_param([sys,'/','PID Controller1/In_1'],...
		'position',[25,65,45,85])

add_block('built-in/Outport',[sys,'/','PID Controller1/Out_1'])
set_param([sys,'/','PID Controller1/Out_1'],...
		'position',[290,65,310,85])

add_block('built-in/Derivative',[sys,'/','PID Controller1/Derivative'])
set_param([sys,'/','PID Controller1/Derivative'],...
		'position',[150,128,190,152])

add_block('built-in/Transfer Fcn',[sys,'/','PID Controller1/Integral'])
set_param([sys,'/','PID Controller1/Integral'],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Gain',[sys,'/','PID Controller1/Proportional'])
set_param([sys,'/','PID Controller1/Proportional'],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Gain',[sys,'/','PID Controller1/D'])
set_param([sys,'/','PID Controller1/D'],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Sum',[sys,'/','PID Controller1/Sum'])
set_param([sys,'/','PID Controller1/Sum'],...
		'inputs','+++',...
		'position',[245,57,265,93])
add_line([sys,'/','PID Controller1'],[145,25;210,25;210,65;240,65])
add_line([sys,'/','PID Controller1'],[150,75;240,75])
add_line([sys,'/','PID Controller1'],[195,140;215,140;215,85;240,85])
add_line([sys,'/','PID Controller1'],[50,75;105,75])
add_line([sys,'/','PID Controller1'],[80,75;80,25;115,25])
add_line([sys,'/','PID Controller1'],[65,75;65,140;90,140])
add_line([sys,'/','PID Controller1'],[270,75;285,75])
add_line([sys,'/','PID Controller1'],[120,140;145,140])
set_param([sys,'/','PID Controller1'],...
		'Mask Display','PID',...
		'Mask Type','PID Controller',...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:')
set_param([sys,'/','PID Controller1'],...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/','PID Controller1'],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/','PID Controller1'],...
		'Mask Entries','.45*Ku\/1.2/Pu\/0\/')


%     Finished composite block 'PID Controller1'.

set_param([sys,'/','PID Controller1'],...
		'hide name',0,...
		'position',[155,234,195,266])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,240,125,260])

add_block('built-in/Step Fcn',[sys,'/','Step Input1'])
set_param([sys,'/','Step Input1'],...
		'hide name',0,...
		'position',[55,235,75,255])

add_block('built-in/Step Fcn',[sys,'/','Step Input2'])
set_param([sys,'/','Step Input2'],...
		'hide name',0,...
		'position',[55,395,75,415])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[105,400,125,420])


%     Subsystem  'PID Controller2'.

new_system([sys,'/','PID Controller2'])
set_param([sys,'/','PID Controller2'],'Location',[0,0,362,244])

add_block('built-in/Sum',[sys,'/','PID Controller2/Sum'])
set_param([sys,'/','PID Controller2/Sum'],...
		'inputs','+++',...
		'position',[245,57,265,93])

add_block('built-in/Gain',[sys,'/','PID Controller2/D'])
set_param([sys,'/','PID Controller2/D'],...
		'Gain','D',...
		'position',[95,129,115,151])

add_block('built-in/Gain',[sys,'/','PID Controller2/Proportional'])
set_param([sys,'/','PID Controller2/Proportional'],...
		'Gain','P',...
		'position',[120,13,140,37])

add_block('built-in/Transfer Fcn',[sys,'/','PID Controller2/Integral'])
set_param([sys,'/','PID Controller2/Integral'],...
		'Numerator','[I]',...
		'Denominator','[1 0]',...
		'position',[110,57,145,93])

add_block('built-in/Derivative',[sys,'/','PID Controller2/Derivative'])
set_param([sys,'/','PID Controller2/Derivative'],...
		'position',[150,128,190,152])

add_block('built-in/Outport',[sys,'/','PID Controller2/Out_1'])
set_param([sys,'/','PID Controller2/Out_1'],...
		'position',[290,65,310,85])

add_block('built-in/Inport',[sys,'/','PID Controller2/In_1'])
set_param([sys,'/','PID Controller2/In_1'],...
		'position',[25,65,45,85])
add_line([sys,'/','PID Controller2'],[120,140;145,140])
add_line([sys,'/','PID Controller2'],[270,75;285,75])
add_line([sys,'/','PID Controller2'],[50,75;105,75])
add_line([sys,'/','PID Controller2'],[65,75;65,140;90,140])
add_line([sys,'/','PID Controller2'],[80,75;80,25;115,25])
add_line([sys,'/','PID Controller2'],[195,140;215,140;215,85;240,85])
add_line([sys,'/','PID Controller2'],[150,75;240,75])
add_line([sys,'/','PID Controller2'],[145,25;210,25;210,65;240,65])
set_param([sys,'/','PID Controller2'],...
		'Mask Display','PID',...
		'Mask Type','PID Controller',...
		'Mask Dialogue','Enter expressions for proportional, integral, and derivative terms.\nP+I/s+Ds|Proportional:|Integral|Derivative:')
set_param([sys,'/','PID Controller2'],...
		'Mask Translate','P=@1; I=@2; D=@3;')
set_param([sys,'/','PID Controller2'],...
		'Mask Help','This block implements a PID controller where parameters are entered for the Proportional, Integral and Derivative terms. Unmask this block to see how it works. The derivative term is implemented using a true derivative block.')
set_param([sys,'/','PID Controller2'],...
		'Mask Entries','.6*Ku\/2/Pu\/Pu/8\/')


%     Finished composite block 'PID Controller2'.

set_param([sys,'/','PID Controller2'],...
		'hide name',0,...
		'position',[155,394,195,426])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn8'])
set_param([sys,'/','Transfer Fcn8'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[270,392,305,428])

add_block('built-in/Sum',[sys,'/','Sum3'])
set_param([sys,'/','Sum3'],...
		'hide name',0,...
		'position',[220,70,240,90])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn12'])
set_param([sys,'/','Transfer Fcn12'],...
		'hide name',0,...
		'Denominator','[6 11 6 1]',...
		'position',[330,105,450,145])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn'])
set_param([sys,'/','Transfer Fcn'],...
		'hide name',0,...
		'Denominator','[1 1]',...
		'position',[270,62,305,98])

add_block('built-in/To Workspace',[sys,'/','To Workspace1'])
set_param([sys,'/','To Workspace1'],...
		'hide name',0,...
		'mat-name','y1',...
		'buffer','1000000',...
		'position',[365,72,415,88])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn13'])
set_param([sys,'/','Transfer Fcn13'],...
		'hide name',0,...
		'Denominator','[6 11 6 1]',...
		'position',[330,265,450,305])

add_block('built-in/Transfer Fcn',[sys,'/','Transfer Fcn14'])
set_param([sys,'/','Transfer Fcn14'],...
		'hide name',0,...
		'Denominator','[6 11 6 1]',...
		'position',[325,425,445,465])

add_block('built-in/To Workspace',[sys,'/','To Workspace5'])
set_param([sys,'/','To Workspace5'],...
		'hide name',0,...
		'mat-name','y3',...
		'buffer','1000000',...
		'position',[365,402,415,418])

add_block('built-in/To Workspace',[sys,'/','To Workspace4'])
set_param([sys,'/','To Workspace4'],...
		'hide name',0,...
		'mat-name','y2',...
		'buffer','1000000',...
		'position',[365,242,415,258])
add_line(sys,[80,80;100,80])
add_line(sys,[130,85;150,85])
add_line(sys,[310,80;310,125;325,125])
add_line(sys,[310,80;360,80])
add_line(sys,[310,250;360,250])
add_line(sys,[310,250;310,285;325,285])
add_line(sys,[200,250;265,250])
add_line(sys,[130,250;150,250])
add_line(sys,[80,245;100,245])
add_line(sys,[80,405;100,405])
add_line(sys,[130,410;150,410])
add_line(sys,[200,410;265,410])
add_line(sys,[310,410;320,445])
add_line(sys,[310,410;360,410])
add_line(sys,[200,85;215,85])
add_line(sys,[245,80;265,80])
add_line(sys,[90,80;90,50;205,50;215,75])
add_line(sys,[455,125;485,125;485,165;90,165;90,90;100,90])
add_line(sys,[455,285;465,285;465,335;90,335;100,255])
add_line(sys,[450,445;465,445;465,495;90,495;100,415])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
