//-------------------------------------------------------------------
// PROGRAM: randchi.hpp
//
// PURPOSE: Generates chi-square distributed random numbers
//-------------------------------------------------------------------

/*
---------------------------------------------------------------------
   Note: Formula obtained from Law & Kelton, see reference.
   We can exploit the gamma function to generate Chi^2 variates by
   setting gamma( k / 2, 2 ), where k is the degrees of freedom of
   the Chi^2 variate.


Parameters: degreesOfFreedom is an integer >= 1.

Range:      [ 0, +infinity ]

Mean:       degreesOfFreedom

Var:        2 * degreesOfFreedom


References: Simulation Modeling & Analysis by Law and Kelton, 1991,
            pgs., 332, 336, 383, 384, 560, 484-485.

            Discrete System Simulation by William G. Bulgren, 1982,
            pg., 170.

            Statistical Distributions by Hastings and Peacock, 1975,
            pgs., 46-51.
---------------------------------------------------------------------
*/

#if !defined _RANDCHI_HPP
#define      _RANDCHI_HPP 1

//----------------------------- Includes --------------------------//

#if !defined ( _RAND_HPP )
#include "rand.hpp"
#endif


//--------------------------- Forward reference -------------------//

class RandGamma;



class RandChiSquare : public Rand
   {
   private:

      RandGamma *pRNG;              // Chi is gamma with shape = ( alpha/2 )
                                    // and scale = 2

      UINT degreesOfFreedom;        // k df

   public:

      //-- constructors --//
      RandChiSquare( UINT _degreesOfFreedom, long _seed, char *_name = "-" );
      RandChiSquare( UINT _degreesOfFreedom, UINT _stream, long _seed,
            char *_name = "-" );

      //-- destructor --//
      virtual ~RandChiSquare( void );

      //-- returns a chi-square random variable --//
      virtual double RandValue( void );

   };

#endif
